#!/usr/bin/perl -w
#
# 2ine; an OS/2 emulator for Linux.
#
# Please see the file LICENSE.txt in the source's root directory.
#
#  This file written by Ryan C. Gordon.

use warnings;
use strict;

# This is by no means a complete list!
my %os2modules = (

  'DOSCALLS' => {
    1 => 'DosICreateThread',
    2 => 'Dos16Cwait',
    3 => 'Dos16EnterCritSec',
    4 => 'DosIExecPgm',
    5 => 'Dos16Exit',
    6 => 'Dos16ExitCritSec',
    7 => 'Dos16ExitList',
    8 => 'Dos16GetInfoSeg',
    9 => 'Dos16GetPrty',
    10 => 'Dos16KillProcess',
    11 => 'Dos16SetPrty',
    12 => 'Dos16Ptrace',
    13 => 'Dos16HoldSignal',
    14 => 'Dos16SetSigHandler',
    15 => 'Dos16FlagProcess',
    16 => 'Dos16MakePipe',
    17 => 'DosISysSemClear',
    18 => 'DosISemRequest',
    19 => 'DosISysSemSet',
    20 => 'Dos16SemSetWait',
    21 => 'DosISemWait',
    22 => 'Dos16MuxSemWait',
    23 => 'Dos16CloseSem',
    24 => 'Dos16CreateSem',
    25 => 'Dos16OpenSem',
    26 => 'Dos16ResumeThread',
    27 => 'Dos16SuspendThread',
    28 => 'Dos16SetDateTime',
    29 => 'Dos16TimerAsync',
    30 => 'Dos16TimerStart',
    31 => 'Dos16TimerStop',
    32 => 'Dos16Sleep',
    33 => 'Dos16GetDateTime',
    34 => 'Dos16AllocSeg',
    35 => 'Dos16AllocShrSeg',
    36 => 'Dos16GetShrSeg',
    37 => 'Dos16GiveSeg',
    38 => 'Dos16ReallocSeg',
    39 => 'Dos16FreeSeg',
    40 => 'Dos16AllocHuge',
    41 => 'Dos16GetHugeShift',
    42 => 'Dos16ReallocHuge',
    43 => 'Dos16CreateCSAlias',
    44 => 'Dos16LoadModule',
    45 => 'Dos16GetProcAddr',
    46 => 'Dos16FreeModule',
    47 => 'Dos16GetModHandle',
    48 => 'Dos16GetModName',
    49 => 'Dos16GetMachineMode',
    50 => 'Dos16Beep',
    51 => 'Dos16CLIAccess',
    52 => 'Dos16DevConfig',
    53 => 'Dos16DevIOCtl',
    54 => 'Dos16SGSwitch',
    55 => 'Dos16SGSwitchMe',
    56 => 'Dos16BufReset',
    57 => 'Dos16ChDir',
    58 => 'Dos16ChgFilePtr',
    59 => 'Dos16Close',
    60 => 'Dos16Delete',
    61 => 'Dos16DupHandle',
    62 => 'Dos16FileLocks',
    63 => 'Dos16FindClose',
    64 => 'Dos16FindFirst',
    65 => 'Dos16FindNext',
    66 => 'Dos16MkDir',
    67 => 'Dos16Move',
    68 => 'Dos16NewSize',
    69 => 'Dos16PortAccess',
    70 => 'Dos16Open',
    71 => 'Dos16QCurDir',
    72 => 'Dos16QCurDisk',
    73 => 'Dos16QFHandState',
    74 => 'Dos16QFileInfo',
    75 => 'Dos16QFileMode',
    76 => 'Dos16QFSInfo',
    77 => 'Dos16QHandType',
    78 => 'Dos16QVerify',
    79 => 'DosIRead',
    80 => 'Dos16RmDir',
    81 => 'Dos16SelectDisk',
    82 => 'Dos16SetFHandState',
    83 => 'Dos16SetFileInfo',
    84 => 'Dos16SetFileMode',
    85 => 'Dos16SetMaxFH',
    86 => 'Dos16SetVerify',
    87 => 'DosIWrite',
    88 => 'Dos16SystemService',
    89 => 'Dos16SetVec',
    90 => 'Dos16SysTrace',
    91 => 'Dos16GetEnv',
    92 => 'Dos16GetVersion',
    93 => 'Dos16QTraceInfo',
    94 => 'Dos16GetPID',
    95 => 'Dos16Open2',
    96 => 'Dos16LibInit',
    97 => 'Dos16SetFSInfo',
    98 => 'Dos16QPathInfo',
    99 => 'Dos16DevIOCtl2',
    100 => 'DosICanonicalize',
    101 => 'Dos16SetFgnd',
    102 => 'Dos16SwapTaskInit',
    103 => 'Dos16ReadPhys',
    104 => 'Dos16SetPathInfo',
    105 => 'Dos16SGSwitchProc2',
    106 => 'STRUCHECK',
    107 => 'STRURESUPDATE',
    108 => 'DosISetRelMaxFH',
    109 => 'DosIDevIOCtl',
    110 => 'Dos32ForceDelete',
    111 => 'Dos32KillThread',
    112 => 'Dos32QueryRASInfo',
    113 => 'Dos32DumpProcess',
    114 => 'Dos32SuppressPopUps',
    115 => 'THK32ALLOCMEM',
    116 => 'THK32FREEMEM',
    117 => 'THK32ALLOCSTACK',
    118 => 'DosOpen2Compt',
    119 => 'Dos16GetSTDA',
    120 => 'Dos16Error',
    121 => 'Dos16GetSeg',
    122 => 'Dos16LockSeg',
    123 => 'Dos16UnlockSeg',
    124 => 'Dos16SGSwitchProc',
    125 => 'DosIRamSemWake',
    126 => 'Dos16SizeSeg',
    127 => 'Dos16MemAvail',
    128 => 'DosIRamSemRequest',
    129 => 'DosPhysicalDisk',
    130 => 'Dos16GetCP',
    131 => 'DosISetCP',
    132 => 'DosGlobalSeg',
    133 => 'Dos16Profile',
    134 => 'Dos16SendSignal',
    135 => 'DosHugeShift',
    136 => 'DosHugeIncr',
    137 => 'Dos16Read',
    138 => 'Dos16Write',
    139 => 'Dos16ErrClass',
    140 => 'Dos16SemRequest',
    141 => 'Dos16SemClear',
    142 => 'Dos16SemWait',
    143 => 'Dos16SemSet',
    144 => 'Dos16ExecPgm',
    145 => 'Dos16CreateThread',
    146 => 'Dos16SubSet',
    147 => 'Dos16SubAlloc',
    148 => 'Dos16SubFree',
    149 => 'Dos16ReadAsync',
    150 => 'Dos16WriteAsync',
    151 => 'Dos16SearchPath',
    152 => 'Dos16ScanEnv',
    153 => 'Dos16SetCP',
    154 => 'Dos16QProcStatus',
    155 => 'Dos16GetResource',
    156 => 'Dos16GetPPID',
    157 => 'Dos16CallBack',
    158 => 'DosICallBack',
    159 => 'DosRetForward',
    160 => 'Dos16R2StackRealloc',
    161 => 'Dos16FSRamSemRequest',
    162 => 'Dos16FSRamSemClear',
    163 => 'Dos16QAppType',
    164 => 'Dos16SetProcCP',
    165 => 'Dos16DynamicTrace',
    166 => 'Dos16QSysInfo',
    167 => 'DosIMakeNmPipe',
    168 => 'DosICallNmPipe',
    169 => 'DosIConnectNmPipe',
    170 => 'DosIDisconnectNmPipe',
    171 => 'DosIPeekNmPipe',
    172 => 'DosIQNmPipeInfo',
    173 => 'DosIQNmPHandState',
    174 => 'DosISetNmPHandState',
    175 => 'DosITransactNmPipe',
    176 => 'DosIWaitNmPipe',
    177 => 'DosISetNmPipeSem',
    178 => 'DosIQNmPipeSemState',
    179 => 'DosIRawReadNmPipe',
    180 => 'DosIRawWriteNmPipe',
    181 => 'Dos16FSAttach',
    182 => 'Dos16QFSAttach',
    183 => 'Dos16FSCtl',
    184 => 'Dos16FindFirst2',
    185 => 'Dos16MkDir2',
    186 => 'Dos16FileIO',
    187 => 'Dos16FindNotifyClose',
    188 => 'Dos16FindNotifyFirst',
    189 => 'Dos16FindNotifyNext',
    190 => 'Dos16SetTraceInfo',
    191 => 'Dos16EditName',
    192 => 'Dos16LogMode',
    193 => 'Dos16LogEntry',
    194 => 'Dos16GetLogBuffer',
    195 => 'Dos16LogRegister',
    196 => 'Dos16LogRead',
    197 => 'Dos16FindFromName',
    198 => 'Dos16OPLockRelease',
    199 => 'Dos16OPLockWait',
    200 => 'DosICopy',
    201 => 'Dos16Copy',
    202 => 'DosIQAppType',
    203 => 'DosForceDelete',
    204 => 'DosEnumAttribute',
    205 => 'Dos16OPLockShutdown',
    206 => 'DosShutdown',
    207 => 'DosGetResource2',
    208 => 'DosFreeResource',
    209 => 'Dos32SetMaxFH',
    210 => 'Dos32SetVerify',
    211 => 'Dos32ErrClass',
    212 => 'Dos32Error',
    213 => 'DosCreateVDM',
    214 => 'DosMaxPathLen',
    215 => 'DosPageSize',
    216 => 'DosLocalInfo',
    217 => 'DosGlobalInfo',
    218 => 'Dos32SetFileInfo',
    219 => 'Dos32SetPathInfo',
    220 => 'Dos32SetDefaultDisk',
    221 => 'Dos32SetFHState',
    222 => 'Dos32SetFSInfo',
    223 => 'Dos32QueryPathInfo',
    224 => 'Dos32QueryHType',
    225 => 'Dos32QueryVerify',
    226 => 'Dos32DeleteDir',
    227 => 'Dos32ScanEnv',
    228 => 'Dos32SearchPath',
    229 => 'Dos32Sleep',
    230 => 'Dos32GetDateTime',
    231 => 'Dos32DevConfig',
    232 => 'Dos32EnterCritSec',
    233 => 'Dos32ExitCritSec',
    234 => 'Dos32Exit',
    235 => 'Dos32KillProcess',
    236 => 'Dos32SetPriority',
    237 => 'Dos32ResumeThread',
    238 => 'Dos32SuspendThread',
    239 => 'Dos32CreatePipe',
    240 => 'Dos32CallNPipe',
    241 => 'Dos32ConnectNPipe',
    242 => 'Dos32DisConnectNPipe',
    243 => 'Dos32CreateNPipe',
    244 => 'Dos32PeekNPipe',
    245 => 'Dos32QueryNPHState',
    246 => 'Dos32RawReadNPipe',
    247 => 'Dos32RawWriteNPipe',
    248 => 'Dos32QueryNPipeInfo',
    249 => 'Dos32QueryNPipeSemState',
    250 => 'Dos32SetNPHState',
    251 => 'Dos32SetNPipeSem',
    252 => 'Dos32TransactNPipe',
    253 => 'Dos32WaitNPipe',
    254 => 'Dos32ResetBuffer',
    255 => 'Dos32SetCurrentDir',
    256 => 'Dos32SetFilePtr',
    257 => 'Dos32Close',
    258 => 'Dos32Copy',
    259 => 'Dos32Delete',
    260 => 'Dos32DupHandle',
    261 => 'Dos32EditName',
    262 => 'THK32FREESTACK',
    263 => 'Dos32FindClose',
    264 => 'Dos32FindFirst',
    265 => 'Dos32FindNext',
    266 => 'Dos16OpenVDD',
    267 => 'Dos16RequestVDD',
    268 => 'Dos16CloseVDD',
    269 => 'Dos32FSAttach',
    270 => 'Dos32CreateDir',
    271 => 'Dos32Move',
    272 => 'Dos32SetFileSize',
    273 => 'Dos32Open',
    274 => 'Dos32QueryCurrentDir',
    275 => 'Dos32QueryCurrentDisk',
    276 => 'Dos32QueryFHState',
    277 => 'Dos32QueryFSAttach',
    278 => 'Dos32QueryFSInfo',
    279 => 'Dos32QueryFileInfo',
    280 => 'Dos32WaitChild',
    281 => 'Dos32Read',
    282 => 'Dos32Write',
    283 => 'Dos32ExecPgm',
    284 => 'Dos32DevIOCtl',
    285 => 'Dos32FSCtl',
    286 => 'Dos32Beep',
    287 => 'Dos32PhysicalDisk',
    288 => 'Dos32SetCp',
    289 => 'Dos32SetProcessCp',
    290 => 'Dos32StopTimer',
    291 => 'Dos32QueryCp',
    292 => 'Dos32SetDateTime',
    293 => 'Thk32AllocBlock',
    294 => 'Thk32FreeBlock',
    295 => 'Thk32R3DS',
    296 => 'Dos32ExitList',
    297 => 'Dos32AllocProtectedMem',
    298 => 'Dos32AliasMem',
    299 => 'Dos32AllocMem',
    300 => 'Dos32AllocSharedMem',
    301 => 'Dos32GetNamedSharedMem',
    302 => 'Dos32GetSharedMem',
    303 => 'Dos32GiveSharedMem',
    304 => 'Dos32FreeMem',
    305 => 'Dos32SetMem',
    306 => 'Dos32QueryMem',
    307 => 'Dos32QueryMemState',
    308 => 'Dos32OpenVDD',
    309 => 'Dos32RequestVDD',
    310 => 'Dos32CloseVDD',
    311 => 'Dos32CreateThread',
    312 => 'Dos32GetInfoBlocks',
    313 => 'Dos16AllocProtSeg',
    314 => 'Dos16AllocShrProtSeg',
    315 => 'Dos16AllocProtHuge',
    316 => 'Dos32DynamicTrace',
    317 => 'Dos32Debug',
    318 => 'Dos32LoadModule',
    319 => 'Dos32QueryModuleHandle',
    320 => 'Dos32QueryModuleName',
    321 => 'Dos32QueryProcAddr',
    322 => 'Dos32FreeModule',
    323 => 'Dos32QueryAppType',
    324 => 'Dos32CreateEventSem',
    325 => 'Dos32OpenEventSem',
    326 => 'Dos32CloseEventSem',
    327 => 'Dos32ResetEventSem',
    328 => 'Dos32PostEventSem',
    329 => 'Dos32WaitEventSem',
    330 => 'Dos32QueryEventSem',
    331 => 'Dos32CreateMutexSem',
    332 => 'Dos32OpenMutexSem',
    333 => 'Dos32CloseMutexSem',
    334 => 'Dos32RequestMutexSem',
    335 => 'Dos32ReleaseMutexSem',
    336 => 'Dos32QueryMutexSem',
    337 => 'Dos32CreateMuxWaitSem',
    338 => 'Dos32OpenMuxWaitSem',
    339 => 'Dos32CloseMuxWaitSem',
    340 => 'Dos32WaitMuxWaitSem',
    341 => 'Dos32AddMuxWaitSem',
    342 => 'Dos32DeleteMuxWaitSem',
    343 => 'Dos32QueryMuxWaitSem',
    344 => 'Dos32SubSetMem',
    345 => 'Dos32SubAllocMem',
    346 => 'Dos32SubFreeMem',
    347 => 'Dos32SubUnsetMem',
    348 => 'Dos32QuerySysInfo',
    349 => 'Dos32WaitThread',
    350 => 'Dos32AsyncTimer',
    351 => 'Dos32StartTimer',
    352 => 'Dos32GetResource',
    353 => 'Dos32FreeResource',
    354 => 'Dos32SetExceptionHandler',
    355 => 'Dos32UnsetExceptionHandler',
    356 => 'Dos32RaiseException',
    357 => 'Dos32UnwindException',
    358 => 'Dos32QueryPageUsage',
    359 => 'Dos16QueryModFromCS',
    360 => 'Dos32QueryModFromEIP',
    361 => 'DosFPDataArea',
    362 => 'Dos32TmrQueryFreq',
    363 => 'Dos32TmrQueryTime',
    364 => 'Dos32AliasPerfCtrs',
    365 => 'Dos32ConfigPerf',
    366 => 'Dos32DeconPerf',
    367 => 'Dos32RegisterPerfCtrs',
    368 => 'Dos32QuerySysState',
    369 => 'Dos32FlatCS',
    370 => 'Dos32FlatDS',
    371 => 'Dos32QueryABIOSSupport',
    372 => 'Dos32EnumAttribute',
    373 => 'Dos32QueryDosProperty',
    374 => 'Dos32SetDosProperty',
    375 => 'Dos16QueryDosProperty',
    376 => 'Dos16SetDosProperty',
    377 => 'Dos32Profile',
    378 => 'Dos32SetSignalExceptionFocus',
    379 => 'Dos32SendSignalException',
    380 => 'Dos32EnterMustComplete',
    381 => 'Dos32ExitMustComplete',
    382 => 'Dos32SetRelMaxFH',
    383 => 'Dos16PutMessage',
    384 => 'Dos16TrueGetMessage',
    385 => 'Dos16InsMessage',
    386 => 'Dos32InsertMessage',
    387 => 'Dos32PutMessage',
    388 => 'Dos32TrueGetMessage',
    389 => 'DosIQueryMessageCP',
    390 => 'Dos32IQueryMessageCP',
    391 => 'Dos16CaseMap',
    392 => 'Dos16GetCollate',
    393 => 'Dos16GetCtryInfo',
    394 => 'Dos16GetDBCSEv',
    395 => 'Dos32QueryCtryInfo',
    396 => 'Dos32QueryDBCSEnv',
    397 => 'Dos32MapCase',
    398 => 'Dos32QueryCollate',
    399 => 'Dos16MakeNmPipe',
    400 => 'Dos16QNmPipeInfo',
    401 => 'Dos16ConnectNmPipe',
    402 => 'Dos16DisconnectNmPipe',
    403 => 'Dos16QNmPHandState',
    404 => 'Dos16SetNmPHandState',
    405 => 'Dos16PeekNmPipe',
    406 => 'Dos16WaitNmPipe',
    407 => 'Dos16TransactNmPipe',
    408 => 'Dos16CallNmPipe',
    409 => 'Dos16RawReadNmPipe',
    410 => 'Dos16RawWriteNmPipe',
    411 => 'Dos16SetNmPipeSem',
    412 => 'Dos16QNmPipeSemState',
    413 => 'StartLazyWriter',
    414 => '_QueInst_Data',
    415 => 'Dos32Shutdown',
    416 => 'Dos32ICacheModule',
    417 => 'Dos32ReplaceModule',
    418 => 'Dos32AcknowledgeSignalException',
    419 => 'Dos32TIB',
    420 => 'Dos16TmrQueryFreq',
    421 => 'Dos16TmrQueryTime',
    422 => 'Dos16RegisterPerfCtrs',
    423 => 'Dos16FlatToSel',
    424 => 'Dos16SelToFlat',
    425 => 'Dos32FlatToSel',
    426 => 'Dos32SelToFlat',
    427 => 'DosIODelayCnt',
    428 => 'Dos32SetFileLocks',
    429 => 'Dos32CancelLockRequest',
    430 => 'Dos32GetLocaleModule',
    430 => 'LogOpen',
    431 => 'LogClose',
    432 => 'LogAddEntries',
    433 => 'LogGetEntries',
    434 => 'LogSetState',
    435 => 'LogSetName',
    436 => 'LogQueryState',
    437 => 'Dos16OpenChangeNotify',
    438 => 'Dos16ResetChangeNotify',
    439 => 'Dos16CloseChangeNotify',
    440 => 'Dos32OpenChangeNotify',
    441 => 'Dos32ResetChangeNotify',
    442 => 'Dos32CloseChangeNotify',
    443 => 'Dos16QueryABIOSSupport',
    444 => 'Dos32ForceSystemDump',
    447 => 'Dos32GetProcessorStatus',
    448 => 'Dos32SetProcessorStatus',
    449 => 'Dos16CreateSpinLock',
    450 => 'Dos16AcquireSpinLock',
    451 => 'Dos16ReleaseSpinLock',
    452 => 'Dos16FreeSpinLock',
    453 => 'Dos32TestPSD',
    454 => 'Dos32AllocThreadLocalMemory',
    455 => 'Dos32FreeThreadLocalMemory',
    460 => 'Dos32VerifyPIDTID',
    464 => 'PTDA_LANMAN_SEC',
    465 => 'PTDA_PID',
    466 => 'SAS_SEL',
    467 => 'TCB_OPCOOKIE',
    468 => 'TCB_OPFLAGS',
    469 => 'TCB_NEWFLAGS',
    470 => 'TCB_USER_ID',
    471 => 'TCB_PROC_ID',
    472 => 'TCB_FSHARING',
    473 => 'TCB_SRVATTRIB',
    474 => 'TCB_ALLOWED',
    475 => 'TCB_PRTCB',
    476 => 'TCB_NUMBER',
    477 => 'TCB_THISSFT',
    478 => 'TCB_THISCDS',
    479 => 'TKOPTDA',
    480 => 'PTDA_CRITSEC',
    481 => 'PTDA_HOLDSIGCNT',
    482 => 'PTDA_PPTDAPARENT',
    483 => 'PTDA_PGDATA',
    484 => 'PTDA_HANDLE',
    485 => 'PTDA_MODULE',
    486 => 'PTDA_LDTHANDLE',
    487 => 'PTDA_CODEPAGE_TAG',
    488 => 'PTDA_JFN_LENGTH',
    489 => 'PTDA_JFN_PTABLE',
    490 => 'PTDA_JFN_FLG_PTR',
    491 => 'PTDA_EXTERR_LOCUS',
    492 => 'PTDA_EXTERR',
    493 => 'PTDA_EXTERR_ACTION',
    494 => 'PTDA_EXTERR_CLASS',
    495 => 'PTDA_PPID',
    496 => 'PTDA_PROCTYPE',
    497 => 'PTDA_CURRTCB',
    498 => 'PTDA_CURRTSD',
    499 => 'PTDA_SIGNATURE',
    500 => 'T32EXITLIST',
    501 => 'T32ALLOCPROTECTEDMEM',
    502 => 'T32ALIASMEM',
    503 => 'T32ALLOCMEM',
    504 => 'T32ALLOCSHAREDMEM',
    505 => 'T32GETNAMEDSHAREDMEM',
    506 => 'T32GETSHAREDMEM',
    507 => 'T32GIVESHAREDMEM',
    508 => 'T32FREEMEM',
    509 => 'T32SETMEM',
    510 => 'T32QUERYMEM',
    511 => 'T32QUERYMEMSTATE',
    512 => 'T32OPENVDD',
    513 => 'T32REQUESTVDD',
    514 => 'T32CLOSEVDD',
    515 => 'T32CREATETHREAD',
    516 => 'T32DYNAMICTRACE',
    517 => 'T32DEBUG',
    518 => 'T32QUERYPROCADDR',
    519 => 'T32CREATEEVENTSEM',
    520 => 'T32OPENEVENTSEM',
    521 => 'T32CLOSEEVENTSEM',
    522 => 'T32RESETEVENTSEM',
    523 => 'T32POSTEVENTSEM',
    524 => 'T32WAITEVENTSEM',
    525 => 'T32QUERYEVENTSEM',
    526 => 'T32CREATEMUTEXSEM',
    527 => 'T32OPENMUTEXSEM',
    528 => 'T32CLOSEMUTEXSEM',
    529 => 'T32REQUESTMUTEXSEM',
    530 => 'T32RELEASEMUTEXSEM',
    531 => 'T32QUERYMUTEXSEM',
    532 => 'T32CREATEMUXWAITSEM',
    533 => 'T32OPENMUXWAITSEM',
    534 => 'T32CLOSEMUXWAITSEM',
    535 => 'T32WAITMUXWAITSEM',
    536 => 'T32ADDMUXWAITSEM',
    537 => 'T32DELETEMUXWAITSEM',
    538 => 'T32QUERYMUXWAITSEM',
    539 => 'T32QUERYSYSINFO',
    540 => 'T32WAITTHREAD',
    541 => 'DosIOpenL',
    541 => 'T32GETRESOURCE',
    542 => 'DosIProtectOpenL',
    542 => 'T32FREERESOURCE',
    543 => 'DosISetFileSizeL',
    543 => 'T32EXCEPTIONCALLBACK',
    544 => 'DosIProtectSetFileSizeL',
    544 => 'T32QUERYPAGEUSAGE',
    545 => 'Dos32ExceptionCallBack',
    546 => 'TI32ASYNCTIMER',
    546 => 'THK32STRLEN',
    547 => 'TI32STARTTIMER',
    547 => 'THK_UNITHUNK',
    548 => 'Dos32R3ExceptionDispatcher',
    549 => 'DosLibiDisp',
    550 => 'DosLibiDisp16',
    551 => 'DosLibiDisp32',
    552 => 'DosR3ExitAddr',
    553 => 'Dos32R3ExitAddr',
    554 => 'Dos32IRead',
    555 => 'T32IREAD',
    556 => 'Dos32IWrite',
    557 => 'Dos32CreateSpinLock',
    557 => 'T32IWRITE',
    558 => 'Dos32AcquireSpinLock',
    558 => 'T32TMRQUERYFREQ',
    559 => 'Dos32ReleaseSpinLock',
    559 => 'T32TMRQUERYTIME',
    560 => 'Dos32FreeSpinLock',
    560 => 'T32ALIASPERFCTRS',
    561 => 'Dos32PMR3WaitEventSem',
    561 => 'T32CONFIGUREPERF',
    562 => 'Dos32PMR3PostEventSem',
    562 => 'T32DECONPERF',
    563 => 'Dos32QueryThreadAffinity',
    563 => 'T32REGISTERPERFCTRS',
    564 => 'Dos32SetThreadAffinity',
    564 => 'T32QUERYSYSSTATE',
    565 => 'DosISetFileInfo',
    566 => 'DosISetPathInfo',
    567 => 'DosOpenL',
    567 => 'T32QUERYDOSPROPERTY',
    568 => 'DosSetFilePtrL',
    568 => 'T32SETDOSPROPERTY',
    569 => 'DosIFindNext',
    570 => 'DosSetFileSizeL',
    570 => 'T32PROFILE',
    571 => 'T32QUERYRESOURCESIZE',
    572 => 'Dos32QueryResourceSize',
    573 => 'DosQueryResourceSize',
    574 => 'T32SETSIGNALEXCEPTIONFOCUS',
    574 => 'DosPMSemWait',
    575 => 'T32SENDSIGNALEXCEPTION',
    575 => 'DosPMMuxSemWait',
    576 => 'T32STARTTIMER',
    576 => 'THK16_UNITHUNK',
    577 => 'T32STOPTIMER',
    577 => 'HT16_STARTUP',
    578 => 'T32ASYNCTIMER',
    578 => 'HT16_CLEANUP',
    579 => 'T32INITIALIZEPORTHOLE',
    579 => 'HT32_STARTUP',
    580 => 'Dos32InitializePorthole',
    581 => 'T32QUERYHEADERINFO',
    581 => 'HT32_CLEANUP',
    582 => 'Dos32QueryHeaderInfo',
    583 => 'DosInitializePorthole',
    584 => 'DosQueryHeaderInfo',
    585 => 'T32QUERYPROCTYPE',
    585 => '_Dos32IMonRead',
    586 => 'Dos32QueryProcType',
    587 => 'DosQueryProcType',
    588 => 'T32IEXITMUSTCOMPLETE',
    588 => '_Dos32IMonWrite',
    589 => 'DosISigDispatch',
    590 => 'T32ICACHEMODULE',
    590 => 'Dos32PMPostEventSem',
    591 => 'T32DLLTERM',
    591 => 'Dos32PMWaitEventSem',
    592 => 'Dos32DllTermDisp',
    593 => 'T32IRAISEEXCEPTION',
    593 => 'Dos32PMRequestMutexSem',
    594 => 'Dos32IRaiseException',
    595 => 'T32ACKNOWLEDGESIGNALEXC',
    595 => 'Dos32PMWaitMuxWaitSem',
    596 => 'Dos32PM16SemChk',
    597 => 'Dos32IQueryFHState',
    598 => 'Dos32ISetFHState',
    599 => 'Dos32LDTSel',
    600 => 'Dos32R3Frestor',
    601 => 'DosIFindFirst',
    602 => 'T32SETFILELOCKS',
    603 => 'T32CANCELLOCKREQUEST',
    604 => 'T32IMONREAD',
    605 => 'T32IMONWRITE',
    606 => 'DosMonOpen',
    607 => 'DosMonClose',
    608 => 'DosMonRead',
    609 => 'DosMonWrite',
    610 => 'DosMonReg',
    611 => 'T32KILLTHREAD',
    612 => 'TQUERYRASINFO',
    615 => 'Dos32IProtectWrite',
    617 => 'DosIProtectSetFileInfo',
    618 => 'Dos32IProtectSetFileInfo',
    619 => 'Dos32IProtectSetFHState',
    620 => 'Dos32IProtectQueryFHState',
    621 => 'Dos32ProtectSetFilePtr',
    622 => 'Dos16ProtectClose',
    623 => 'Dos16ProtectFileIO',
    624 => 'Dos16ProtectFileLocks',
    625 => 'DosIProtectRead',
    626 => 'DosIProtectWrite',
    627 => 'Dos16ProtectNewSize',
    628 => 'Dos16ProtectOpen',
    629 => 'Dos16ProtectQFHandState',
    630 => 'Dos16ProtectSetFHandState',
    631 => 'Dos16ProtectQFileInfo',
    632 => 'Dos16ProtectSetFileInfo',
    634 => 'Dos16ProtectChgFilePtr',
    635 => 'Dos16ProtectEnumAttribute',
    636 => 'Dos32ProtectEnumAttribute',
    637 => 'Dos32ProtectOpen',
    638 => 'Dos32ProtectClose',
    639 => 'Dos32ProtectSetFileLocks',
    640 => 'Dos32ProtectSetFileSize',
    641 => 'Dos32ProtectRead',
    642 => 'Dos32ProtectWrite',
    643 => 'Dos32ProtectSetFileInfo',
    644 => 'Dos32ProtectSetFHState',
    645 => 'Dos32ProtectQueryFHState',
    646 => 'Dos32ProtectQueryFileInfo',
    647 => 'Dos32IProtectRead',
    649 => 'DosCloseMessageFile',
    650 => 'DosLDRDirtyWorker',
    651 => 'Dos16LDRDirtyWorker',
    652 => 'Dos32IGetInfoBlocks',
    653 => 'T32IGETINFOBLOCKS',
    656 => 'T32GETPROCESSORSTATUS',
    657 => 'T32SETPROCESSORSTATUS',
    658 => 'T32TESTPSD',
    659 => 'T32QUERYTHREADAFFINITY',
    660 => 'T32SETTHREADAFFINITY',
    661 => 'Dos32ReadQueue',
    662 => 'Dos32PurgeQueue',
    663 => 'Dos32CloseQueue',
    664 => 'Dos32QueryQueue',
    665 => 'Dos32PeekQueue',
    666 => 'Dos32WriteQueue',
    667 => 'Dos32OpenQueue',
    668 => 'Dos32CreateQueue',
    669 => 'Dos32StartSession',
    670 => 'Dos32SelectSession',
    671 => 'Dos32SetSession',
    672 => 'Dos32StopSession',
    673 => 'DosRegisterNotification',
    674 => 'Dos16ReadQueue',
    675 => 'Dos16PurgeQueue',
    676 => 'Dos16CloseQueue',
    677 => 'Dos16QueryQueue',
    678 => 'Dos16PeekQueue',
    679 => 'Dos16WriteQueue',
    680 => 'Dos16OpenQueue',
    681 => 'Dos16CreateQueue',
    682 => 'Dos16SMGetmem',
    683 => 'Dos16SMFreemem',
    684 => 'Dos16SMGetSGCB',
    685 => 'Dos16SMInitSGCB',
    686 => 'Dos16SMSGDoPopup',
    687 => 'Dos16SMSwitch',
    688 => 'Dos16SMServeAppReq',
    689 => 'Dos16GetTimes',
    690 => 'Dos16SMSetTitle',
    691 => 'Dos16ScrUnlock',
    692 => 'Dos16SMDoAppReq',
    693 => 'Dos16StopSession',
    694 => 'Dos16SelectSession',
    695 => 'Dos16ScrLock',
    696 => 'Dos16SavRedrawWait',
    697 => 'Dos16SavRedrawUndo',
    698 => 'Dos16SMSGEndPopup',
    699 => 'Dos16SetSession',
    700 => 'Dos16SetMNLockTime',
    701 => 'Dos16ModeUndo',
    702 => 'Dos16StartSession',
    703 => 'Dos16SMGetStatus',
    704 => 'Dos16ModeWait',
    705 => 'Dos16SMTerminate',
    706 => 'Dos16SMGetAppReq',
    707 => 'Dos16SMInitialize',
    708 => 'Dos16SMStart',
    709 => 'Dos16SMParentSwitch',
    710 => 'Dos16SMPause',
    711 => 'Dos16SMHDeinit',
    712 => 'Dos16SMPMPresent',
    713 => 'Dos16SMRegisterDD',
    714 => 'Dos16SMNotifyDD',
    715 => 'Dos16SMNotifyDD2',
    716 => 'Dos16SMOpenDD',
    717 => 'Dos16SMSetSessionType',
    718 => 'OS2BaseInit',
    719 => 'MouGetPtrShape',
    720 => 'MouSetPtrShape',
    721 => 'MouGetNumMickeys',
    722 => 'MouGetThreshold',
    723 => 'MouShellInit',
    724 => 'MouGetScaleFact',
    725 => 'MouFlushQue',
    726 => 'MouGetNumButtons',
    727 => 'MouClose',
    728 => 'MouSetThreshold',
    729 => 'MouSetScaleFact',
    730 => 'MouGetNumQueEl',
    731 => 'MouDeRegister',
    732 => 'MouGetEventMask',
    733 => 'MouSetEventMask',
    734 => 'MouOpen',
    735 => 'MouRemovePtr',
    736 => 'MouGetPtrPos',
    737 => 'MouReadEventQue',
    738 => 'MouSetPtrPos',
    739 => 'MouGetDevStatus',
    740 => 'MouSynch',
    741 => 'MouRegister',
    742 => 'MouSetDevStatus',
    743 => 'MouDrawPtr',
    744 => 'MouInitReal',
    745 => 'KbdSetCustXt',
    746 => 'KbdInit',
    747 => 'KbdGetCp',
    748 => 'KbdCharIn',
    749 => 'KbdSetCp',
    750 => 'KbdLoadInstance',
    751 => 'KbdSynch',
    752 => 'KbdRegister',
    753 => 'KbdStringIn',
    754 => 'KbdGetStatus',
    755 => 'KbdSetStatus',
    756 => 'KbdGetFocus',
    757 => 'KbdFlushBuffer',
    758 => 'KbdXlate',
    759 => 'KbdSwitchFgnd',
    760 => 'KbdShellInit',
    761 => 'KbdClose',
    762 => 'KbdFreeFocus',
    763 => 'KbdFree',
    764 => 'KbdDeRegister',
    765 => 'KbdSetFgnd',
    766 => 'KbdPeek',
    767 => 'KbdOpen',
    768 => 'KbdGetHWId',
    769 => 'KbdSetHWId',
    770 => 'VioEndPopup',
    771 => 'VioGetPhysBuf',
    772 => 'VioGetAnsi',
    773 => 'VioFree',
    774 => 'VioSetAnsi',
    775 => 'VioDeRegister',
    776 => 'VioScrollUp',
    777 => 'VioPrtSc',
    778 => 'VioGetCurPos',
    779 => 'VioWrtCellStr',
    780 => 'VioPopUp',
    781 => 'VioScrollRt',
    782 => 'VioWrtCharStr',
    783 => 'Avs_Prtsc',
    784 => 'VioSetCurPos',
    785 => 'VioSrfUnblock',
    786 => 'VioSrfBlock',
    787 => 'VioScrUnlock',
    788 => 'VioWrtTty',
    789 => 'VioSave',
    790 => 'VioGetMode',
    791 => 'VioSetMode',
    792 => 'VioScrLock',
    793 => 'VioReadCellStr',
    794 => 'VioSavRedrawWait',
    795 => 'VioWrtNAttr',
    796 => 'VioGetCurType',
    797 => 'VioSavRedrawUndo',
    798 => 'VioGetFont',
    799 => 'VioReadCharStr',
    800 => 'VioGetBuf',
    801 => 'VioSetCurType',
    802 => 'VioSetFont',
    803 => 'VioHetInit',
    804 => 'VioModeUndo',
    805 => 'VioSswSwitch',
    806 => 'VioModeWait',
    807 => 'Avs_PrtscToggle',
    808 => 'VioGetCp',
    809 => 'VioRestore',
    810 => 'VioSetCp',
    811 => 'VioShowBuf',
    812 => 'VioScrollLf',
    813 => 'VioRegister',
    814 => 'VioGetConfig',
    815 => 'VioScrollDn',
    816 => 'VioWrtCharStrAtt',
    817 => 'VioGetState',
    818 => 'VioPrtScToggle',
    819 => 'VioSetState',
    820 => 'VioWrtNCell',
    821 => 'VioWrtNChar',
    822 => 'VioShellInit',
    823 => 'VioAssociate',
    824 => 'VioCreatePS',
    825 => 'VioDeleteSetId',
    826 => 'VioGetDeviceCellSize',
    827 => 'VioGetOrg',
    828 => 'VioCreateLogFont',
    829 => 'VioDestroyPS',
    830 => 'VioQuerySetIds',
    831 => 'VioSetOrg',
    832 => 'VioQueryFonts',
    833 => 'VioSetDeviceCellSize',
    834 => 'VioShowPS',
    835 => 'VioGetPSAddress',
    836 => 'VioQueryConsole',
    837 => 'VioRedrawSize',
    838 => 'VioGlobalReg',
    839 => 'XVioSetCAState',
    840 => 'XVioCheckCharType',
    841 => 'XVioDestroyCA',
    842 => 'XVioCreateCA',
    843 => 'VioCheckCharType',
    844 => 'XVioGetCAState',
    845 => 'BVSMAIN',
    846 => 'BVSREDRAWSIZE',
    847 => 'BVSGETPTRDRAWNAME',
    848 => 'AnsiInject',
    849 => 'AnsiKeydef',
    850 => 'AnsiInterp',
    851 => 'BKSMAIN',
    852 => 'BMSMAIN',
    853 => 'MouGetHotKey',
    854 => 'MouSetHotKey',
    855 => 'Dos16SMSysInit',
    856 => 'QhKeybdHandle',
    857 => 'QhMouseHandle',
    858 => 'SMQueueRamSem',
    859 => 'SMArray',
    860 => 'SMPIDArray',
    861 => 'SMInitialized',
    862 => 'SMArraySize',
    863 => 'BVSGLOBAL',
    864 => 'SMGINSTANCE',
    865 => 'BVHINSTANCE',
    866 => 'THK32ALIASMEM',
    867 => 'THK32FREEALIAS',
    868 => 'THK32ALLOCVARLEN',
    869 => 'THK32HANDLEBOUNDARY',
    870 => 'THK32HANDLESTRING',
    871 => 'THK32DEALLOC',
    872 => 'THK32XHNDLR',
    873 => 'Dos32SetExtLIBPATH',
    874 => 'Dos32QueryExtLIBPATH',
    875 => 'Dos32PM16SemRst',
    876 => 'Dos32SysCtl',
    877 => 'Dos32QueryThreadContext',
    878 => 'DosSGQueryTopmost',
    976 => 'Dos32PerfSysCall',
    981 => 'Dos32OpenL',
    982 => 'Dos32ProtectOpenL',
    983 => 'Dos32ProtectSetFileLocksL',
    984 => 'Dos32ProtectSetFilePtrL',
    985 => 'Dos32ProtectSetFileSizeL',
    986 => 'Dos32SetFileLocksL',
    987 => 'Dos32CancelLockRequestL',
    988 => 'Dos32SetFilePtrL',
    989 => 'Dos32SetFileSizeL',
    990 => 'Dos32ListIOL',
    991 => 'Dos16FSRamSemRequest2',
    992 => 'Dos16FSRamSemClear2',
    995 => 'Dos32SystemService',
    996 => 'Dos32ListIO',
    997 => 'Dos32CreateThread2',
    998 => 'Dos16SetExtLIBPATH',
    999 => 'Dos16QueryExtLIBPATH',
    1000 => 'T32EXITLIST',
    1001 => 'T32ALLOCPROTECTEDMEM',
    1002 => 'T32ALIASMEM',
    1003 => 'T32ALLOCMEM',
    1004 => 'T32ALLOCSHAREDMEM',
    1005 => 'T32GETNAMEDSHAREDMEM',
    1006 => 'T32GETSHAREDMEM',
    1007 => 'T32GIVESHAREDMEM',
    1008 => 'T32FREEMEM',
    1009 => 'T32SETMEM',
    1010 => 'T32QUERYMEM',
    1011 => 'T32QUERYMEMSTATE',
    1012 => 'T32OPENVDD',
    1013 => 'T32REQUESTVDD',
    1014 => 'T32CLOSEVDD',
    1015 => 'T32CREATETHREAD',
    1016 => 'T32DYNAMICTRACE',
    1017 => 'T32DEBUG',
    1018 => 'T32QUERYPROCADDR',
    1019 => 'T32CREATEEVENTSEM',
    1020 => 'T32OPENEVENTSEM',
    1021 => 'T32CLOSEEVENTSEM',
    1022 => 'T32RESETEVENTSEM',
    1023 => 'T32POSTEVENTSEM',
    1024 => 'T32WAITEVENTSEM',
    1025 => 'T32QUERYEVENTSEM',
    1026 => 'T32CREATEMUTEXSEM',
    1027 => 'T32OPENMUTEXSEM',
    1028 => 'T32CLOSEMUTEXSEM',
    1029 => 'T32REQUESTMUTEXSEM',
    1030 => 'T32RELEASEMUTEXSEM',
    1031 => 'T32QUERYMUTEXSEM',
    1032 => 'T32CREATEMUXWAITSEM',
    1033 => 'T32OPENMUXWAITSEM',
    1034 => 'T32CLOSEMUXWAITSEM',
    1035 => 'T32WAITMUXWAITSEM',
    1036 => 'T32ADDMUXWAITSEM',
    1037 => 'T32DELETEMUXWAITSEM',
    1038 => 'T32QUERYMUXWAITSEM',
    1039 => 'T32QUERYSYSINFO',
    1040 => 'T32WAITTHREAD',
    1041 => 'T32GETRESOURCE',
    1042 => 'T32FREERESOURCE',
    1043 => 'T32EXCEPTIONCALLBACK',
    1044 => 'T32QUERYPAGEUSAGE',
    1045 => 'T32FORCESYSTEMDUMP',
    1046 => 'TI32ASYNCTIMER',
    1047 => 'TI32STARTTIMER',
    1048 => 'T32QUERYABIOSSUPPORT',
    1049 => 'T32QUERYMODFROMEIP',
    1050 => 'T32ALIASPERFCTRS',
    1051 => 'T32CONFIGUREPERF',
    1052 => 'T32DECONPERF',
    1053 => 'T32REGISTERPERFCTRS',
    1054 => 'T32QUERYSYSSTATE',
    1055 => 'T32IREAD',
    1056 => 'T32IWRITE',
    1057 => 'T32TMRQUERYFREQ',
    1058 => 'T32TMRQUERYTIME',
    1059 => 'T32IMONREAD',
    1060 => 'T32IMONWRITE',
    1061 => 'T32QUERYRESOURCESIZE',
    1062 => 'T32PROFILE',
    1063 => 'T32SETSIGNALEXCEPTIONFOCUS',
    1064 => 'T32SENDSIGNALEXCEPTION',
    1065 => 'T32STARTTIMER',
    1066 => 'T32STOPTIMER',
    1067 => 'T32ASYNCTIMER',
    1068 => 'T32INITIALIZEPORTHOLE',
    1069 => 'T32QUERYHEADERINFO',
    1070 => 'T32QUERYPROCTYPE',
    1071 => 'T32IEXITMUSTCOMPLETE',
    1072 => 'T32ICACHEMODULE',
    1073 => 'T32DLLTERM',
    1074 => 'T32IRAISEEXCEPTION',
    1075 => 'T32ACKNOWLEDGESIGNALEXCEPTION',
    1076 => 'T32QUERYDOSPROPERTY',
    1077 => 'T32SETDOSPROPERTY',
    1078 => 'T32SETFILELOCKS',
    1079 => 'T32CANCELLOCKREQUEST',
    1080 => 'T32KILLTHREAD',
    1081 => 'TQUERYRASINFO',
    1082 => 'T32DUMPPROCESS',
    1083 => 'T32SUPPRESSPOPUPS',
    1084 => 'T32IPROTECTWRITE',
    1085 => 'T32PROTECTSETFILELOCKS',
    1086 => 'T32IPROTECTREAD',
    1087 => 'T32PMPOSTEVENTSEM',
    1088 => 'T32PMWAITEVENTSEM',
    1089 => 'T32PMREQUESTMUTEXSEM',
    1090 => 'T32PMWAITMUXWAITSEM',
    1091 => 'T32PM16SEMCHK',
    1092 => 'T32ALLOCTHREADLOCALMEMORY',
    1093 => 'T32FREETHREADLOCALMEMORY',
    1094 => 'T32SETEXTLIBPATH',
    1095 => 'T32QUERYEXTLIBPATH',
    1096 => 'T32PM16SEMRST',
    1097 => 'T32VERIFYPIDTID',
    1098 => 'T32SYSCTL',
    1099 => 'T32QUERYTHREADCONTEXT',
    1101 => 'T32PERFSYSCALL',
    1102 => 'T32LISTIO',
    1103 => 'T32PMR3WAITEVENTSEM',
    1104 => 'T32PMR3POSTEVENTSEM',
    1105 => 'T32CREATETHREAD2',
    1106 => 'T32PROTECTSETFILELOCKSL',
    1107 => 'T32IPROTECTSETFILEPTRL',
    1108 => 'T32SETFILELOCKSL',
    1109 => 'T32CANCELLOCKREQUESTL',
    1110 => 'T32ISETFILEPTRL',
    1111 => 'T32LISTIOL',
    1116 => 'T32ISETFILEPTR',
    1117 => 'T32IPROTECTSETFILEPTR',
    9004 => 'Dos32CreateRamSem',
    9005 => 'Dos32CloseRamSem',
    9006 => 'Dos32OpenRamSem',
    9007 => 'Dos32RequestRamSem',
    9008 => 'Dos32ReleaseRamSem',
    9010 => 'Dos32QueryProcessInfo',
    9011 => 'Dos32QueryThreadInfo',
    9018 => 'Dos32FindFromName',
  },

  'VIOCALLS' => {
    1 => 'VioEndPopup',
    2 => 'VioGetPhysBuf',
    3 => 'VioGetAnsi',
    4 => 'VioFree',
    5 => 'VioSetAnsi',
    6 => 'VioDeRegister',
    7 => 'VioScrollUp',
    8 => 'VioPrtSc',
    9 => 'VioGetCurPos',
    10 => 'VioWrtCellStr',
    11 => 'VioPopUp',
    12 => 'VioScrollRt',
    13 => 'VioWrtCharStr',
    14 => 'Avs_Prtsc',
    15 => 'VioSetCurPos',
    16 => 'VioSrfUnblock',
    17 => 'VioSrfBlock',
    18 => 'VioScrUnlock',
    19 => 'VioWrtTty',
    20 => 'VioSave',
    21 => 'VioGetMode',
    22 => 'VioSetMode',
    23 => 'VioScrLock',
    24 => 'VioReadCellStr',
    25 => 'VioSavRedrawWait',
    26 => 'VioWrtNAttr',
    27 => 'VioGetCurType',
    28 => 'VioSavRedrawUndo',
    29 => 'VioGetFont',
    30 => 'VioReadCharStr',
    31 => 'VioGetBuf',
    32 => 'VioSetCurType',
    33 => 'VioSetFont',
    34 => 'VioHetInit',
    35 => 'VioModeUndo',
    36 => 'VioSswSwitch',
    37 => 'VioModeWait',
    38 => 'Avs_PrtscToggle',
    39 => 'VioInit',
    40 => 'VioGetCp',
    41 => 'VioRestore',
    42 => 'VioSetCp',
    43 => 'VioShowBuf',
    44 => 'VioScrollLf',
    45 => 'VioRegister',
    46 => 'VioGetConfig',
    47 => 'VioScrollDn',
    48 => 'VioWrtCharStrAtt',
    49 => 'VioGetState',
    50 => 'VioPrtScToggle',
    51 => 'VioSetState',
    52 => 'VioWrtNCell',
    53 => 'VioWrtNChar',
    54 => 'VioShellInit',
    55 => 'VioAssociate',
    56 => 'VioCreatePS',
    57 => 'VioDeleteSetId',
    58 => 'VioGetDeviceCellSize',
    59 => 'VioGetOrg',
    60 => 'VioCreateLogFont',
    61 => 'VioDestroyPS',
    62 => 'VioQuerySetIds',
    63 => 'VioSetOrg',
    64 => 'VioQueryFonts',
    65 => 'VioSetDeviceCellSize',
    66 => 'VioShowPS',
    67 => 'VioGetPSAddress',
    68 => 'VioQueryConsole',
    69 => 'VioRedrawSize',
    70 => 'VioGlobalReg',
    71 => 'XVioSetCAState',
    72 => 'XVioCheckCharType',
    73 => 'XVioDestroyCA',
    74 => 'XVioCreateCA',
    75 => 'VioCheckCharType',
    76 => 'XVioGetCAState',
  },

  'KBDCALLS' => {
    1 => 'KbdSetCustXt',
    2 => 'KbdInit',
    3 => 'KbdGetCp',
    4 => 'KbdCharIn',
    5 => 'KbdSetCp',
    6 => 'KbdLoadInstance',
    7 => 'KbdSynch',
    8 => 'KbdRegister',
    9 => 'KbdStringIn',
    10 => 'KbdGetStatus',
    11 => 'KbdSetStatus',
    12 => 'KbdGetFocus',
    13 => 'KbdFlushBuffer',
    14 => 'KbdXlate',
    15 => 'KbdSwitchFgnd',
    16 => 'KbdShellInit',
    17 => 'KbdClose',
    18 => 'KbdFreeFocus',
    19 => 'KbdFree',
    20 => 'KbdDeRegister',
    21 => 'KbdSetFgnd',
    22 => 'KbdPeek',
    23 => 'KbdOpen',
    24 => 'KbdGetHWId',
    25 => 'KbdSetHWId',
  },

  'NLS' => {
    1 => 'DosCaseMap',
    2 => 'DosGetCollate',
    3 => 'DosGetCtryInfo',
    4 => 'DosGetDBCSEv',
    5 => 'Dos32QueryCtryInfo',
    6 => 'Dos32QueryDBCSEnv',
    7 => 'Dos32MapCase',
    8 => 'Dos32QueryCollate',
  },

  'MSG' => {
    1 => 'DosPutMessage',
    2 => 'DosTrueGetMessage',
    3 => 'DosInsMessage',
    4 => 'Dos32InsertMessage',
    5 => 'Dos32PutMessage',
    6 => 'Dos32TrueGetMessage',
    7 => 'DosIQueryMessageCP',
    8 => 'Dos32IQueryMessageCP',
    9 => 'DosCloseMessageFile',
  },

  'QUECALLS' => {
    1 => 'DosReadQueue',
    2 => 'DosPurgeQueue',
    3 => 'DosCloseQueue',
    4 => 'DosQueryQueue',
    5 => 'DosPeekQueue',
    6 => 'DosWriteQueue',
    7 => 'DosOpenQueue',
    8 => 'DosCreateQueue',
    9 => 'Dos32ReadQueue',
    10 => 'Dos32PurgeQueue',
    11 => 'Dos32CloseQueue',
    12 => 'Dos32QueryQueue',
    13 => 'Dos32PeekQueue',
    14 => 'Dos32WriteQueue',
    15 => 'Dos32OpenQueue',
    16 => 'Dos32CreateQueue',
  },

  'SESMGR' => {
    1 => 'DosSMSGDoPopup',
    2 => 'DosSMSwitch',
    3 => 'DosSMServeAppReq',
    4 => 'DosGetTimes',
    5 => 'DosSMSetTitle',
    6 => 'DosScrUnlock',
    7 => 'DosSMDoAppReq',
    8 => 'DosStopSession',
    9 => 'DosSelectSession',
    10 => 'DosScrLock',
    11 => 'DosSavRedrawWait',
    12 => 'DosSavRedrawUndo',
    13 => 'DosSMSGEndPopup',
    14 => 'DosSetSession',
    15 => 'DosSetMNLockTime',
    16 => 'DosModeUndo',
    17 => 'DosStartSession',
    18 => 'DosSMGetStatus',
    19 => 'DosModeWait',
    20 => 'DosSMTerminate',
    21 => 'DosSMGetAppReq',
    22 => 'DosSMRealPrtSc',
    23 => 'DosSMInitialize',
    24 => 'DosSMStart',
    25 => 'DosSMParentSwitch',
    26 => 'DosSMPause',
    27 => 'DosSMHDEInit',
    28 => 'DosSMPMPresent',
    29 => 'DosSMRegisterDD',
    30 => 'DosSMSysInit',
    31 => 'DosSMNotifyDD',
    32 => 'DosSMNotifyDD2',
    33 => 'DosSMOpenDD',
    34 => 'QhKeybdHandle',
    35 => 'QhMouseHandle',
    36 => 'DosSMSetSessionType',
    37 => 'Dos32StartSession',
    38 => 'Dos32SelectSession',
    39 => 'Dos32SetSession',
    40 => 'Dos32StopSession',
    41 => 'DosRegisterNotification',
  },

  'PMSHAPI' => {
    1 => 'ShePIInitialise',
    2 => 'WinQueryProfileInt',
    3 => 'WinQueryProfileString',
    4 => 'WinWriteProfileString',
    5 => 'WinQueryProfileSize',
    6 => 'WinQueryProfileData',
    7 => 'WinWriteProfileData',
    8 => 'WinInitSessionMgr',
    9 => 'WinSetFgndWindow',
    10 => 'ShlUnloadPublicFonts',
    11 => 'WinStpRegister',
    12 => 'WinAddProgram',
    13 => 'WinRemoveProgram',
    14 => 'WinChangeProgram',
    15 => 'WinQueryDefinition',
    16 => 'WinQueryProgramTitles',
    17 => 'WinCreateGroup',
    18 => 'WinInitializePL',
    19 => 'WinAddToGroup',
    20 => 'WinQueryProgramUse',
    21 => 'WinRemoveFromGroup',
    22 => 'StartStartUpDotCmd',
    23 => 'WinDestroyGroup',
    24 => 'WinQueryFileExtOpts',
    25 => 'WinSetFileExtOpts',
    26 => 'WinQueryProgramType',
    27 => 'PrfChangeWriteThru',
    28 => 'PMExecRegister',
    29 => 'ShePIInitIniFiles',
    30 => 'SheUpdateIniFile',
    31 => 'SheConvert190ProgramListTo300',
    32 => 'PrfQueryProfileInt',
    33 => 'PrfQueryProfileString',
    34 => 'PrfWriteProfileString',
    35 => 'PrfQueryProfileSize',
    36 => 'PrfQueryProfileData',
    37 => 'PrfWriteProfileData',
    38 => 'PrfOpenProfile',
    39 => 'PrfCloseProfile',
    42 => 'PrfReset',
    43 => 'PrfQueryProfile',
    44 => 'WinInstStartApp',
    45 => 'WinTerminateApp',
    46 => 'WinCreateSwitchEntry',
    47 => 'WinQuerySessionTitle',
    48 => 'WinAddSwitchEntry',
    49 => 'WinChangeSwitchEntry',
    50 => 'PrfAddProgram',
    51 => 'PrfRemoveProgram',
    52 => 'PrfChangeProgram',
    53 => 'PrfQueryDefinition',
    54 => 'PrfQueryProgramTitles',
    55 => 'PrfCreateGroup',
    56 => 'WinQuerySwitchEntry',
    57 => 'WinQuerySwitchHandle',
    58 => 'PrfQueryProgramHandle',
    59 => 'PrfQueryProgramCategory',
    60 => 'PrfDestroyGroup',
    61 => 'SheSetProfileHook',
    62 => 'SheProfileHook',
    63 => 'ShpLockProgramList',
    64 => 'ShpUnlockProgramList',
    65 => 'WinQueryTaskTitle',
    66 => 'WinQueryTaskSizePos',
    67 => 'WinQuerySwitchList',
    68 => 'WinRemoveSwitchEntry',
    69 => 'WinSwitchToProgram',
    70 => 'WinSwitchProgramRegister',
    73 => 'WinEndProgram',
    74 => 'WinStopProgram',
    75 => 'WinEndWindowSession',
    76 => 'lpfnShellWndProc',
    77 => 'lpfnIconWndProc',
    78 => 'WinSwitchToTaskManager',
    79 => 'fnBadAppDlgProc',
    80 => 'WinSwitchToProgram2',
    81 => 'WinProcessHotKey',
    82 => 'WinInitSession',
    83 => 'WinEndSession',
    84 => 'WinInitSwEntry',
    85 => 'WinSetSwEntry',
    86 => 'WinQueryExtIDFocus',
    87 => 'WinSetExtIDFocus',
    88 => 'SheSystemShutdown',
    89 => 'StartSystemExecutables',
    90 => 'ShlLoadPublicFonts',
    91 => 'WinNoShutdown',
    92 => 'SheInitializeIniFile',
    93 => 'WinSetTitle',
    94 => 'WinCplRegister',
    95 => 'WinPMFileRegister',
    96 => 'SheStartLongProgram',
    97 => 'WinSetTitleAndIcon',
    98 => 'Win32NoShutdown',
    99 => 'WinSetTitleAndHwndIcon',
    100 => 'ShellWindow',
    101 => 'Prf32QueryProfileSize',
    102 => 'Prf32OpenProfile',
    103 => 'Prf32CloseProfile',
    104 => 'Prf32RemoveProgram',
    105 => 'Prf32CreateGroup',
    106 => 'Prf32DestroyGroup',
    107 => 'Prf32QueryProfile',
    108 => 'Prf32Reset',
    109 => 'Prf32AddProgram',
    110 => 'Prf32ChangeProgram',
    111 => 'Prf32QueryDefinition',
    112 => 'Prf32QueryProgramHandle',
    113 => 'Prf32QueryProgramTitles',
    114 => 'Prf32QueryProfileInt',
    115 => 'Prf32QueryProfileString',
    116 => 'Prf32WriteProfileString',
    117 => 'Prf32QueryProfileData',
    118 => 'Prf32WriteProfileData',
    119 => 'Win32StartApp',
    120 => 'Win32AddSwitchEntry',
    121 => 'Win32CreateSwitchEntry',
    122 => 'Win32QuerySessionTitle',
    123 => 'Win32ChangeSwitchEntry',
    124 => 'Win32QuerySwitchEntry',
    125 => 'Win32QuerySwitchHandle',
    126 => 'Win32QuerySwitchList',
    127 => 'Win32QueryTaskSizePos',
    128 => 'Win32QueryTaskTitle',
    129 => 'Win32RemoveSwitchEntry',
    130 => 'Win32TerminateApp',
    131 => 'Win32SwitchToProgram',
    132 => 'Prf32QueryProgramCategory',
    133 => 'Prf32ChangeWriteThru',
    134 => 'She32PIInitIniFiles',
    135 => 'PrfWriteToDisk',
    136 => 'PrfSuspendWriteToDisk',
    151 => 'She32SystemShutdown',
    152 => 'Start32SystemExecutables',
    153 => 'PM32ExecRegister',
    154 => 'Win32HAPPfromPID',
    155 => 'Win32HSWITCHfromHAPP',
    156 => 'Win32SwitchProgramRegister',
    157 => 'Win32EndProgram',
    158 => 'Win32SwitchToProgram2',
    160 => 'WinCanTerminate',
    201 => 'WinStartApp',
    208 => 'WinHAPPfromPID',
    209 => 'WinHSWITCHfromHAPP',
    210 => 'ShpPILockIniFile',
    211 => 'ShpPI16LockIniFile',
    212 => 'ShpPIShutdown',
    213 => 'ShpPI16Shutdown',
  },

  'PMWIN' => {
    1 => 'WinQueryDesktopWindow',
    2 => 'WinQueryObjectWindow',
    3 => 'WinRegisterClass',
    4 => 'WinQueryClassName',
    5 => 'WinQueryClassInfo',
    6 => 'WinCreateWindow',
    7 => 'WinDestroyWindow',
    8 => 'WinSetWindowPos',
    9 => 'WinSetMultWindowPos',
    10 => 'WinQueryWindowPos',
    11 => 'WinEnableWindow',
    12 => 'WinIsWindowEnabled',
    13 => 'WinShowWindow',
    14 => 'WinEnableWindowUpdate',
    15 => 'WinIsWindowVisible',
    16 => 'WinSetWindowText',
    17 => 'WinQueryWindowText',
    18 => 'WinQueryWindowTextLength',
    19 => 'WinWindowFromID',
    20 => 'WinMultWindowFromIDs',
    21 => 'WinIsWindow',
    22 => 'WinIsChild',
    23 => 'WinSetParent',
    24 => 'WinSetOwner',
    25 => 'WinQueryWindow',
    26 => 'WinQueryWindowRect',
    27 => 'WinQueryWindowProcess',
    28 => 'WinSetWindowUShort',
    29 => 'WinQueryWindowUShort',
    30 => 'WinSetWindowULong',
    31 => 'WinQueryWindowULong',
    32 => 'WinBeginEnumWindows',
    33 => 'WinGetNextWindow',
    34 => 'WinEndEnumWindows',
    35 => 'WinWindowFromPoint',
    36 => 'WinMapWindowPoints',
    37 => 'WinSubclassWindow',
    38 => 'WinLockWindow',
    39 => 'WinQueryWindowLockCount',
    40 => 'WinRegisterWindowDestroy',
    41 => 'WinOpenWindowDC',
    42 => 'WinGetScreenPS',
    43 => 'WinGetPS',
    44 => 'WinReleasePS',
    45 => 'WinBeginPaint',
    46 => 'WinEndPaint',
    47 => 'WinInvalidateRect',
    48 => 'WinInvalidateRegion',
    49 => 'WinValidateRect',
    50 => 'WinValidateRegion',
    51 => 'WinQueryUpdateRect',
    52 => 'WinQueryUpdateRegion',
    53 => 'WinUpdateWindow',
    54 => 'WinExcludeUpdateRegion',
    55 => 'WinLockWindowUpdate',
    56 => 'WinLockVisRegions',
    57 => 'WinWindowFromDC',
    58 => 'WinCreateMsgQueue',
    59 => 'WinDestroyMsgQueue',
    60 => 'WinQueryQueueStatus',
    61 => 'WinSendMsg',
    63 => 'WinBroadcastMsg',
    64 => 'WinInSendMsg',
    65 => 'WinGetMsg',
    66 => 'WinPeekMsg',
    67 => 'WinWaitMsg',
    68 => 'WinDispatchMsg',
    69 => 'WinPostMsg',
    70 => 'WinPostQueueMsg',
    71 => 'WinQueryMsgPos',
    72 => 'WinQueryMsgTime',
    73 => 'WinCallMsgFilter',
    74 => 'WinSetMsgInterest',
    75 => 'WinSetCapture',
    76 => 'WinQueryCapture',
    77 => 'WinSetFocus',
    78 => 'WinQueryFocus',
    79 => 'WinSetActiveWindow',
    80 => 'WinQueryActiveWindow',
    81 => 'WinSetSysModalWindow',
    82 => 'WinQuerySysModalWindow',
    83 => 'WinIsThreadActive',
    84 => 'WinStartTimer',
    85 => 'WinStopTimer',
    86 => 'WinGetCurrentTime',
    87 => 'WinLoadPointer',
    88 => 'WinCreatePointer',
    89 => 'WinDestroyPointer',
    90 => 'OldWinQueryPointerInfo',
    91 => 'WinQuerySysPointer',
    92 => 'WinSetPointer',
    93 => 'WinQueryPointer',
    94 => 'WinShowPointer',
    95 => 'WinSetPointerPos',
    96 => 'WinQueryPointerPos',
    97 => 'WinGetSysBitmap',
    98 => 'WinCreateCursor',
    99 => 'WinDestroyCursor',
    100 => 'WinShowCursor',
    101 => 'WinQueryCursorInfo',
    102 => 'WinLoadAccelTable',
    103 => 'WinCreateAccelTable',
    104 => 'WinDestroyAccelTable',
    105 => 'WinTranslateAccel',
    106 => 'WinSetAccelTable',
    107 => 'WinQueryAccelTable',
    108 => 'WinCopyAccelTable',
    109 => 'WinSetHook',
    110 => 'WinReleaseHook',
    111 => 'WinOpenClipbrd',
    112 => 'WinCloseClipbrd',
    113 => 'WinEmptyClipbrd',
    114 => 'WinSetClipbrdOwner',
    115 => 'WinQueryClipbrdOwner',
    116 => 'WinSetClipbrdData',
    117 => 'WinQueryClipbrdData',
    118 => 'WinEnumClipbrdFmts',
    119 => 'WinQueryClipbrdFmtInfo',
    120 => 'WinSetClipbrdViewer',
    121 => 'WinQueryClipbrdViewer',
    122 => 'WinLoadDlg',
    123 => 'WinCreateDlg',
    124 => 'WinProcessDlg',
    125 => 'WinDlgBox',
    126 => 'WinDismissDlg',
    127 => 'WinSendDlgItemMsg',
    128 => 'WinSetDlgItemShort',
    129 => 'WinQueryDlgItemShort',
    130 => 'WinMapDlgPoints',
    132 => 'WinSubstituteStrings',
    133 => 'WinEnumDlgItem',
    134 => 'WinSetDlgItemText',
    135 => 'WinQueryDlgItemText',
    136 => 'WinLoadMenu',
    137 => 'WinCreateMenu',
    138 => 'WinAlarm',
    139 => 'WinMessageBox',
    140 => 'WinCreateStdWindow',
    141 => 'WinCreateFrameControls',
    142 => 'WinFormatFrame',
    143 => 'WinCalcFrameRect',
    144 => 'WinFlashWindow',
    146 => 'WinGetMinPosition',
    147 => 'WinGetMaxPosition',
    149 => 'WinQuerySysValue',
    150 => 'WinSetSysValue',
    151 => 'WinSetSysColors',
    152 => 'WinQuerySysColor',
    153 => 'WinScrollWindow',
    154 => 'WinTrackRect',
    155 => 'WinShowTrackRect',
    156 => 'GpiLoadBitmap',
    157 => 'WinLoadString',
    158 => 'WinLoadMessage',
    159 => 'WinSetRectEmpty',
    160 => 'WinSetRect',
    161 => 'WinCopyRect',
    162 => 'WinIsRectEmpty',
    163 => 'WinEqualRect',
    164 => 'WinPtInRect',
    165 => 'WinOffsetRect',
    166 => 'WinInflateRect',
    167 => 'WinIntersectRect',
    168 => 'WinUnionRect',
    169 => 'WinSubtractRect',
    170 => 'WinMakeRect',
    171 => 'WinMakePoints',
    172 => 'WinInvertRect',
    173 => 'WinFillRect',
    174 => 'KbdPacket',
    177 => 'WinDrawPointer',
    178 => 'WinDefWindowProc',
    179 => 'WinDefDlgProc',
    197 => 'WinSyncStartPgm',
    198 => 'WinScreenSwitch',
    199 => 'WinResetSystem',
    200 => 'WinQueryHungProcess',
    201 => 'WinLoadStringTable',
    202 => 'WinLoadVkeyGlyphXlatetbl',
    203 => 'WinLoadCharXlatetbl',
    204 => 'WinSetVkeyGlyphXlatetbl',
    205 => 'WinSetCharXlatetbl',
    206 => 'WinQueryVkeyGlyphXlatetbl',
    207 => 'WinQueryCharXlatetbl',
    208 => 'WinVkeyGlyphCharXlate',
    209 => 'WinVkeyToScanID',
    210 => 'WinQueryProcessCP',
    211 => 'WinGetKeyState',
    212 => 'WinGetPhysKeyState',
    213 => 'WinSetKeyboardStateTable',
    214 => 'WinEnablePhysInput',
    215 => 'WinSetCp',
    216 => 'WinQueryCp',
    217 => 'WinQueryCpList',
    218 => 'WinCpTranslateString',
    219 => 'WinCpTranslateChar',
    220 => 'WinCompareStrings',
    221 => 'WinUpper',
    222 => 'WinUpperChar',
    223 => 'WinNextChar',
    224 => 'WinPrevChar',
    225 => 'WinCreateHeap',
    226 => 'WinDestroyHeap',
    227 => 'WinAvailMem',
    228 => 'WinAllocMem',
    229 => 'WinReallocMem',
    230 => 'WinFreeMem',
    231 => 'WinLockHeap',
    233 => 'WinCreateAtomTable',
    234 => 'WinDestroyAtomTable',
    235 => 'WinAddAtom',
    236 => 'WinFindAtom',
    237 => 'WinDeleteAtom',
    238 => 'WinQueryAtomUsage',
    239 => 'WinQueryAtomLength',
    240 => 'WinQueryAtomName',
    241 => 'WinQuerySystemAtomTable',
    242 => 'WinSetLastError',
    243 => 'WinGetLastError',
    244 => 'WinGetErrorInfo',
    245 => 'WinFreeErrorInfo',
    246 => 'WinInitialize',
    247 => 'WinTerminate',
    248 => 'WinCatch',
    249 => 'WinThrow',
    250 => 'WinQueryVersion',
    251 => 'FsrSemEnter',
    252 => 'FsrSemLeave',
    253 => 'FsrSemExit',
    254 => 'FsrSemCheck',
    255 => 'AabAllocReg',
    255 => 'FsrSemEnterP',
    256 => 'AabGetReg',
    257 => 'AabSetReg',
    258 => 'ValidateSelector',
    259 => 'LoadModuleHandle',
    260 => 'GetScreenSelector',
    261 => 'IdentifyCodeSelector',
    262 => 'WinQueryWindowSGID',
    263 => '_WinSetErrorInfo',
    264 => 'WinIsPhysInputEnabled',
    265 => 'WinQueryWindowDC',
    266 => 'WinDrawBorder',
    267 => 'WinDrawText',
    268 => 'WinDrawBitmap',
    269 => 'WinQueryWindowPtr',
    270 => 'WinSetWindowPtr',
    271 => 'WinInitializeSystem',
    272 => 'WinTerminateSystem',
    273 => 'WinLockStartInput',
    274 => 'WinMsgSemWait',
    275 => 'WinMsgMuxSemWait',
    276 => 'WinSystemShutdown',
    277 => 'WinCancelShutdown',
    278 => 'WinSetWindowBits',
    279 => 'WinGetClipPS',
    281 => 'WinSendQueueMsg',
    282 => 'WinSetQueueProc',
    283 => 'WinDefQueueProc',
    285 => 'WinSaveWindowPos',
    286 => 'WinFocusChange',
    287 => 'WinQueryQueueInfo',
    288 => 'WinCallHelpHook',
    289 => 'WinSetAtomTableOwner',
    290 => 'WinIsShuttingDown',
    291 => 'WinTerminateShutdown',
    292 => 'WinSetClassMsgInterest',
    293 => 'VisRegionCallback',
    294 => 'WinQueryDlgItemTextLength',
    295 => 'WinQueryKbdLayout',
    296 => 'WinSetKbdLayout',
    297 => 'WinDdeInitiate',
    298 => 'WinDdeRespond',
    299 => 'WinDdePostMsg',
    300 => 'WinCancelMode',
    301 => 'WinSetPresParam',
    302 => 'WinQueryPresParam',
    303 => 'WinRemovePresParam',
    304 => 'WinThreadAssocQueue',
    305 => 'WinQueueFromID',
    306 => 'WinQuerySendMsg',
    307 => 'WinReplyMsg',
    308 => 'WinWakeThread',
    309 => 'WinLockInput',
    310 => 'WinBuildPtrHandle',
    311 => 'WinCreateHelpInstance',
    312 => 'WinDestroyHelpInstance',
    313 => 'WinAssociateHelpInstance',
    314 => 'WinCreateHelpTable',
    315 => 'WinLoadHelpTable',
    316 => 'WinQueryHelpInstance',
    317 => 'WinQueryWindowModel',
    318 => 'WinSetDesktopBkgnd',
    319 => 'WinQueryDesktopBkgnd',
    320 => 'WinPopupMenu',
    321 => 'WinRealizePalette',
    322 => 'DummyHelpEntry',
    325 => 'GetPMDDCodeSelector',
    326 => 'WinSemEnter',
    327 => 'WinSemLeave',
    328 => 'WinQueryPwnd',
    329 => 'WinQueryState',
    330 => 'WinLoadAniPointer',
    331 => 'WinDestroyAniPointer',
    332 => 'WinSetAniPointer',
    333 => 'WinEnumVKeyScanIDs',
    334 => 'WinSemQuery',
    400 => 'WinLoadTranslationTable',
    401 => 'WinSetKbdLayout2',
    495 => 'WinSeamlessBox',
    496 => 'WinIsWindowOverlapped',
    497 => 'WinJiggleMouse',
    498 => 'WinTrackSeamless',
    499 => 'WinRegisterSeamlessProc',
    500 => 'AbnormalProcessExit',
    508 => 'WinProfControl',
    509 => 'DebugInputEnable',
    510 => 'DebugInput',
    511 => 'DebugOutput',
    512 => 'DebugCurPos',
    513 => 'DebugCls',
    514 => 'WinDebugBreak',
    515 => 'DebugRedirect',
    590 => 'InputGetDeviceInfo',
    600 => 'StartTimer',
    601 => 'DestroyTimers',
    602 => 'WinDeleteLibrary',
    603 => 'WinLoadProcedure',
    604 => 'WinDeleteProcedure',
    605 => 'WinSetMsgMode',
    606 => 'WinSetSynchroMode',
    607 => 'WinGetDlgMsg',
    608 => 'WinRegisterUserMsg',
    609 => 'WinQueryAnchorBlock',
    610 => 'WinLangsupWindowProc',
    611 => 'WinLangsupDlgProc',
    612 => 'WinRegisterUserDatatype',
    613 => 'FarCallHook',
    614 => 'WinIsWindowShowing',
    615 => 'WinLoadLibrary',
    616 => 'WinCreatePointerIndirect',
    617 => 'WinQueryPointerInfo',
    618 => 'WinSetMenuData',
    619 => 'WinQueryMenuData',
    620 => 'WinMenuIndexFromID',
    621 => 'WinForceMenuRedraw',
    622 => 'WinGetScanState',
    623 => 'WinSetScanStateTable',
    624 => 'WinGetErasePS',
    625 => 'WinReleaseErasePS',
    626 => 'WinSetWindowDC',
    627 => 'WinTranslateChar',
    628 => 'WinPortHoleUtil',
    629 => 'WinExplodeWindow',
    630 => 'WinSetAccelTableValue',
    631 => 'WinQueryAccelTableValue',
    632 => 'WinStretchPointer',
    633 => 'WinSetPointerOwner',
    634 => 'WinGetFrameTreePPSize',
    635 => 'WinGetFrameTreePPs',
    636 => 'WinSetFrameTreePPs',
    637 => 'WinGetMinWindowViewer',
    638 => 'WinQueryWorkplaceWindow',
    639 => 'WinLockPointerUpdate',
    640 => 'WinCheckInput',
    641 => 'FarFlushBufHook',
    700 => 'Win32AddAtom',
    701 => 'Win32Alarm',
    702 => 'Win32BeginEnumWindows',
    703 => 'Win32BeginPaint',
    704 => 'Win32CalcFrameRect',
    705 => 'Win32CancelShutdown',
    707 => 'Win32CloseClipbrd',
    708 => 'Win32CompareStrings',
    709 => 'Win32CopyAccelTable',
    710 => 'Win32CopyRect',
    711 => 'Win32CpTranslateChar',
    712 => 'Win32CpTranslateString',
    713 => 'Win32CreateAccelTable',
    714 => 'Win32CreateAtomTable',
    715 => 'Win32CreateCursor',
    716 => 'Win32CreateMsgQueue',
    717 => 'Win32CreatePointer',
    718 => 'Win32DdeInitiate',
    719 => 'Win32DdePostMsg',
    720 => 'Win32DdeRespond',
    721 => 'Win32DeleteAtom',
    722 => 'Win32DeleteLibrary',
    723 => 'Win32DestroyAccelTable',
    724 => 'Win32DestroyAtomTable',
    725 => 'Win32DestroyCursor',
    726 => 'Win32DestroyMsgQueue',
    727 => 'Win32DestroyPointer',
    728 => 'Win32DestroyWindow',
    729 => 'Win32DismissDlg',
    730 => 'Win32DrawBitmap',
    731 => 'Win32DrawBorder',
    732 => 'Win32DrawPointer',
    733 => 'Win32EmptyClipbrd',
    734 => 'Win32EnablePhysInput',
    735 => 'Win32EnableWindow',
    736 => 'Win32EnableWindowUpdate',
    737 => 'Win32EndEnumWindows',
    738 => 'Win32EndPaint',
    739 => 'Win32EnumClipbrdFmts',
    740 => 'Win32EnumDlgItem',
    741 => 'Win32EqualRect',
    742 => 'Win32ExcludeUpdateRegion',
    743 => 'Win32FillRect',
    744 => 'Win32FindAtom',
    745 => 'Win32FlashWindow',
    746 => 'Win32FocusChange',
    748 => 'Win32FreeErrorInfo',
    749 => 'Win32GetClipPS',
    750 => 'Win32GetCurrentTime',
    751 => 'Win32GetErrorInfo',
    752 => 'Win32GetKeyState',
    753 => 'Win32GetLastError',
    754 => 'Win32GetMaxPosition',
    755 => 'Win32GetMinPosition',
    756 => 'Win32GetNextWindow',
    757 => 'Win32GetPS',
    758 => 'Win32GetPhysKeyState',
    759 => 'Win32GetScreenPS',
    760 => 'Win32GetSysBitmap',
    761 => 'Win32InSendMsg',
    762 => 'Win32InflateRect',
    763 => 'Win32Initialize',
    764 => 'Win32IntersectRect',
    765 => 'Win32InvalidateRect',
    766 => 'Win32InvalidateRegion',
    767 => 'Win32InvertRect',
    768 => 'Win32IsChild',
    769 => 'Win32IsPhysInputEnabled',
    770 => 'Win32IsRectEmpty',
    771 => 'Win32IsThreadActive',
    772 => 'Win32IsWindow',
    773 => 'Win32IsWindowEnabled',
    774 => 'Win32IsWindowShowing',
    775 => 'Win32IsWindowVisible',
    776 => 'Win32LoadAccelTable',
    777 => 'Win32LoadLibrary',
    778 => 'Win32LoadMenu',
    779 => 'Win32LoadMessage',
    780 => 'Win32LoadPointer',
    781 => 'Win32LoadString',
    782 => 'Win32LockVisRegions',
    784 => 'Win32LockWindowUpdate',
    785 => 'Win32MakePoints',
    786 => 'Win32MakeRect',
    787 => 'Win32MapDlgPoints',
    788 => 'Win32MapWindowPoints',
    789 => 'Win32MessageBox',
    790 => 'Win32MsgSemWait',
    791 => 'Win32NextChar',
    792 => 'Win32OffsetRect',
    793 => 'Win32OpenClipbrd',
    794 => 'Win32OpenWindowDC',
    795 => 'Win32PrevChar',
    796 => 'Win32ProcessDlg',
    797 => 'Win32PtInRect',
    798 => 'Win32QueryAccelTable',
    799 => 'Win32QueryActiveWindow',
    800 => 'Win32QueryAnchorBlock',
    801 => 'Win32QueryAtomLength',
    802 => 'Win32QueryAtomName',
    803 => 'Win32QueryAtomUsage',
    804 => 'Win32QueryCapture',
    805 => 'Win32QueryClassName',
    806 => 'Win32QueryClipbrdData',
    807 => 'Win32QueryClipbrdFmtInfo',
    808 => 'Win32QueryClipbrdOwner',
    809 => 'Win32QueryClipbrdViewer',
    810 => 'Win32QueryCp',
    811 => 'Win32QueryCpList',
    812 => 'Win32QueryCursorInfo',
    813 => 'Win32QueryDesktopWindow',
    814 => 'Win32QueryDlgItemShort',
    815 => 'Win32QueryDlgItemText',
    816 => 'Win32QueryDlgItemTextLength',
    817 => 'Win32QueryFocus',
    818 => 'Win32QueryMsgPos',
    819 => 'Win32QueryMsgTime',
    820 => 'Win32QueryObjectWindow',
    821 => 'Win32QueryPointer',
    822 => 'Win32QueryPointerInfo',
    823 => 'Win32QueryPointerPos',
    824 => 'Win32QueryQueueInfo',
    825 => 'Win32QueryQueueStatus',
    826 => 'Win32QuerySysColor',
    827 => 'Win32QuerySysModalWindow',
    828 => 'Win32QuerySysPointer',
    829 => 'Win32QuerySysValue',
    830 => 'Win32QuerySystemAtomTable',
    831 => 'Win32QueryUpdateRect',
    832 => 'Win32QueryUpdateRegion',
    833 => 'Win32QueryVersion',
    834 => 'Win32QueryWindow',
    835 => 'Win32QueryWindowDC',
    837 => 'Win32QueryWindowPos',
    838 => 'Win32QueryWindowProcess',
    839 => 'Win32QueryWindowPtr',
    840 => 'Win32QueryWindowRect',
    841 => 'Win32QueryWindowText',
    842 => 'Win32QueryWindowTextLength',
    843 => 'Win32QueryWindowULong',
    844 => 'Win32QueryWindowUShort',
    845 => 'Win32RegisterUserDatatype',
    846 => 'Win32RegisterUserMsg',
    848 => 'Win32ReleasePS',
    849 => 'Win32ScrollWindow',
    850 => 'Win32SetAccelTable',
    851 => 'Win32SetActiveWindow',
    852 => 'Win32SetCapture',
    853 => 'Win32SetClassMsgInterest',
    854 => 'Win32SetClipbrdData',
    855 => 'Win32SetClipbrdOwner',
    856 => 'Win32SetClipbrdViewer',
    857 => 'Win32SetCp',
    858 => 'Win32SetDlgItemShort',
    859 => 'Win32SetDlgItemText',
    860 => 'Win32SetFocus',
    861 => 'Win32SetMsgInterest',
    862 => 'Win32SetMsgMode',
    863 => 'Win32SetMultWindowPos',
    864 => 'Win32SetOwner',
    865 => 'Win32SetParent',
    866 => 'Win32SetPointer',
    867 => 'Win32SetPointerPos',
    868 => 'Win32SetRect',
    869 => 'Win32SetRectEmpty',
    870 => 'Win32SetSynchroMode',
    871 => 'Win32SetSysColors',
    872 => 'Win32SetSysModalWindow',
    873 => 'Win32SetSysValue',
    874 => 'Win32SetWindowBits',
    875 => 'Win32SetWindowPos',
    876 => 'Win32SetWindowPtr',
    877 => 'Win32SetWindowText',
    878 => 'Win32SetWindowULong',
    879 => 'Win32SetWindowUShort',
    880 => 'Win32ShowCursor',
    881 => 'Win32ShowPointer',
    882 => 'Win32ShowTrackRect',
    883 => 'Win32ShowWindow',
    884 => 'Win32StartTimer',
    885 => 'Win32StopTimer',
    886 => 'Win32SubstituteStrings',
    887 => 'Win32SubtractRect',
    888 => 'Win32Terminate',
    890 => 'Win32TrackRect',
    891 => 'Win32UnionRect',
    892 => 'Win32UpdateWindow',
    893 => 'Win32Upper',
    894 => 'Win32UpperChar',
    895 => 'Win32ValidateRect',
    896 => 'Win32ValidateRegion',
    897 => 'Win32WaitMsg',
    898 => 'Win32WindowFromDC',
    899 => 'Win32WindowFromID',
    900 => 'Win32WindowFromPoint',
    901 => 'Win32BroadcastMsg',
    902 => 'Win32PostQueueMsg',
    903 => 'Win32SendDlgItemMsg',
    904 => 'Win32TranslateAccel',
    905 => 'Win32CallMsgFilter',
    906 => 'Win32CreateFrameControls',
    907 => 'Win32CreateMenu',
    908 => 'Win32CreateStdWindow',
    909 => 'Win32CreateWindow',
    910 => 'Win32DefDlgProc',
    911 => 'Win32DefWindowProc',
    912 => 'Win32DispatchMsg',
    913 => 'Win32DrawText',
    914 => 'Win32GetDlgMsg',
    915 => 'Win32GetMsg',
    916 => 'Win32MsgMuxSemWait',
    917 => 'Win32MultWindowFromIDs',
    918 => 'Win32PeekMsg',
    919 => 'Win32PostMsg',
    920 => 'Win32SendMsg',
    921 => 'Win32SetKeyboardStateTable',
    922 => 'Win32CreateDlg',
    923 => 'Win32DlgBox',
    924 => 'Win32LoadDlg',
    925 => 'Win32QueryClassInfo',
    926 => 'Win32RegisterClass',
    927 => 'Win32ReleaseHook',
    928 => 'Win32SetHook',
    929 => 'Win32SubclassWindow',
    930 => 'Win32SetClassThunkProc',
    931 => 'Win32QueryClassThunkProc',
    932 => 'Win32SetWindowThunkProc',
    933 => 'Win32QueryWindowThunkProc',
    934 => 'Win32QueryWindowModel',
    935 => 'Win32SetDesktopBkgnd',
    936 => 'Win32QueryDesktopBkgnd',
    937 => 'Win32PopupMenu',
    938 => 'Win32SetPresParam',
    939 => 'Win32QueryPresParam',
    940 => 'Win32RemovePresParam',
    941 => 'Win32RealizePalette',
    942 => 'Win32CreatePointerIndirect',
    943 => 'Win32SaveWindowPos',
    947 => 'WinCreateFarHeap',
    948 => 'WinDestroyFarHeap',
    949 => 'WinAllocFarMem',
    950 => 'WinFreeFarMem',
    951 => 'WinReallocFarMem',
    952 => 'Win32GetErasePS',
    953 => 'Win32ReleaseErasePS',
    954 => 'DEBUG32INPUT',
    955 => 'DEBUG32OUTPUT',
    956 => 'DEBUG32CURPOS',
    957 => 'DEBUG32CLS',
    958 => 'Win32DebugBreak',
    959 => 'WinSetClassThunkProc',
    960 => 'WinQueryClassThunkProc',
    961 => 'WinSetWindowThunkProc',
    962 => 'WinQueryWindowThunkProc',
    963 => 'Win32SystemShutdown',
    964 => 'Win32BuildPtrHandle',
    965 => 'Win32ExplodeWindow',
    966 => 'Win32SetAccelTableValue',
    967 => 'Win32QueryAccelTableValue',
    968 => 'Win32StretchPointer',
    969 => 'AAB32GETREG',
    970 => 'AAB32SETREG',
    971 => 'Win32SetPointerOwner',
    972 => 'Win32GetFrameTreePPSize',
    973 => 'Win32GetFrameTreePPs',
    974 => 'Win32SetFrameTreePPs',
    975 => 'Win32QueryProcessCP',
    976 => 'Win32VisRegionNotify',
    977 => 'Win32SetErrorInfo',
    978 => 'Win32WaitEventSem',
    979 => 'Win32RequestMutexSem',
    980 => 'Win32WaitMuxWaitSem',
    981 => 'WinSetSysClipbrdViewer',
    982 => 'Win32SetSysClipbrdViewer',
    983 => 'Win32SemQuery',
    984 => 'Win32SemEnter',
    985 => 'Win32SemLeave',
    986 => 'Win32LoadProcedure',
    987 => 'Win32DeleteProcedure',
    988 => 'Win32MoveCursor',
    990 => 'Win32QuerySendMsg',
    991 => 'Win32ReplyMsg',
    992 => 'Win32WakeThread',
    993 => 'Win32QueueFromID',
    994 => 'Win32ThreadAssocQueue',
    995 => 'Win32LockInput',
    996 => 'Win32SetSysFont',
    997 => 'Win32LockPointerUpdate',
    998 => 'Win32CheckInput',
    999 => 'Far32LockupHook',
    1000 => 'Win32QueryVisibleRegion',
    1001 => 'Win32SetVisibleRegionNotify',
    1002 => 'Win32SetSysPointerData',
    1003 => 'Win32QuerySysPointerData',
    1004 => 'Win32SeamlessBox',
    1005 => 'Win32JiggleMouse',
    1006 => 'Win32TrackSeamless',
    1007 => 'Win32RegisterSeamlessProc',
    1008 => 'Win32SetCharXlateTbl',
    1009 => 'WinMspInit',
    1010 => 'WinMspAlloc',
    1011 => 'WinMspFree',
    1012 => 'ThkDos16SetFgnd',
    1013 => 'InputGetDeviceInfo',
    1014 => 'Win32RegisterPen',
    1015 => 'Win32MessageBox2',
    1016 => 'Ring0FlushSysQueue',
    1017 => 'IsCodeSelector',
    1018 => 'InputInterrupt',
    1019 => 'InotMQSems',
    1020 => 'AllocMQSem',
    1021 => 'FreeMQSem',
    1022 => 'Ring2SetBoostBit',
    1023 => 'FarRing0WriteMessage',
    1024 => 'StopTimer',
    1026 => 'FPen',
    1027 => 'WinDrawTabbedText',
    1028 => 'PMReleaseMutexSem',
    1029 => 'PMRequestMutexSem',
    1030 => 'Win32QueryPointerClipRect',
    1031 => 'Win32SetPointerClipRect',
    1032 => 'Win32SendMsgTimeout',
    1033 => 'Win32WaitMsgTimeout',
    1034 => 'Win32IsWindowOfClass',
    1035 => 'Win32SetAtomTableOwner',
    1036 => 'WinXXCreateHeap',
    1037 => 'WinXXDestroyHeap',
    1038 => 'WinXXAllocMem',
    1039 => 'WinXXFreeMem',
    1040 => 'WinXXAllocFill',
    1041 => 'WinXXReallocMem',
    1042 => 'WinXXQueryMemSize',
    1043 => 'Win32SetClipRegion',
    1044 => 'Win32QueryClipRegion',
    1045 => 'Win32AddClipbrdViewer',
    1046 => 'Win32RemoveClipbrdViewer',
    1047 => 'Win32QueryClipbrdViewerChain',
    1048 => 'Win32IncrementAtomUsage',
    1049 => 'DaxQueryOpenClipbrdWindow',
    1050 => 'WinSetDaxData',
    1051 => 'WinQueryDaxData',
    1052 => 'WinEnumProperties',
    1053 => 'WinQueryProperty',
    1054 => 'WinRemoveProperty',
    1055 => 'WinSetProperty',
    1056 => 'WinEnumClassProperties',
    1057 => 'WinQueryClassProperty',
    1058 => 'WinRemoveClassProperty',
    1059 => 'WinSetClassProperty',
    1060 => 'Win32SetKbdLayout',
    1061 => 'Win32GetAFCValue',
    1062 => 'Win32SetAFCValue',
    1063 => 'Win32LoadVkeyGlyphXlateTbl',
    1064 => 'Win32SetVkeyGlyphXlateTbl',
    1065 => 'Win32QueryVkeyGlyphXlateTbl',
    1066 => 'Win32TrackWindow',
    1067 => 'Win32SemEnterTimeout',
    1068 => 'WinSetDesktopWorkArea',
    1069 => 'WinQueryDesktopWorkArea',
    1070 => 'Win32TranslateChar2',
    1071 => 'Win32WaitForIdleThread',
    1072 => 'WinXXCreateHeap2',
    1073 => 'WinQuerySharedHeapData',
    1074 => 'Win32QueryActiveOtherWindow',
    1075 => 'Win32EnumVkeyScanIDs',
    1500 => 'WinSetLangInfo',
    1501 => 'WinQueryLangInfo',
    1502 => 'WinSetKbdLayer',
    1503 => 'WinQueryKbdLayer',
    1504 => 'WinSetLangViewer',
    1505 => 'WinQueryLangViewer',
    1600 => 'WinPourEvent',
    1601 => 'WinSetMsgQimInfo',
    1602 => 'WinQueryMsgQimInfo',
    10000 => 'DaxCreateCaret',
    10001 => 'DaxDestroyCaret',
    10002 => 'DaxGetCaretBlinkTime',
    10004 => 'DaxHideCaret',
    10005 => 'DaxSetCaretBlinkTime',
    10007 => 'DaxShowCaret',
    10018 => 'DaxShowCursor',
    10019 => 'DaxSwapMouseButton',
    10020 => 'LookupAtom',
    10021 => 'DaxOpenClipbrd',
  },

  'PMGPI' => {
    1 => 'DevOpenDC',
    2 => 'DevCloseDC',
    3 => 'DevPostDeviceModes',
    4 => 'DevEscape',
    5 => 'DevQueryHardCopyCaps',
    6 => 'DevQueryCaps',
    7 => 'GpiCreatePS',
    9 => 'GpiQueryPS',
    10 => 'GpiDestroyPS',
    11 => 'GpiResetPS',
    12 => 'GpiSavePS',
    13 => 'GpiRestorePS',
    14 => 'GpiAssociate',
    15 => 'GpiErrorSegmentData',
    16 => 'GpiErase',
    17 => 'GpiSetDrawControl',
    18 => 'GpiQueryDrawControl',
    19 => 'GpiDrawChain',
    20 => 'GpiDrawFrom',
    21 => 'GpiDrawSegment',
    22 => 'GpiSetStopDraw',
    23 => 'GpiQueryStopDraw',
    24 => 'GpiRemoveDynamics',
    25 => 'GpiDrawDynamics',
    26 => 'GpiSetDrawingMode',
    27 => 'GpiQueryDrawingMode',
    28 => 'GpiGetData',
    29 => 'GpiPutData',
    30 => 'GpiSetPickApertureSize',
    31 => 'GpiQueryPickApertureSize',
    32 => 'GpiSetPickAperturePosition',
    33 => 'GpiQueryPickAperturePosition',
    34 => 'GpiSetTag',
    35 => 'GpiQueryTag',
    36 => 'GpiCorrelateChain',
    37 => 'GpiCorrelateFrom',
    38 => 'GpiCorrelateSegment',
    42 => 'GpiResetBoundaryData',
    43 => 'GpiQueryBoundaryData',
    44 => 'GpiOpenSegment',
    46 => 'GpiCloseSegment',
    47 => 'GpiDeleteSegment',
    48 => 'GpiDeleteSegments',
    49 => 'GpiQuerySegmentNames',
    51 => 'GpiSetInitialSegmentAttrs',
    52 => 'GpiQueryInitialSegmentAttrs',
    53 => 'GpiSetSegmentAttrs',
    54 => 'GpiQuerySegmentAttrs',
    55 => 'GpiSetSegmentPriority',
    56 => 'GpiQuerySegmentPriority',
    57 => 'GpiSetEditMode',
    58 => 'GpiQueryEditMode',
    59 => 'GpiSetElementPointer',
    60 => 'GpiQueryElementPointer',
    61 => 'GpiOffsetElementPointer',
    62 => 'GpiDeleteElement',
    63 => 'GpiDeleteElementRange',
    64 => 'GpiLabel',
    65 => 'GpiSetElementPointerAtLabel',
    66 => 'GpiDeleteElementsBetweenLabels',
    67 => 'GpiQueryElementType',
    68 => 'GpiQueryElement',
    69 => 'GpiElement',
    70 => 'GpiBeginElement',
    71 => 'GpiEndElement',
    78 => 'GpiSetSegmentTransformMatrix',
    79 => 'GpiQuerySegmentTransformMatrix',
    80 => 'GpiSetModelTransformMatrix',
    81 => 'GpiQueryModelTransformMatrix',
    82 => 'GpiCallSegmentMatrix',
    83 => 'GpiSetDefaultViewMatrix',
    84 => 'GpiQueryDefaultViewMatrix',
    85 => 'GpiSetPageViewport',
    86 => 'GpiQueryPageViewport',
    87 => 'GpiSetViewingTransformMatrix',
    88 => 'GpiQueryViewingTransformMatrix',
    89 => 'GpiSetGraphicsField',
    90 => 'GpiQueryGraphicsField',
    91 => 'GpiSetViewingLimits',
    92 => 'GpiQueryViewingLimits',
    93 => 'GpiConvert',
    94 => 'GpiSetAttrMode',
    95 => 'GpiQueryAttrMode',
    96 => 'GpiPop',
    97 => 'GpiSetAttrs',
    98 => 'GpiQueryAttrs',
    99 => 'GpiCreateLogColorTable',
    100 => 'GpiRealizeColorTable',
    101 => 'GpiUnrealizeColorTable',
    102 => 'GpiQueryColorData',
    103 => 'GpiQueryLogColorTable',
    104 => 'GpiQueryRealColors',
    105 => 'GpiQueryNearestColor',
    106 => 'GpiQueryColorIndex',
    107 => 'GpiQueryRGBColor',
    108 => 'GpiSetColor',
    109 => 'GpiQueryColor',
    110 => 'GpiSetBackColor',
    111 => 'GpiQueryBackColor',
    112 => 'GpiSetMix',
    113 => 'GpiQueryMix',
    114 => 'GpiSetBackMix',
    115 => 'GpiQueryBackMix',
    116 => 'GpiSetLineType',
    117 => 'GpiQueryLineType',
    118 => 'GpiSetLineWidth',
    119 => 'GpiQueryLineWidth',
    120 => 'GpiSetLineWidthGeom',
    121 => 'GpiQueryLineWidthGeom',
    122 => 'GpiSetLineEnd',
    123 => 'GpiQueryLineEnd',
    124 => 'GpiSetLineJoin',
    125 => 'GpiQueryLineJoin',
    126 => 'GpiSetCurrentPosition',
    127 => 'GpiQueryCurrentPosition',
    128 => 'GpiMove',
    129 => 'GpiLine',
    130 => 'GpiPolyLine',
    131 => 'GpiBox',
    132 => 'GpiPtVisible',
    133 => 'GpiRectVisible',
    134 => 'GpiSetArcParams',
    135 => 'GpiQueryArcParams',
    136 => 'GpiPointArc',
    137 => 'GpiFullArc',
    138 => 'GpiPartialArc',
    139 => 'GpiPolyFillet',
    140 => 'GpiPolyFilletSharp',
    141 => 'GpiPolySpline',
    142 => 'GpiSetBitmapId',
    143 => 'GpiQueryBitmapHandle',
    144 => 'GpiSetPatternSet',
    145 => 'GpiQueryPatternSet',
    146 => 'GpiSetPattern',
    147 => 'GpiQueryPattern',
    148 => 'GpiSetPatternRefPoint',
    149 => 'GpiQueryPatternRefPoint',
    150 => 'GpiBeginArea',
    151 => 'GpiEndArea',
    152 => 'GpiLoadFonts',
    153 => 'GpiUnloadFonts',
    154 => 'GpiCreateLogFont',
    155 => 'GpiDeleteSetId',
    156 => 'GpiQueryNumberSetIds',
    157 => 'GpiQuerySetIds',
    158 => 'GpiQueryFonts',
    159 => 'GpiQueryFontMetrics',
    160 => 'GpiQueryKerningPairs',
    161 => 'GpiQueryWidthTable',
    162 => 'GpiSetCp',
    163 => 'GpiQueryCp',
    164 => 'GpiQueryTextBox',
    165 => 'DevQueryDeviceNames',
    166 => 'GpiQueryDefCharBox',
    167 => 'GpiQueryFontFileDescriptions',
    168 => 'GpiSetCharSet',
    169 => 'GpiQueryCharSet',
    170 => 'GpiSetCharBox',
    171 => 'GpiQueryCharBox',
    172 => 'GpiSetCharAngle',
    173 => 'GpiQueryCharAngle',
    174 => 'GpiSetCharShear',
    175 => 'GpiQueryCharShear',
    176 => 'GpiSetCharDirection',
    177 => 'GpiQueryCharDirection',
    178 => 'GpiSetCharMode',
    179 => 'GpiQueryCharMode',
    180 => 'GpiCharString',
    181 => 'GpiCharStringAt',
    182 => 'GpiCharStringPos',
    183 => 'GpiCharStringPosAt',
    184 => 'GpiSetMarkerSet',
    185 => 'GpiQueryMarkerSet',
    186 => 'GpiSetMarker',
    187 => 'GpiQueryMarker',
    188 => 'GpiSetMarkerBox',
    189 => 'GpiQueryMarkerBox',
    190 => 'GpiMarker',
    191 => 'GpiPolyMarker',
    192 => 'GpiImage',
    196 => 'GpiCreateBitmap',
    197 => 'GpiDeleteBitmap',
    198 => 'GpiSetBitmap',
    199 => 'GpiSetBitmapDimension',
    200 => 'GpiQueryBitmapDimension',
    201 => 'GpiQueryDeviceBitmapFormats',
    202 => 'GpiQueryBitmapParameters',
    203 => 'GpiSetBitmapBits',
    204 => 'GpiQueryBitmapBits',
    205 => 'GpiBitBlt',
    206 => 'GpiSetPel',
    207 => 'GpiQueryPel',
    208 => 'GpiCreateRegion',
    209 => 'GpiSetRegion',
    210 => 'GpiDestroyRegion',
    211 => 'GpiCombineRegion',
    212 => 'GpiEqualRegion',
    213 => 'GpiOffsetRegion',
    214 => 'GpiPtInRegion',
    215 => 'GpiRectInRegion',
    216 => 'GpiQueryRegionBox',
    217 => 'GpiQueryRegionRects',
    218 => 'GpiSetClipRegion',
    219 => 'GpiQueryClipRegion',
    220 => 'GpiQueryClipBox',
    221 => 'GpiIntersectClipRectangle',
    222 => 'GpiExcludeClipRectangle',
    223 => 'GpiOffsetClipRegion',
    224 => 'GpiPaintRegion',
    225 => 'GpiLoadMetaFile',
    226 => 'GpiCopyMetaFile',
    227 => 'GpiPlayMetaFile',
    228 => 'GpiSaveMetaFile',
    229 => 'GpiDeleteMetaFile',
    230 => 'GpiQueryMetaFileBits',
    231 => 'GpiSetMetaFileBits',
    232 => 'GpiQueryMetaFileLength',
    233 => 'GpiSetClipPath',
    234 => 'GpiBeginPath',
    235 => 'GpiEndPath',
    236 => 'GpiCloseFigure',
    237 => 'GpiModifyPath',
    238 => 'GpiFillPath',
    239 => 'GpiStartRequest',
    240 => 'GpiQueryDevice',
    241 => 'GpiVectorSymbol',
    242 => 'GpiOpenMetafile',
    243 => 'GpiCloseMetafile',
    244 => 'DevStdOpen',
    245 => 'GpiQueryCharStringPos',
    246 => 'GpiQueryCharStringPosAt',
    247 => 'GpiConvPSH',
    248 => 'GpiSetPS',
    249 => 'SegsGWOpenSegmentWindow',
    250 => 'MtEndReadRequest',
    251 => 'MtGetDescription',
    252 => 'FmtOrderTable',
    253 => 'MtGetCodepage',
    254 => 'MtGetLCT',
    255 => 'MtGetGDDInfo',
    256 => 'FmtConvertGocaPoly',
    257 => 'MtGetFirstFont',
    258 => 'SegsGWNewPartData',
    259 => 'MtStartReadRequest',
    260 => 'MtGetFirstGraphicsData',
    261 => 'MtGetNextFont',
    262 => 'MtGetNextGraphicsData',
    263 => 'GpiLoadPublicFonts',
    264 => 'GpiUnloadPublicFonts',
    265 => 'GpiAccessMetaFile',
    266 => 'GpiMtAssociate',
    267 => 'GpiMtDisassociate',
    268 => 'GpiComment',
    269 => 'GpiWCBitBlt',
    270 => 'GpiStrokePath',
    271 => 'SegsGWNextOrderF',
    272 => 'GpiSuspendPlay',
    273 => 'GpiResumePlay',
    274 => 'GpiOutlinePath',
    275 => 'GpiSetDefTag',
    276 => 'GpiQueryDefTag',
    277 => 'GpiSetDefAttrs',
    278 => 'GpiQueryDefAttrs',
    279 => 'GpiSetDefViewingLimits',
    280 => 'GpiQueryDefViewingLimits',
    281 => 'GpiSetDefArcParams',
    282 => 'GpiQueryDefArcParams',
    283 => 'GpiTranslate',
    284 => 'GpiScale',
    285 => 'GpiRotate',
    286 => 'GpiPolyLineDisjoint',
    287 => 'GpiPathToRegion',
    289 => 'GpiFloodFill',
    290 => 'GpiDrawBits',
    291 => 'GpiQueryBitmapInfoHeader',
    292 => 'GpiQueryLogicalFont',
    293 => 'GpiQueryFaceString',
    294 => 'GpiQueryFontAction',
    295 => 'GpiCreatePalette',
    296 => 'GpiDeletEpalette',
    297 => 'GpiSelectPalette',
    298 => 'GpiAnimatePalette',
    299 => 'GpiSetPaletteEntries',
    300 => 'GpiQueryPalette',
    301 => 'GpiQueryPaletteInfo',
    302 => 'GpiQueryCharExtra',
    303 => 'GpiSetCharExtra',
    304 => 'GpiQueryCharBreakExtra',
    305 => 'GpiSetCharBreakExtra',
    306 => 'GpiFrameRegion',
    307 => 'GpiConvertWithMatrix',
    308 => 'GpiSetDCOwner',
    309 => 'GpiSetBitmapOwner',
    310 => 'GpiSetRegionOwner',
    311 => 'GpiInstallIFIFont',
    312 => 'DspInitSystemDriverName',
    351 => 'Gpi32Associate',
    352 => 'Gpi32BeginArea',
    353 => 'Gpi32BeginElement',
    354 => 'Gpi32BeginPath',
    355 => 'Gpi32BitBlt',
    356 => 'Gpi32Box',
    357 => 'Gpi32CallSegmentMatrix',
    358 => 'Gpi32CharString',
    359 => 'Gpi32CharStringAt',
    360 => 'Gpi32CloseFigure',
    361 => 'Gpi32CloseSegment',
    362 => 'Gpi32CombineRegion',
    363 => 'Gpi32Comment',
    364 => 'Gpi32Convert',
    365 => 'Gpi32CopyMetaFile',
    366 => 'Gpi32CorrelateChain',
    367 => 'Gpi32CorrelateFrom',
    368 => 'Gpi32CreateLogFont',
    369 => 'Gpi32CreatePS',
    370 => 'Gpi32CreateRegion',
    371 => 'Gpi32DeleteBitmap',
    372 => 'Gpi32DeleteElement',
    373 => 'Gpi32DeleteElementRange',
    374 => 'Gpi32DeleteElementsBetweenLabels',
    375 => 'Gpi32DeleteMetaFile',
    376 => 'Gpi32DeleteSegment',
    377 => 'Gpi32DeleteSegments',
    378 => 'Gpi32DeleteSetId',
    379 => 'Gpi32DestroyPS',
    380 => 'Gpi32DrawChain',
    381 => 'Gpi32DrawDynamics',
    382 => 'Gpi32DrawFrom',
    383 => 'Gpi32DrawSegment',
    384 => 'Gpi32Element',
    385 => 'Gpi32EndArea',
    386 => 'Gpi32EndElement',
    387 => 'Gpi32EndPath',
    388 => 'Gpi32EqualRegion',
    389 => 'Gpi32Erase',
    390 => 'Gpi32ErrorSegmentData',
    391 => 'Gpi32ExcludeClipRectangle',
    392 => 'Gpi32FillPath',
    393 => 'Gpi32FullArc',
    394 => 'Gpi32GetData',
    395 => 'Gpi32Image',
    396 => 'Gpi32IntersectClipRectangle',
    397 => 'Gpi32Label',
    398 => 'Gpi32Line',
    399 => 'Gpi32LoadBitmap',
    400 => 'Gpi32LoadFonts',
    401 => 'Gpi32LoadMetaFile',
    402 => 'Gpi32Marker',
    403 => 'Gpi32ModifyPath',
    404 => 'Gpi32Move',
    405 => 'Gpi32OffsetClipRegion',
    406 => 'Gpi32OffsetElementPointer',
    407 => 'Gpi32OffsetRegion',
    408 => 'Gpi32OpenSegment',
    409 => 'Gpi32PaintRegion',
    411 => 'Gpi32PlayMetaFile',
    412 => 'Gpi32PointArc',
    413 => 'Gpi32PolyFillet',
    414 => 'Gpi32PolyFilletSharp',
    415 => 'Gpi32PolyLine',
    416 => 'Gpi32PolyMarker',
    417 => 'Gpi32PolySpline',
    418 => 'Gpi32Pop',
    419 => 'Gpi32PtInRegion',
    420 => 'Gpi32PtVisible',
    421 => 'Gpi32PutData',
    422 => 'Gpi32QueryArcParams',
    423 => 'Gpi32QueryAttrMode',
    424 => 'Gpi32QueryBackColor',
    425 => 'Gpi32QueryBackMix',
    426 => 'Gpi32QueryBitmapDimension',
    427 => 'Gpi32QueryBitmapHandle',
    428 => 'Gpi32QueryBoundaryData',
    429 => 'Gpi32QueryCharAngle',
    430 => 'Gpi32QueryCharBox',
    431 => 'Gpi32QueryCharDirection',
    432 => 'Gpi32QueryCharMode',
    433 => 'Gpi32QueryCharSet',
    434 => 'Gpi32QueryCharShear',
    435 => 'Gpi32QueryClipBox',
    436 => 'Gpi32QueryClipRegion',
    437 => 'Gpi32QueryColor',
    438 => 'Gpi32QueryColordata',
    439 => 'Gpi32QueryColorIndex',
    440 => 'Gpi32QueryCp',
    441 => 'Gpi32QueryCurrentPosition',
    442 => 'Gpi32QueryDefCharBox',
    443 => 'Gpi32QueryDefaultViewMatrix',
    444 => 'Gpi32QueryDevice',
    445 => 'Gpi32QueryDeviceBitmapFormats',
    446 => 'Gpi32QueryDrawControl',
    447 => 'Gpi32QueryDrawingMode',
    448 => 'Gpi32QueryEditMode',
    449 => 'Gpi32QueryElement',
    450 => 'Gpi32QueryElementPointer',
    451 => 'Gpi32QueryElementType',
    452 => 'Gpi32QueryFontFileDescriptions',
    453 => 'Gpi32QueryFontMetrics',
    454 => 'Gpi32QueryGraphicsField',
    455 => 'Gpi32QueryInitialSegmentAttrs',
    456 => 'Gpi32QueryKerningPairs',
    457 => 'Gpi32QueryLineEnd',
    458 => 'Gpi32QueryLineJoin',
    459 => 'Gpi32QueryLineType',
    460 => 'Gpi32QueryLineWidth',
    461 => 'Gpi32QueryLineWidthGeom',
    462 => 'Gpi32QueryMarker',
    463 => 'Gpi32QueryMarkerBox',
    464 => 'Gpi32QueryMarkerSet',
    465 => 'Gpi32QueryMetaFileBits',
    466 => 'Gpi32QueryMetaFileLength',
    467 => 'Gpi32QueryMix',
    468 => 'Gpi32QueryModelTransformMatrix',
    469 => 'Gpi32QueryNearestColor',
    470 => 'Gpi32QueryNumberSetIds',
    471 => 'Gpi32QueryPS',
    472 => 'Gpi32QueryPageViewport',
    473 => 'Gpi32QueryPattern',
    474 => 'Gpi32QueryPatternRefPoint',
    475 => 'Gpi32QueryPatternSet',
    476 => 'Gpi32QueryPel',
    477 => 'Gpi32QueryPickAperturePosition',
    478 => 'Gpi32QueryPickApertureSize',
    479 => 'Gpi32QueryRGBColor',
    480 => 'Gpi32QueryRealColors',
    481 => 'Gpi32QueryRegionBox',
    482 => 'Gpi32QuerySegmentAttrs',
    483 => 'Gpi32QuerySegmentNames',
    484 => 'Gpi32QuerySegmentPriority',
    485 => 'Gpi32QuerySegmentTransformMatrix',
    486 => 'Gpi32QuerySetIds',
    487 => 'Gpi32QueryStopDraw',
    488 => 'Gpi32QueryTag',
    489 => 'Gpi32QueryTextBox',
    490 => 'Gpi32QueryViewingLimits',
    491 => 'Gpi32QueryViewingTransformMatrix',
    492 => 'Gpi32QueryWidthTable',
    494 => 'Gpi32RectInRegion',
    495 => 'Gpi32RectVisible',
    496 => 'Gpi32RemoveDynamics',
    497 => 'Gpi32ResetBoundaryData',
    498 => 'Gpi32ResetPS',
    499 => 'Gpi32RestorePS',
    500 => 'Gpi32SaveMetaFile',
    501 => 'Gpi32SavePS',
    502 => 'Gpi32SetArcParams',
    503 => 'Gpi32SetAttrMode',
    504 => 'Gpi32SetBackColor',
    505 => 'Gpi32SetBackMix',
    506 => 'Gpi32SetBitmap',
    507 => 'Gpi32SetBitmapDimension',
    508 => 'Gpi32SetBitmapId',
    509 => 'Gpi32SetCharAngle',
    510 => 'Gpi32SetCharBox',
    511 => 'Gpi32SetCharDirection',
    512 => 'Gpi32SetCharMode',
    513 => 'Gpi32SetCharSet',
    514 => 'Gpi32SetCharShear',
    515 => 'Gpi32SetClipPath',
    516 => 'Gpi32SetClipRegion',
    517 => 'Gpi32SetColor',
    518 => 'Gpi32SetCp',
    519 => 'Gpi32SetCurrentPosition',
    520 => 'Gpi32SetDefaultViewMatrix',
    521 => 'Gpi32SetDrawControl',
    522 => 'Gpi32SetDrawingMode',
    523 => 'Gpi32SetEditMode',
    524 => 'Gpi32SetElementPointer',
    525 => 'Gpi32SetElementPointerAtLabel',
    526 => 'Gpi32SetGraphicsField',
    527 => 'Gpi32SetInitialSegmentAttrs',
    528 => 'Gpi32SetLineEnd',
    529 => 'Gpi32SetLineJoin',
    530 => 'Gpi32SetLineType',
    531 => 'Gpi32SetLineWidth',
    532 => 'Gpi32SetLineWidthGeom',
    533 => 'Gpi32SetMarker',
    534 => 'Gpi32SetMarkerBox',
    535 => 'Gpi32SetMarkerSet',
    536 => 'Gpi32SetMetaFileBits',
    537 => 'Gpi32SetMix',
    538 => 'Gpi32SetModelTransformMatrix',
    539 => 'Gpi32SetPS',
    540 => 'Gpi32SetPageViewport',
    541 => 'Gpi32SetPattern',
    542 => 'Gpi32SetPatternRefPoint',
    543 => 'Gpi32SetPatternSet',
    544 => 'Gpi32SetPel',
    545 => 'Gpi32SetPickAperturePosition',
    546 => 'Gpi32SetRegion',
    547 => 'Gpi32SetSegmentAttrs',
    548 => 'Gpi32SetSegmentPriority',
    549 => 'Gpi32SetSegmentTransformMatrix',
    550 => 'Gpi32SetStopDraw',
    551 => 'Gpi32SetTag',
    552 => 'Gpi32SetViewingLimits',
    553 => 'Gpi32SetViewingTransformMatrix',
    554 => 'Gpi32StrokePath',
    555 => 'Gpi32UnloadFonts',
    557 => 'Gpi32WCBitBlt',
    558 => 'Gpi32PolyLineDisjoint',
    559 => 'Gpi32PathToRegion',
    560 => 'Gpi32FloodFill',
    561 => 'Gpi32SuspendPlay',
    562 => 'Gpi32ResumePlay',
    563 => 'Gpi32OutlinePath',
    564 => 'Gpi32Translate',
    565 => 'Gpi32Scale',
    566 => 'Gpi32Rotate',
    567 => 'Gpi32QueryDefArcParams',
    568 => 'Gpi32QueryDefTag',
    569 => 'Gpi32QueryDefViewingLimits',
    570 => 'Gpi32SetDefArcParams',
    571 => 'Gpi32SetDefTag',
    572 => 'Gpi32SetDefViewingLimits',
    573 => 'Gpi32QueryBitmapParameters',
    574 => 'Gpi32QueryLogicalFont',
    575 => 'Gpi32QueryFaceString',
    576 => 'Gpi32QueryFontAction',
    577 => 'Gpi32DeletePalette',
    578 => 'Gpi32SelectPalette',
    579 => 'Gpi32QueryPalette',
    580 => 'Gpi32CharStringPos',
    581 => 'Gpi32CharStringPosAt',
    582 => 'Gpi32CorrelateSegment',
    583 => 'Gpi32QueryAttrs',
    584 => 'Gpi32QueryCharStringPos',
    585 => 'Gpi32QueryCharStringPosAt',
    586 => 'Gpi32QueryFonts',
    587 => 'Gpi32QueryRegionRects',
    588 => 'Gpi32SetAttrs',
    589 => 'Gpi32SetPickApertureSize',
    590 => 'Gpi32QueryDefAttrs',
    591 => 'Gpi32SetDefAttrs',
    592 => 'Gpi32CreateLogColorTable',
    593 => 'Gpi32QueryLogColorTable',
    594 => 'Gpi32CreatePalette',
    595 => 'Gpi32AnimatePalette',
    596 => 'Gpi32SetPaletteEntries',
    597 => 'Gpi32QueryPaletteInfo',
    598 => 'Gpi32CreateBitmap',
    599 => 'Gpi32QueryBitmapBits',
    601 => 'Gpi32QueryBitmapInfoHeader',
    602 => 'Gpi32SetBitmapBits',
    603 => 'Gpi32DrawBits',
    604 => 'Dev32CloseDC',
    605 => 'Dev32Escape',
    606 => 'Dev32QueryCaps',
    607 => 'Dev32QueryDeviceNames',
    608 => 'Dev32QueryHardcopyCaps',
    609 => 'Dev32PostDeviceModes',
    610 => 'Dev32OpenDC',
    611 => 'Gpi32DestroyRegion',
    612 => 'Gpi32PartialArc',
    613 => 'Gpi32QueryCharExtra',
    614 => 'Gpi32SetCharExtra',
    615 => 'Gpi32QueryCharBreakExtra',
    616 => 'Gpi32SetCharBreakExtra',
    617 => 'Gpi32FrameRegion',
    618 => 'Gpi32ConvertWithMatrix',
    619 => 'Gpi32SetDCOwner',
    620 => 'Gpi32SetBitmapOwner',
    621 => 'Gpi32SetRegionOwner',
    622 => 'Gpi32LoadPublicFonts',
    623 => 'Gpi32UnloadPublicFonts',
    624 => 'Gpi32InstallIFIFont',
    625 => 'Dev32StdOpen',
    626 => 'Gpi32VectorSymbol',
    627 => 'Gpi32OpenMetaFile',
    628 => 'Gpi32CloseMetaFile',
    629 => 'Gpi32ConvPSH',
    630 => 'SEG32SGWOPENSEGMENTWINDOW',
    631 => 'MT32ENDREADREQUEST',
    632 => 'MT32GETDESCRIPTION',
    633 => 'MT32GETCODEPAGE',
    634 => 'MT32GETLCT',
    635 => 'MT32GETGDDINFO',
    636 => 'FMT32CONVERTGOCAPOLY',
    637 => 'MT32GETFIRSTFONT',
    638 => 'SEG32SGWNEWPARTDATA',
    639 => 'MT32STARTREADREQUEST',
    640 => 'MT32GETFIRSTGRAPHICSDATA',
    641 => 'MT32GETNEXTFONT',
    642 => 'MT32GETNEXTGRAPHICSDATA',
    643 => 'Gpi32AccessMetaFile',
    644 => 'Gpi32MTAssociate',
    645 => 'Gpi32MTDisassociate',
    646 => 'SEG32SGWNEXTORDERF',
    648 => 'Gpi32QueryTextAlignment',
    649 => 'Gpi32SetTextAlignment',
    650 => 'Gpi32Polygons',
    651 => 'Dsp32SetDriverInfo',
    652 => 'Dsp32QueryDriverInfo',
    653 => 'Dsp32QueryDriverNames',
    654 => 'Dsp32DefaultResolution',
    655 => 'Dev32QueryDisplayResolutions',
    656 => 'Dsp32InitSystemDriverName',
    657 => 'Gpi32QueryFullFontFileDescs',
    658 => 'Gpi32QueryTabbedTextExtent',
    659 => 'Gpi32TabbedCharStringAt',
    660 => 'Gpi32QueryRasterizerCaps',
    661 => 'Gpi32CreateRoundRectRegion',
    662 => 'Gpi32CreateEllipticRegion',
    663 => 'Gpi32CreatePolygonRegion',
    664 => 'Gpi32AllocateDCData',
    665 => 'Gpi32QueryDCData',
    666 => 'Gpi32ResizePalette',
    667 => 'Gpi32QueryNearestPaletteIndex',
    668 => 'Gpi32SetFontMappingFlags',
    669 => 'Gpi32QueryFontMappingFlags',
    670 => 'Gpi32BeginInkPath',
    671 => 'Gpi32EndInkPath',
    672 => 'Gpi32StrokeInkPath',
    700 => 'PAXGETPOLYFILLMODE',
    701 => 'PAXSETPOLYFILLMODE',
    703 => 'PAXBEGINPATH',
    704 => 'PAXCLOSEFIGURE',
    705 => 'PAXENDPATH',
    706 => 'PAXFILLPATH',
    707 => 'PAXFLATTENPATH',
    710 => 'PAXPATHTOREGION',
    712 => 'PAXSTROKEANDFILLPATH',
    713 => 'PAXSTROKEPATH',
    714 => 'PAXWIDENPATH',
    715 => 'PAXARC',
    716 => 'PAXCHORD',
    717 => 'PAXELLIPSE',
    718 => 'PAXLINEDDA',
    719 => 'PAXPIE',
    720 => 'PAXPOLYBEZIER',
    721 => 'PAXPOLYBEZIERAT',
    722 => 'Gpi32AbortPath',
    723 => 'Gpi32EnableYInversion',
    724 => 'Gpi32QueryMitreLimit',
    725 => 'Gpi32QueryPath',
    726 => 'Gpi32QueryYInversion',
    727 => 'Gpi32SetMitreLimit',
    728 => 'Gpi32SaveMetaFile2',
    729 => 'Dev32PostEscape',
    730 => 'Gpi32Oval',
  },

  'PMCTLS' => {
    1 => 'PMCtlsOrd1',
    2 => 'WinFontDlg',
    3 => 'WinDefFontDlgProc',
    4 => 'WinFileDlg',
    5 => 'WinDefFileDlgProc',
    6 => 'WinFreeFileDlgList',
    7 => 'RegisterBook',
    8 => 'RegisterValueset',
    9 => 'RegisterSlider',
    10 => 'InitContainer',
    11 => 'RegisterSpinButton',
    12 => 'BookWndProc',
    13 => 'CnrGateProc',
    14 => 'ValuesetWndProc',
    15 => 'SliderWndProc',
    16 => 'SpinButtonWndProc',
    17 => 'AllocHeapMem',
    18 => 'FreeHeapMem',
    19 => 'CnrCreateNlsDateString',
    20 => 'CnrCreateNlsTimeString',
    21 => 'CnrCreateNlsNumberstring',
    22 => 'XallocHeapMem',
    23 => 'RegisterDial',
    24 => 'WinRegisterCircularSlider',
    31 => 'MLE_Initialize',
    32 => 'MultiLineEditProc',
    33 => 'BDMultiLineEditProc',
    41 => 'Drg16AccessDraginfo',
    42 => 'Drg16AddStrHandle',
    43 => 'Drg16AllocDraginfo',
    44 => 'Drg16AllocDragtransfer',
    45 => 'Drg16DeleteDraginfoStrHandles',
    46 => 'Drg16DeleteStrHandle',
    47 => 'Drg16Drag',
    48 => 'Drg16FreeDraginfo',
    49 => 'Drg16FreeDragtransfer',
    50 => 'Drg16GetPS',
    51 => 'Drg16PostTransferMsg',
    52 => 'Drg16PushDraginfo',
    53 => 'Drg16QueryDragitem',
    54 => 'Drg16QueryDragitemCount',
    55 => 'Drg16QueryDragitemPtr',
    56 => 'Drg16QueryNativeRMF',
    57 => 'Drg16QueryNativeRMFLen',
    58 => 'Drg16QueryStrName',
    59 => 'Drg16QueryStrNameLen',
    60 => 'Drg16QueryTrueType',
    61 => 'Drg16QueryTrueTypeLen',
    62 => 'Drg16ReleasePS',
    63 => 'Drg16SendTransferMsg',
    64 => 'Drg16SetDragPointer',
    65 => 'Drg16SetDragImage',
    66 => 'Drg16SetDragitem',
    67 => 'Drg16VerifyNativeRMF',
    68 => 'Drg16VerifyRMF',
    69 => 'Drg16VerifyTrueType',
    70 => 'Drg16VerifyType',
    71 => 'Drg16VerifyTypeSet',
    72 => 'Drg16DragFiles',
    73 => 'Drg16AcceptDroppedFiles',
    74 => 'DrgAccessDragInfo',
    75 => 'DrgAddStrHandle',
    76 => 'DrgAllocDragInfo',
    77 => 'DrgAllocDragTransfer',
    78 => 'DrgDeleteDragInfoStrHandles',
    79 => 'DrgDeleteStrHandle',
    80 => 'DrgDrag',
    81 => 'DrgFreeDragInfo',
    82 => 'DrgFreeDragTransfer',
    83 => 'DrgGetPS',
    84 => 'DrgPostTransferMsg',
    85 => 'DrgPushDragInfo',
    86 => 'DrgQueryDragItem',
    87 => 'DrgQueryDragItemCount',
    88 => 'DrgQueryDragItemPtr',
    89 => 'DrgQueryNativeRMF',
    90 => 'DrgQueryNativeRMFLen',
    91 => 'DrgQueryStrName',
    92 => 'DrgQueryStrNameLen',
    93 => 'DrgQueryTrueType',
    94 => 'DrgQueryTrueTypeLen',
    95 => 'DrgReleasePS',
    96 => 'DrgSendTransferMsg',
    97 => 'DrgSetDragPointer',
    98 => 'DrgSetDragImage',
    99 => 'DrgSetDragItem',
    100 => 'DrgVerifyNativeRMF',
    101 => 'DrgVerifyRMF',
    102 => 'DrgVerifyTrueType',
    103 => 'DrgVerifyType',
    104 => 'DrgVerifyTypeSet',
    105 => 'DrgDragFiles',
    106 => 'DrgAcceptDroppedFiles',
    107 => 'DrgQueryFormat',
    108 => 'DrgGetClipPS',
    110 => 'DM_CHLOCTOIPT',
    111 => 'DM_CHECKHORZLIMIT',
    112 => 'DM_CHECKVERTLIMIT',
    113 => 'DM_DISPLAY',
    114 => 'DM_DRAWBORDER',
    115 => 'DM_FILLMARGINS',
    116 => 'DM_GETERRLIMIT',
    117 => 'DM_GETFONTINFO',
    118 => 'DM_GETFORMATLEN',
    119 => 'DM_GETLINEPELS',
    120 => 'DM_GETPRINTSTRING',
    121 => 'DM_HSCROLL',
    122 => 'DM_HILITSEL',
    123 => 'DM_INIT',
    124 => 'DM_ISNEWTEXTFIT',
    125 => 'DM_ISSELECTED',
    126 => 'DM_LOLITSEL',
    127 => 'DM_PAINT',
    128 => 'DM_PRINT',
    129 => 'DM_PRINTALINE',
    130 => 'DM_PRINTLINES',
    131 => 'DM_QUERYSELECTION',
    132 => 'DM_REFLOWDISPLAY',
    133 => 'DM_REFLOWTHEREST',
    134 => 'DM_REMOVEDELLINES',
    135 => 'DM_RETURNPAINT',
    136 => 'DM_SELVIEWCHECK',
    137 => 'DM_SETCLIPREGION',
    138 => 'DM_SETFORMATRECT',
    139 => 'DM_SETSELECTION',
    140 => 'DM_SETWORDWRAP',
    141 => 'DM_UPDATESEL',
    142 => 'DM_UPDATEVIEW',
    143 => 'DM_VSCROLL',
    144 => 'DM_VSHIFT',
    145 => 'DM_WIPESELECTION',
    146 => 'DM_XFORMAT',
    147 => 'DT_ADDLINE',
    148 => 'DT_ADJUSTANCHOR',
    149 => 'DT_ADJUSTBREAKPOINT',
    150 => 'DT_ASSERT',
    151 => 'DT_CHFROMLINE',
    152 => 'DT_CMPLOC',
    153 => 'DT_DLTOIPT',
    154 => 'DT_DROPLINE',
    155 => 'DT_ENDSEL',
    156 => 'DT_FIRSTDLOFNEXTEL',
    157 => 'DT_FLUSHDISPLAYTEXT',
    158 => 'DT_GETBOTFROMTOP',
    159 => 'DT_GETDLFROMNUM',
    160 => 'DT_GETDLFROMOFFSET',
    161 => 'DT_GETLASTDLOFEL',
    162 => 'DT_GETLINE',
    163 => 'DT_GETTOKEN',
    164 => 'DT_GETTOPFROMDL',
    165 => 'DT_HORZMOVECURSOR',
    166 => 'DT_IPTTODL',
    167 => 'DT_INIT',
    168 => 'DT_ISEQUAL',
    169 => 'DT_LINEFROMCHAR',
    170 => 'DT_PATCHLINES',
    171 => 'DT_POPDL',
    172 => 'DT_PUSHDL',
    173 => 'DT_QUERYFIRSTCH',
    174 => 'DT_QUERYLINELEN',
    175 => 'DT_QUERYSELTEXT',
    176 => 'DT_REFLOWALINE',
    177 => 'DT_REFLOWLINES',
    178 => 'DT_REMOVESELECTION',
    179 => 'DT_RESTOREDTSTAT',
    180 => 'DT_SAVEDTSTAT',
    181 => 'DT_SETFIRSTCH',
    182 => 'DT_SETTEXTLIMIT',
    183 => 'DT_STARTSEL',
    184 => 'DT_SWAP',
    185 => 'DT_UPDATECURSOR',
    186 => 'DT_UPDATEDL',
    187 => 'DT_UPDATEEDITNUM',
    188 => 'ET_ADDLINE',
    189 => 'ET_DROPLINE',
    190 => 'ET_FLUSHEDITTEXT',
    191 => 'ET_GETLINE',
    192 => 'ET_GETLINELEN',
    193 => 'ET_INIT',
    194 => 'ET_INSERT',
    195 => 'ET_PATCHLINES',
    196 => 'ET_POPEL',
    197 => 'ET_PUSHEL',
    198 => 'ET_REMOVE',
    199 => 'ET_SETTEXT',
    200 => 'ET_UPDATEEL',
    201 => 'IE_ADDTEXT',
    202 => 'IE_COMPACTWINFMT',
    203 => 'IE_DELETE',
    204 => 'IE_EXPORT',
    205 => 'IE_EXPORTWINFMT',
    206 => 'IE_GETLINELEN',
    207 => 'IE_GETSTARTPOS',
    208 => 'IE_IPTTOEL',
    209 => 'IE_IMPORT',
    210 => 'IE_INSERTSTRING',
    211 => 'IE_INSERTTEXT',
    212 => 'IE_ISCREMBEDDED',
    213 => 'IE_ISSLB',
    214 => 'IE_NONWWLINE',
    215 => 'IE_QUERYLINELEN',
    216 => 'IE_QUERYTEXTLEN',
    217 => 'MLEC_ADJUSTOFFSET',
    218 => 'MLEC_BACKSPACE',
    219 => 'MLEC_CHTOCX',
    220 => 'MLEC_CHTOCY',
    221 => 'MLEC_CHTOPT',
    222 => 'MLEC_CLEAR',
    223 => 'MLEC_COPY',
    224 => 'MLEC_CREATECURSOR',
    225 => 'MLEC_CREATEINSTANCE',
    226 => 'MLEC_CXTOCH',
    227 => 'MLEC_CYTODL',
    228 => 'MLEC_DELKEY',
    229 => 'MLEC_DESTROYCURSOR',
    230 => 'MLEC_ENDHOMEKEYS',
    231 => 'MLEC_GENTABS',
    232 => 'MLEC_INIT',
    233 => 'MLEC_INITDBCSEV',
    234 => 'MLEC_INITPEN',
    235 => 'MLEC_INITUNDO',
    236 => 'MLEC_INSERTKEY',
    237 => 'MLEC_ISDBCSBYTE',
    238 => 'MLEC_ISMOUSEINMLE',
    239 => 'MLEC_ISMOUSEINVIEW',
    240 => 'MLEC_ISPTINMARGIN',
    241 => 'MLEC_ISPTINRECT',
    242 => 'MLEC_KEYBOARD',
    243 => 'MLEC_LARROWKEY',
    244 => 'MLEC_NBYTES',
    245 => 'MLEC_NCHARS',
    246 => 'MLEC_NEWLINE',
    247 => 'MLEC_NEXTCHAR',
    248 => 'MLEC_OTHERKEYS',
    249 => 'MLEC_OVERTYPEDMODE',
    250 => 'MLEC_PAGESCRL',
    251 => 'MLEC_PASTE',
    252 => 'MLEC_PERFORMUNDO',
    253 => 'MLEC_POSTOWNERMSG',
    254 => 'MLEC_PRESPARAMCHANGED',
    255 => 'MLEC_PREVCHAR',
    256 => 'MLEC_PTTOCH',
    257 => 'MLEC_QUERYFONT',
    258 => 'MLEC_QUERYPARAMS',
    259 => 'MLEC_QUERYTEXT',
    260 => 'MLEC_RARROWKEY',
    261 => 'MLEC_SAVEREDO',
    262 => 'MLEC_SAVEUNDO',
    263 => 'MLEC_SEARCH',
    264 => 'MLEC_SENDOWNERMSG',
    265 => 'MLEC_SETFOCUS',
    266 => 'MLEC_SETFONT',
    267 => 'MLEC_SETPPFONT',
    268 => 'MLEC_SETPARAMS',
    269 => 'MLEC_SETRECT',
    270 => 'MLEC_SETSYSVALUES',
    271 => 'MLEC_SIZE',
    272 => 'MLEC_STRLEN',
    273 => 'MLEC_STRTOPIX',
    274 => 'MLEC_STRWIDTH',
    275 => 'MLEC_TRACKMOUSE',
    276 => 'MLEC_UDARROWKEYS',
    277 => 'MLEC_UPDATEHSB',
    278 => 'MLEC_UPDATEVSB',
    279 => 'REMOVENEWTEXT',
    280 => 'REMOVEOLDTEXT',
    281 => 'RESETREDO',
    282 => 'RESTORENEWTEXT',
    283 => 'RESTOREOLDTEXT',
    284 => 'DrgLazyDrag',
    285 => 'DrgCancelLazyDrag',
    286 => 'DrgLazyDrop',
    287 => 'DrgQueryDragInfoPtr',
    288 => 'DrgQueryDragInfoPtrFromHWND',
    289 => 'DrgQueryDragInfoPtrFromDragItem',
    290 => 'DrgQueryDragStatus',
    291 => 'DrgReallocDragInfo',
    292 => 'PaxChooseFont',
    293 => 'WinDefColorDlgProc',
    294 => 'WinColorDlg',
    295 => 'DaxOpenSave',
    296 => 'WinFindDlg',
    297 => 'WinDefFindDlgProc',
    298 => 'WinReplaceDlg',
    299 => 'WinDefReplaceDlgProc',
    300 => 'WinPrintDlg',
    301 => 'WinDefPrintDlgProc',
  },

  'PMSPL' => {
    1 => 'SplQmOpen',
    2 => 'SplQmStartDoc',
    3 => 'SplQmEndDoc',
    4 => 'SplQmWrite',
    5 => 'SplQmAbort',
    6 => 'SplQmClose',
    7 => 'SplMessageBox',
    8 => 'SplQmAbortDoc',
    10 => 'SplQmSpoolerPresent',
    11 => 'SplQmChooseLogAddr',
    12 => 'SplQmInitialize',
    13 => 'SplQmTerminate',
    15 => 'SplPrmSpool',
    16 => 'SplQmCancelWaitingJobs',
    17 => 'SplQmCancelPrintingJob',
    19 => 'SplVqIfInit',
    20 => 'SplInit',
    21 => 'SplQmListQueues',
    22 => 'SplQmQueryQInfo',
    23 => 'SplQmListJobs',
    24 => 'SplQmQueryJInfo',
    25 => 'SplQmHoldQueue',
    26 => 'SplQmReleaseQueue',
    27 => 'SplQmHoldJob',
    28 => 'SplQmReleaseJob',
    29 => 'SplQmCancelJob',
    30 => 'SplQmRestartJob',
    31 => 'SplQmRepeatJob',
    32 => 'SplQmPrintJobNext',
    33 => 'SplQmQueryPInfo',
    34 => 'SplQmChangeJobPrty',
    35 => 'SplQmWriteFile',
    36 => 'SplQmSetStatus',
    50 => 'SplStdOpen',
    51 => 'SplStdClose',
    52 => 'SplStdStart',
    53 => 'SplStdStop',
    54 => 'SplStdDelete',
    55 => 'SplStdGetBits',
    56 => 'SplStdQueryLength',
    68 => 'SplProfileWriteCheck',
    69 => 'ProfileValidationHook',
    70 => 'PrtOpen',
    71 => 'PrtWrite',
    72 => 'PrtDevIoctl',
    73 => 'PrtClose',
    75 => 'PrtAbort',
    76 => 'Prt16Query',
    77 => 'Prt16Set',
    78 => 'Prt16AbortDoc',
    79 => 'Prt16ResetAbort',
    80 => 'DosPrintDestControl',
    81 => 'DosPrintDestGetInfo',
    82 => 'DosPrintDestEnum',
    84 => 'DosPrintJobContinue',
    85 => 'DosPrintJobPause',
    86 => 'DosPrintJobDel',
    87 => 'DosPrintJobSchedule',
    88 => 'DosPrintJobAdd',
    89 => 'DosPrintJobAdd2',
    90 => 'DosPrintJobGetInfo',
    91 => 'DosPrintJobSetInfo',
    92 => 'DosPrintJobEnum',
    93 => 'DosPrintQAdd',
    94 => 'DosPrintQPause',
    95 => 'DosPrintQContinue',
    96 => 'DosPrintQDel',
    97 => 'DosPrintQGetInfo',
    98 => 'DosPrintQSetInfo',
    99 => 'DosPrintQEnum',
    101 => 'DosPrintDestAdd',
    102 => 'DosPrintDestSetInfo',
    103 => 'DosPrintDestDel',
    104 => 'DosPrintQPurge',
    105 => 'DosPrintJobGetId',
    106 => 'DosPrintDriverEnum',
    107 => 'DosPrintQProcessOrEnum',
    108 => 'DosPrintPortEnum',
    110 => 'WprintDestControl',
    111 => 'WprintDestGetInfo',
    112 => 'WprintDestEnum',
    113 => 'WprintJobContinue',
    114 => 'WprintJobPause',
    115 => 'WprintJobDel',
    116 => 'WprintJobGetInfo',
    117 => 'WprintJobSetInfo',
    118 => 'WprintJobEnum',
    119 => 'WprintQAdd',
    120 => 'WprintQPause',
    121 => 'WprintQContinue',
    122 => 'WprintQDel',
    123 => 'WprintQGetInfo',
    124 => 'WprintQSetInfo',
    125 => 'WprintQEnum',
    126 => 'WprintDestAdd',
    127 => 'WprintDestSetInfo',
    128 => 'WprintDestDel',
    129 => 'WprintQPurge',
    130 => 'WprintDriverEnum',
    131 => 'WprintQProcessOrEnum',
    132 => 'WprintPortEnum',
    133 => 'WprintJobCopy',
    134 => 'WprintDriverGetInfo',
    135 => 'WprintDriverSetInfo',
    136 => 'WprintJobMove',
    137 => 'WprintJobMoveAll',
    138 => 'Wprt16Set',
    140 => 'SplQmQueryPrintRes',
    141 => 'Spl32EnumPrinter',
    142 => 'Spl32CopyJob',
    143 => 'Spl32QmSetup',
    144 => 'SplFileDlgProc',
    168 => 'Spl32ProfileWriteCheck',
    200 => 'NetSplqmOpen',
    201 => 'NetSplqmStartDoc',
    202 => 'NetSplqmWrite',
    203 => 'NetSplqmEndDoc',
    204 => 'NetSplqmClose',
    205 => 'NetSplqmAbort',
    206 => 'NetSplqmAbortDoc',
    301 => 'Spl32QmOpen',
    302 => 'Spl32QmStartDoc',
    303 => 'Spl32QmEndDoc',
    304 => 'Spl32QmWrite',
    305 => 'Spl32QmAbort',
    306 => 'Spl32QmClose',
    307 => 'Spl32MessageBox',
    308 => 'Spl32QmAbortDoc',
    310 => 'Spl32QmSpoolerPresent',
    311 => 'Spl32QmChooseLogAddr',
    312 => 'Spl32QmInitialize',
    313 => 'Spl32QmTerminate',
    315 => 'Spl32PrmSpool',
    316 => 'Spl32QmCancelWaitingJobs',
    317 => 'Spl32QmCancelPrintingJob',
    319 => 'Spl32VqIfInit',
    320 => 'Spl32Init',
    350 => 'Spl32StdOpen',
    351 => 'Spl32StdClose',
    352 => 'Spl32StdStart',
    353 => 'Spl32StdStop',
    354 => 'Spl32StdDelete',
    355 => 'Spl32StdGetBits',
    356 => 'Spl32StdQueryLength',
    370 => 'Prt32Open',
    371 => 'Prt32Write',
    372 => 'Prt32DevIOCtl',
    373 => 'Prt32Close',
    375 => 'Prt32Abort',
    380 => 'SplControlDevice',
    381 => 'SplQueryDevice',
    382 => 'SplEnumDevice',
    384 => 'SplReleaseJob',
    385 => 'SplHoldJob',
    386 => 'SplDeleteJob',
    390 => 'SplQueryJob',
    391 => 'SplSetJob',
    392 => 'SplEnumJob',
    393 => 'SplCreateQueue',
    394 => 'SplHoldQueue',
    395 => 'SplReleaseQueue',
    396 => 'SplDeleteQueue',
    397 => 'SplQueryQueue',
    398 => 'SplSetQueue',
    399 => 'SplEnumQueue',
    401 => 'SplCreateDevice',
    402 => 'SplSetDevice',
    403 => 'SplDeleteDevice',
    404 => 'SplPurgeQueue',
    405 => 'SplQueryJobId',
    406 => 'SplEnumDriver',
    407 => 'SplEnumQueueProcessor',
    408 => 'SplEnumPort',
    410 => 'SplQueryPort',
    411 => 'SplSetPort',
    412 => 'SplQueryPath',
    413 => 'SplCreatePort',
    414 => 'SplDeletePort',
    440 => 'Spl32QmQueryPrintRes',
    441 => 'SplEnumPrinter',
    442 => 'SplCopyJob',
    443 => 'SplQmSetup',
    444 => 'SplQueryJobFile',
    445 => 'SplRenameQueue',
    446 => 'SplQueryDriver',
    447 => 'SplSetDriver',
    448 => 'SplMoveJob',
    449 => 'SplMoveAllJobs',
    480 => 'SplThkControlDevice',
    481 => 'SplThkQueryDevice',
    482 => 'SplThkEnumDevice',
    483 => 'SplThkReleaseJob',
    484 => 'SplThkHoldJob',
    485 => 'SplThkDeleteJob',
    486 => 'SplThkQueryJob',
    487 => 'SplThkSetJob',
    488 => 'SplThkEnumJob',
    489 => 'SplThkCreateQueue',
    490 => 'SplThkHoldQueue',
    491 => 'SplThkReleaseQueue',
    492 => 'SplThkDeleteQueue',
    493 => 'SplThkQueryQueue',
    494 => 'SplThkSetQueue',
    495 => 'SplThkEnumQueue',
    496 => 'SplThkCreateDevice',
    497 => 'SplThkSetDevice',
    498 => 'SplThkDeleteDevice',
    499 => 'SplThkPurgeQueue',
    501 => 'SplThkEnumDriver',
    502 => 'SplThkEnumQueueProcessor',
    503 => 'SplThkEnumPort',
    504 => 'SplThkEnumPrinter',
    505 => 'SplThkCopyJob',
    506 => 'SplThkQueryJobFile',
    507 => 'SplThkQueryDriver',
    508 => 'SplThkSetDriver',
    509 => 'SplThkMoveJob',
    510 => 'SplThkMoveAllJobs',
    600 => 'PrtResetAbort',
    601 => 'PrtAbortDoc',
    602 => 'PrtNewPage',
    603 => 'PrtQuery',
    604 => 'PrtSet',
    605 => 'SplProtSendCmd',
    606 => 'SplProtXlateCmd',
    607 => 'SplQmNewPage',
    608 => 'SplQmGetJobID',
    609 => 'SplAlert',
    610 => 'SplDisable',
    611 => 'SplEnable',
    612 => 'SplRegister',
    613 => 'SplUnRegister',
    614 => 'SplRegisterControlPanel',
    615 => 'SplQueryControlPanel',
    616 => 'SplDisplayControlPanel',
    617 => 'SplGetPortFromQ',
    618 => 'SplGetControlPanelList',
    619 => 'SplPrinterOpen',
    620 => 'SplNotifyLogon',
    621 => 'SplPrinterClose',
    622 => 'SplPrinterWrite',
    623 => 'SplPrinterPrintFile',
    625 => 'SplSynchDrivers',
  },

  'PMDRAG' => {
    1 => 'DrgAccessDraginfo',
    2 => 'DrgAddStrHandle',
    3 => 'DrgAllocDraginfo',
    4 => 'DrgAllocDragtransfer',
    5 => 'DrgDeleteDraginfoStrHandles',
    6 => 'DrgDeleteStrHandle',
    7 => 'DrgDrag',
    8 => 'DrgFreeDraginfo',
    9 => 'DrgFreeDragtransfer',
    10 => 'DrgGetPS',
    11 => 'DrgPostTransferMsg',
    12 => 'DrgPushDraginfo',
    13 => 'DrgQueryDragitem',
    14 => 'DrgQueryDragitemCount',
    15 => 'DrgQueryDragitemPtr',
    16 => 'DrgQueryNativeRMF',
    17 => 'DrgQueryNativeRMFLen',
    18 => 'DrgQueryStrName',
    19 => 'DrgQueryStrNameLen',
    20 => 'DrgQueryTrueType',
    21 => 'DrgQueryTrueTypeLen',
    22 => 'DrgReleasePS',
    23 => 'DrgSendTransferMsg',
    24 => 'DrgSetDragPointer',
    25 => 'DrgSetDragImage',
    26 => 'DrgSetDragItem',
    27 => 'DrgVerifyNativeRMF',
    28 => 'DrgVerifyRMF',
    29 => 'DrgVerifyTrueType',
    30 => 'DrgVerifyType',
    31 => 'DrgVerifyTypeSet',
    32 => 'Drg32AccessDraginfo',
    33 => 'Drg32AddStrHandle',
    34 => 'Drg32AllocDraginfo',
    35 => 'Drg32AllocDragtransfer',
    36 => 'Drg32DeleteDraginfoStrHandles',
    37 => 'Drg32DeleteStrHandle',
    38 => 'Drg32Drag',
    39 => 'Drg32FreeDraginfo',
    40 => 'Drg32FreeDragtransfer',
    41 => 'Drg32GetPS',
    42 => 'Drg32PostTransferMsg',
    43 => 'Drg32PushDraginfo',
    44 => 'Drg32QueryDragitem',
    45 => 'Drg32QueryDragitemCount',
    46 => 'Drg32QueryDragitemPtr',
    47 => 'Drg32QueryNativeRMF',
    48 => 'Drg32QueryNativeRMFLen',
    49 => 'Drg32QueryStrName',
    50 => 'Drg32QueryStrNameLen',
    51 => 'Drg32QueryTrueType',
    52 => 'Drg32QueryTrueTypeLen',
    53 => 'Drg32ReleasePS',
    54 => 'Drg32SendTransferMsg',
    55 => 'Drg32SetDragPointer',
    56 => 'Drg32SetDragImage',
    57 => 'Drg32SetDragitem',
    58 => 'Drg32VerifyNativeRMF',
    59 => 'Drg32VerifyRMF',
    60 => 'Drg32VerifyTrueType',
    61 => 'Drg32VerifyType',
    62 => 'Drg32VerifyTypeSet',
    63 => 'DrgDragFiles',
    64 => 'DrgAcceptDroppedFiles',
    65 => 'Drg32DragFiles',
    66 => 'Drg32AcceptDroppedFiles',
    67 => 'DrgLazyDrag',
    68 => 'DrgCancelLazyDrag',
    69 => 'DrgLazyDrop',
    70 => 'DrgQueryDraginfoPtr',
    71 => 'DrgQueryDraginfoPtrFromHwnd',
    72 => 'DrgQueryDraginfoPtrFromDragitem',
    73 => 'DrgQueryDragStatus',
    74 => 'DrgReallocDraginfo',
    75 => 'Drg32QueryFormat',
    76 => 'DrgGetClipPS',
  },

  'PMMERGE' => {
    2000 => 'ShePIInitialise',
    2001 => 'WinQueryProfileInt',
    2002 => 'WinQueryProfileString',
    2003 => 'WinWriteProfileString',
    2004 => 'WinQueryProfileSize',
    2005 => 'WinQueryProfileData',
    2006 => 'WinWriteProfileData',
    2007 => 'PrfChangeWriteThru',
    2008 => 'PMExecRegister',
    2009 => 'ShePIInitIniFiles',
    2010 => 'SheConvert190ProgramListTo300',
    2011 => 'PrfQueryProfileInt',
    2012 => 'PrfQueryProfileString',
    2013 => 'PrfWriteProfileString',
    2014 => 'PrfQueryProfileSize',
    2015 => 'PrfQueryProfileData',
    2016 => 'PrfWriteProfileData',
    2017 => 'PrfOpenProfile',
    2018 => 'PrfCloseProfile',
    2019 => 'PrfReset',
    2020 => 'PrfQueryProfile',
    2021 => 'PrfAddProgram',
    2022 => 'PrfRemoveProgram',
    2023 => 'PrfChangeProgram',
    2024 => 'PrfQueryDefinition',
    2025 => 'PrfQueryProgramTitles',
    2026 => 'PrfCreateGroup',
    2027 => 'PrfQueryProgramHandle',
    2028 => 'PrfQueryProgramCategory',
    2029 => 'PrfDestroyGroup',
    2030 => 'SheProfileHook',
    2031 => 'SheInitializeIniFile',
    2032 => 'ShpPI16LockIniFile',
    2033 => 'ShpPI16Shutdown',
    2034 => 'EnablePMPre',
    2035 => 'InnerGreEntry',
    2036 => 'GreInitialize',
    2037 => 'GreEntry2',
    2038 => 'GreEntry3',
    2039 => 'GreEntry4',
    2040 => 'GreEntry5',
    2041 => 'GreEntry6',
    2042 => 'GreEntry7',
    2043 => 'GreEntry8',
    2044 => 'GreEntry9',
    2045 => 'GreEntry10',
    2046 => 'GetDriverInfo',
    2047 => 'SetDriverInfo',
    2048 => 'PostDeviceModes',
    2049 => 'BitmapLimitWarning',
    2050 => 'PmWinGreEntry2',
    2051 => 'PmWinGreEntry3',
    2052 => 'PmWinGreEntry4',
    2053 => 'PmWinGreEntry5',
    2054 => 'PmWinGreEntry6',
    2055 => 'PmWinGreEntry7',
    2056 => 'PmWinGreEntry8',
    2057 => 'PmWinGreEntry9',
    2058 => 'PmWinGreEntry10',
    2059 => 'SSAllocSeg',
    2060 => 'SSAllocHuge',
    2061 => 'SSFreeSeg',
    2062 => 'SSFlushSegs',
    2063 => 'RamSemRequest16',
    2064 => 'RamSemClear16',
    2065 => 'WinQueryClassInfo',
    2066 => 'WinMultWindowFromIDs',
    2067 => 'WinLockWindow',
    2068 => 'WinQueryWindowLockCount',
    2069 => 'WinLoadPointer',
    2070 => 'WinCreatePointer',
    2071 => 'WinDestroyPointer',
    2072 => 'OldWinQueryPointerInfo',
    2073 => 'WinQuerySysPointer',
    2074 => 'WinGetSysBitmap',
    2075 => 'WinQueryCursorInfo',
    2076 => 'WinLoadAccelTable',
    2077 => 'WinCreateAccelTable',
    2078 => 'WinDestroyAccelTable',
    2079 => 'WinCopyAccelTable',
    2080 => 'WinSetClipbrdData',
    2081 => 'WinQueryClipbrdFmtInfo',
    2082 => 'GpiLoadBitmap',
    2083 => 'WinLoadString',
    2084 => 'WinLoadMessage',
    2085 => 'WinSetRectEmpty',
    2086 => 'WinSetRect',
    2087 => 'WinCopyRect',
    2088 => 'WinIsRectEmpty',
    2089 => 'WinPtInRect',
    2090 => 'WinOffsetRect',
    2091 => 'WinInflateRect',
    2092 => 'WinMakeRect',
    2093 => 'WinMakePoints',
    2094 => 'WinDefWindowProc',
    2095 => 'WinDefDlgProc',
    2096 => 'WinQueryHungProcess',
    2097 => 'WinLoadStringTable',
    2098 => 'WinLoadVkeyGlyphXlatetbl',
    2099 => 'WinLoadCharXlatetbl',
    2100 => 'WinSetVkeyGlyphXlatetbl',
    2101 => 'WinQueryVkeyGlyphXlatetbl',
    2102 => 'WinVkeyToScanID',
    2103 => 'WinQueryProcessCP',
    2104 => 'WinGetKeyState',
    2105 => 'WinSetCp',
    2106 => 'WinQueryCp',
    2107 => 'WinQueryCpList',
    2108 => 'WinCpTranslateString',
    2109 => 'WinCpTranslateChar',
    2110 => 'WinCompareStrings',
    2111 => 'WinUpper',
    2112 => 'WinUpperChar',
    2113 => 'WinNextChar',
    2114 => 'WinPrevChar',
    2115 => 'WinCreateHeap',
    2116 => 'WinDestroyHeap',
    2117 => 'WinAvailMem',
    2118 => 'WinAllocMem',
    2119 => 'WinReallocMem',
    2120 => 'WinFreeMem',
    2121 => 'WinLockHeap',
    2122 => 'WinCreateAtomTable',
    2123 => 'WinDestroyAtomTable',
    2124 => 'WinAddAtom',
    2125 => 'WinFindAtom',
    2126 => 'WinDeleteAtom',
    2127 => 'WinQueryAtomUsage',
    2128 => 'WinQueryAtomLength',
    2129 => 'WinQueryAtomName',
    2130 => 'WinQuerySystemAtomTable',
    2131 => 'WinSetLastError',
    2132 => 'WinGetLastError',
    2133 => 'WinGetErrorInfo',
    2134 => 'WinFreeErrorInfo',
    2135 => 'WinInitialize',
    2136 => 'WinTerminate',
    2137 => 'WinCatch',
    2138 => 'WinThrow',
    2139 => 'WinQueryVersion',
    2140 => 'FsrSemExit',
    2141 => 'FsrSemCheck',
    2142 => 'AabGetReg',
    2143 => 'AabSetReg',
    2144 => 'ValidateSelector',
    2145 => 'LoadModuleHandle',
    2146 => 'GetScreenSelector',
    2147 => 'IdentifyCodeSelector',
    2148 => '_WinSetErrorInfo',
    2149 => 'WinTerminateSystem',
    2150 => 'WinDefQueueProc',
    2151 => 'WinVisRegionNotify',
    2152 => 'WinQueryKbdLayout',
    2153 => 'WinSetKbdLayout',
    2154 => 'WinBuildPtrHandle',
    2155 => 'DumWinCreateHelpInstance',
    2156 => 'DimWinDestroyHelpInstance',
    2157 => 'DumWinAssociateHelpInstance',
    2158 => 'DimWinCreateHelpTable',
    2159 => 'DumWinLoadHelpTable',
    2160 => 'DumWinQueryHelpInstance',
    2161 => 'DummyHelpEntry',
    2162 => 'GetPMDDCodeSelector',
    2163 => 'WinQueryPwnd',
    2164 => 'WinEnumVKeyScanIDs',
    2165 => 'WinLoadTranslationTable',
    2166 => 'WinSetKbdLayout2',
    2167 => 'DebugInputEnable',
    2168 => 'DebugInput',
    2169 => 'DebugOutput',
    2170 => 'DebugCurPos',
    2171 => 'DebugCls',
    2172 => 'DebugRedirect',
    2173 => 'WinLangsupWindowProc',
    2174 => 'WinLangsupDlgProc',
    2175 => 'WinCreatePointerIndirect',
    2176 => 'WinQueryPointerInfo',
    2177 => 'WinPortHoleUtil',
    2178 => 'WinCreateFarHeap',
    2179 => 'WinDestroyFarHeap',
    2180 => 'WinAllocFarMem',
    2181 => 'WinFreeFarMem',
    2182 => 'WinReallocFarMem',
    2183 => 'WinSetQueueProc',
    3000 => 'FarFlushBufHook',
    3001 => 'fnBadAppDlgProc',
    3002 => 'InputGetDeviceInfo16',
    3003 => 'lpfnIconWndProc',
    3004 => 'lpfnShellWndProc',
    3005 => 'SheStartLongProgram',
    3006 => 'SheSystemShutdown',
    3007 => 'SheUpdateIniFile',
    3008 => 'ShlLoadPublicFonts',
    3009 => 'ShlUnloadPublicFonts',
    3010 => 'ShpLockProgramList',
    3011 => 'ShpUnlockProgramList',
    3012 => 'StartStartUpDotCmd',
    3013 => 'StartSystemExecutables',
    3014 => 'WinAlarm',
    3015 => 'WinBeginEnumWindows',
    3016 => 'WinBeginPaint',
    3017 => 'WinBroadcastMsg',
    3018 => 'WinCancelMode',
    3019 => 'WinCancelShutdown',
    3020 => 'WinCreateMsgQueue',
    3021 => 'WinCreateStdWindow',
    3022 => 'WinCreateWindow',
    3023 => 'WinDestroyMsgQueue',
    3024 => 'WinDestroyWindow',
    3025 => 'WinDispatchMsg',
    3026 => 'WinDrawText',
    3027 => 'WinEndPaint',
    3028 => 'WinFillRect',
    3029 => 'WinGetMinWindowViewer',
    3030 => 'WinGetMsg',
    3031 => 'WinGetNextWindow',
    3032 => 'WinInitializeSystem',
    3033 => 'WinInvalidateRect',
    3034 => 'WinIsChild',
    3035 => 'WinIsWindow',
    3036 => 'WinIsWindowVisible',
    3037 => 'WinLoadDlg',
    3038 => 'WinLockStartInput',
    3039 => 'WinMessageBox',
    3040 => 'WinMsgSemWait',
    3041 => 'WinOpenWindowDC',
    3042 => 'WinPeekMsg',
    3043 => 'WinPostMsg',
    3044 => 'WinProcessDlg',
    3045 => 'WinQueryActiveWindow',
    3046 => 'WinQueryAnchorBlock',
    3047 => 'WinQueryDesktopWindow',
    3048 => 'WinQueryFocus',
    3049 => 'WinQueryQueueInfo',
    3050 => 'WinQuerySysModalWindow',
    3051 => 'WinQuerySysValue',
    3052 => 'WinQueryWindow',
    3053 => 'WinQueryWindowPos',
    3054 => 'WinQueryWindowProcess',
    3055 => 'WinQueryWindowRect',
    3056 => 'WinQueryWindowULong',
    3057 => 'WinQueryWindowUShort',
    3058 => 'WinRegisterClass',
    3059 => 'WinResetSystem',
    3060 => 'WinScreenSwitch',
    3061 => 'WinSendDlgItemMsg',
    3062 => 'WinSendMsg',
    3063 => 'WinSetActiveWindow',
    3064 => 'WinSetDlgItemText',
    3065 => 'WinSetFocus',
    3066 => 'WinSetMultWindowPos',
    3067 => 'WinSetParent',
    3068 => 'WinSetPresParam',
    3069 => 'WinSetSysModalWindow',
    3070 => 'WinSetSysValue',
    3071 => 'WinSetWindowBits',
    3072 => 'WinSetWindowPos',
    3073 => 'WinSetWindowText',
    3074 => 'WinShowWindow',
    3075 => 'WinSubclassWindow',
    3076 => 'WinTerminateShutdown',
    3077 => 'WinTrackRect',
    3078 => 'WinWindowFromID',
    3079 => 'WinAddProgram',
    3080 => 'WinAddSwitchEntry',
    3081 => 'WinAddToGroup',
    3082 => 'WinCalcFrameRect',
    3083 => 'WinCallHelpHook',
    3084 => 'WinCallMsgFilter',
    3085 => 'WinCanTerminate',
    3086 => 'WinChangeProgram',
    3087 => 'WinChangeSwitchEntry',
    3088 => 'WinCheckInput',
    3089 => 'WinCloseClipbrd',
    3090 => 'WinCplRegister',
    3091 => 'WinCreateCursor',
    3092 => 'WinCreateDlg',
    3093 => 'WinCreateFrameControls',
    3094 => 'WinCreateGroup',
    3095 => 'WinCreateMenu',
    3096 => 'WinCreateSwitchEntry',
    3097 => 'WinDdeInitiate',
    3098 => 'WinDdePostMsg',
    3099 => 'WinDdeRespond',
    3100 => 'WinDebugBreak',
    3101 => 'WinDeleteLibrary',
    3102 => 'WinDeleteProcedure',
    3103 => 'WinDestroyAniPointer',
    3104 => 'WinDestroyCursor',
    3105 => 'WinDestroyGroup',
    3106 => 'WinDismissDlg',
    3107 => 'WinDlgBox',
    3108 => 'WinDrawBitmap',
    3109 => 'WinDrawBorder',
    3110 => 'WinDrawPointer',
    3111 => 'WinEmptyClipbrd',
    3112 => 'WinEnablePhysInput',
    3113 => 'WinEnableWindow',
    3114 => 'WinEnableWindowUpdate',
    3115 => 'WinEndEnumWindows',
    3116 => 'WinEndProgram',
    3117 => 'WinEndSession',
    3118 => 'WinEndWindowSession',
    3119 => 'WinEnumClipbrdFmts',
    3120 => 'WinEnumDlgItem',
    3121 => 'WinEqualRect',
    3122 => 'WinExcludeUpdateRegion',
    3123 => 'WinExplodeWindow',
    3124 => 'WinFlashWindow',
    3125 => 'WinFocusChange',
    3126 => 'WinForceMenuRedraw',
    3127 => 'WinFormatFrame',
    3128 => 'WinGetClipPS',
    3129 => 'WinGetCurrentTime',
    3130 => 'WinGetDlgMsg',
    3131 => 'WinGetErasePS',
    3132 => 'WinGetFrameTreePPs',
    3133 => 'WinGetFrameTreePPSize',
    3134 => 'WinGetMaxPosition',
    3135 => 'WinGetMinPosition',
    3136 => 'WinGetPhysKeyState',
    3137 => 'WinGetPS',
    3138 => 'WinGetScanState',
    3139 => 'WinGetScreenPS',
    3140 => 'WinHAPPfromPID',
    3141 => 'WinHSWITCHfromHAPP',
    3142 => 'WinInitializePL',
    3143 => 'WinInitSession',
    3144 => 'WinInitSessionMgr',
    3145 => 'WinInitSwEntry',
    3146 => 'WinInSendMsg',
    3147 => 'WinInstStartApp',
    3148 => 'WinIntersectRect',
    3149 => 'WinInvalidateRegion',
    3150 => 'WinInvertRect',
    3151 => 'WinIsPhysInputEnabled',
    3152 => 'WinIsShuttingDown',
    3153 => 'WinIsThreadActive',
    3154 => 'WinIsWindowEnabled',
    3155 => 'WinIsWindowShowing',
    3156 => 'WinJiggleMouse',
    3157 => 'WinLoadAniPointer',
    3158 => 'WinLoadLibrary',
    3159 => 'WinLoadMenu',
    3160 => 'WinLoadProcedure',
    3161 => 'WinLockInput',
    3162 => 'WinLockPointerUpdate',
    3163 => 'WinLockVisRegions',
    3164 => 'WinLockWindowUpdate',
    3165 => 'WinMapDlgPoints',
    3166 => 'WinMapWindowPoints',
    3167 => 'WinMenuIndexFromID',
    3168 => 'WinMsgMuxSemWait',
    3169 => 'WinNoShutdown',
    3170 => 'WinOpenClipbrd',
    3171 => 'WinPMFileRegister',
    3172 => 'WinPopupMenu',
    3173 => 'WinPostQueueMsg',
    3174 => 'WinQueryAccelTable',
    3175 => 'WinQueryAccelTableValue',
    3176 => 'WinQueryCapture',
    3177 => 'WinQueryCharXlatetbl',
    3178 => 'WinQueryClassName',
    3179 => 'WinQueryClassThunkProc',
    3180 => 'WinQueryClipbrdData',
    3181 => 'WinQueryClipbrdOwner',
    3182 => 'WinQueryClipbrdViewer',
    3183 => 'WinQueryDefinition',
    3184 => 'WinQueryDesktopBkgnd',
    3185 => 'WinQueryDlgItemShort',
    3186 => 'WinQueryDlgItemText',
    3187 => 'WinQueryDlgItemTextLength',
    3188 => 'WinQueryExtIDFocus',
    3189 => 'WinQueryFileExtOpts',
    3190 => 'WinQueryMenuData',
    3191 => 'WinQueryMsgPos',
    3192 => 'WinQueryMsgTime',
    3193 => 'WinQueryObjectWindow',
    3194 => 'WinQueryPointer',
    3195 => 'WinQueryPointerPos',
    3196 => 'WinQueryPresParam',
    3197 => 'WinQueryProgramTitles',
    3198 => 'WinQueryProgramType',
    3199 => 'WinQueryProgramUse',
    3200 => 'WinQueryQueueStatus',
    3201 => 'WinQuerySendMsg',
    3202 => 'WinQuerySessionTitle',
    3203 => 'WinQueryState',
    3204 => 'WinQuerySwitchEntry',
    3205 => 'WinQuerySwitchHandle',
    3206 => 'WinQuerySwitchList',
    3207 => 'WinQuerySysColor',
    3208 => 'WinQueryTaskSizePos',
    3209 => 'WinQueryTaskTitle',
    3210 => 'WinQueryUpdateRect',
    3211 => 'WinQueryUpdateRegion',
    3212 => 'WinQueryWindowDC',
    3213 => 'WinQueryWindowModel',
    3214 => 'WinQueryWindowPtr',
    3215 => 'WinQueryWindowSGID',
    3216 => 'WinQueryWindowText',
    3217 => 'WinQueryWindowTextLength',
    3218 => 'WinQueryWindowThunkProc',
    3219 => 'WinQueryWorkplaceWindow',
    3220 => 'WinQueueFromID',
    3221 => 'WinRealizePalette',
    3222 => 'WinRegisterSeamlessProc',
    3223 => 'WinRegisterUserDatatype',
    3224 => 'WinRegisterUserMsg',
    3225 => 'WinRegisterWindowDestroy',
    3226 => 'WinReleaseErasePS',
    3227 => 'WinReleaseHook',
    3228 => 'WinReleasePS',
    3229 => 'WinRemoveFromGroup',
    3230 => 'WinRemovePresParam',
    3231 => 'WinRemoveProgram',
    3232 => 'WinRemoveSwitchEntry',
    3233 => 'WinReplyMsg',
    3234 => 'WinSaveWindowPos',
    3235 => 'WinScrollWindow',
    3236 => 'WinSeamlessBox',
    3237 => 'WinSemEnter',
    3238 => 'WinSemLeave',
    3239 => 'WinSemQuery',
    3240 => 'WinSendQueueMsg',
    3241 => 'WinSetAccelTable',
    3242 => 'WinSetAccelTableValue',
    3243 => 'WinSetAniPointer',
    3244 => 'WinSetAtomTableOwner',
    3245 => 'WinSetCapture',
    3246 => 'WinSetCharXlatetbl',
    3247 => 'WinSetClassMsgInterest',
    3248 => 'WinSetClassThunkProc',
    3249 => 'WinSetClipbrdOwner',
    3250 => 'WinSetClipbrdViewer',
    3251 => 'WinSetDesktopBkgnd',
    3252 => 'WinSetDlgItemShort',
    3253 => 'WinSetExtIDFocus',
    3254 => 'WinSetFgndWindow',
    3255 => 'WinSetFileExtOpts',
    3256 => 'WinSetFrameTreePPs',
    3257 => 'WinSetHook',
    3258 => 'WinSetKeyboardStateTable',
    3259 => 'WinSetMenuData',
    3260 => 'WinSetMsgInterest',
    3261 => 'WinSetMsgMode',
    3262 => 'WinSetOwner',
    3263 => 'WinSetPointer',
    3264 => 'WinSetPointerOwner',
    3265 => 'WinSetPointerPos',
    3266 => 'WinSetScanStateTable',
    3267 => 'WinSetSwEntry',
    3268 => 'WinSetSynchroMode',
    3269 => 'WinSetSysClipbrdViewer',
    3270 => 'WinSetSysColors',
    3271 => 'WinSetTitle',
    3272 => 'WinSetTitleAndIcon',
    3273 => 'WinSetWindowDC',
    3274 => 'WinSetWindowPtr',
    3275 => 'WinSetWindowThunkProc',
    3276 => 'WinSetWindowULong',
    3277 => 'WinSetWindowUShort',
    3278 => 'WinShowCursor',
    3279 => 'WinShowPointer',
    3280 => 'WinShowTrackRect',
    3281 => 'WinStartApp',
    3282 => 'WinStartTimer',
    3283 => 'WinStopProgram',
    3284 => 'WinStopTimer',
    3285 => 'WinStpRegister',
    3286 => 'WinStretchPointer',
    3287 => 'WinSubstituteStrings',
    3288 => 'WinSubtractRect',
    3289 => 'WinSwitchProgramRegister',
    3290 => 'WinSwitchToProgram2',
    3291 => 'WinSwitchToProgram',
    3292 => 'WinSwitchToTaskManager',
    3293 => 'WinSyncStartPgm',
    3294 => 'WinSystemShutdown',
    3295 => 'WinTerminateApp',
    3296 => 'WinThreadAssocQueue',
    3297 => 'WinTrackSeamless',
    3298 => 'WinTranslateAccel',
    3299 => 'WinTranslateChar',
    3300 => 'WinUnionRect',
    3301 => 'WinUpdateWindow',
    3302 => 'WinValidateRect',
    3303 => 'WinValidateRegion',
    3304 => 'WinVkeyGlyphCharXlate',
    3305 => 'WinWaitMsg',
    3306 => 'WinWakeThread',
    3307 => 'WinWindowFromDC',
    3308 => 'WinWindowFromPoint',
    3309 => 'WinSetTitleAndHwndIcon',
    3310 => 'WinTrackWindow',
    3500 => 'WinSetLangInfo',
    3501 => 'WinQueryLangInfo',
    3502 => 'WinSetKbdLayer',
    3503 => 'WinQueryKbdLayer',
    3504 => 'WinSetLangViewer',
    3505 => 'WinQueryLangViewer',
    3600 => 'WinPourEvent',
    3601 => 'WinSetMsgQimInfo',
    3602 => 'WinQueryMsgQimInfo',
    4000 => 'Devmode_Call_16',
    4001 => 'Devname_Call_16',
    4002 => 'Dispatch16Gate10',
    4003 => 'Dispatch16Gate3',
    4004 => 'Dispatch16Gate4',
    4005 => 'Dispatch16Gate5',
    4006 => 'Dispatch16Gate6',
    4007 => 'Dispatch16Gate7',
    4008 => 'Dispatch16Gate8',
    4009 => 'Dispatch16Gate9',
    4010 => 'Enable_Call_16',
    4011 => 'FsrSemEnter',
    4012 => 'FsrSemEnterP',
    4013 => 'FsrSemLeave',
    4014 => 'PFN10R2',
    4015 => 'PFN4R2',
    4016 => 'PFN5R2',
    4017 => 'PFN6R2',
    4018 => 'PFN7R2',
    4019 => 'PFN8R2',
    4020 => 'PFN9R2',
    4021 => 'DeleteBitmap16Call',
    4022 => 'Do16CLI',
    4023 => 'Do16STI',
    4024 => 'GRE16Callback',
    4025 => 'Dispatch32Gate',
    4026 => 'GRE16CallForwardReturn',
    4027 => 'FirePSProbe',
    5000 => 'AAB32GETREG',
    5001 => 'AAB32SETREG',
    5002 => 'AbnormalProcessExit',
    5003 => 'DEBUG32CLS',
    5004 => 'DEBUG32CURPOS',
    5005 => 'DEBUG32INPUT',
    5006 => 'DEBUG32OUTPUT',
    5007 => 'DestroyTimers',
    5008 => 'EDITAllocSpace',
    5009 => 'EditAutoSize',
    5010 => 'EditBackSpace',
    5011 => 'EditChangeFocus',
    5012 => 'EditChangeSelection',
    5013 => 'EditChar',
    5014 => 'EditCheckScroll',
    5015 => 'EditClear',
    5016 => 'EditCopy',
    5017 => 'EditCreate',
    5018 => 'EditCreateCursor',
    5019 => 'EditCreatePassword',
    5020 => 'EditCut',
    5021 => 'EditCXFromICH',
    5022 => 'EditDrawSubString',
    5023 => 'EditGetFlags',
    5024 => 'EditGetWindowRect',
    5025 => 'EditICHFromPt',
    5026 => 'EditNotify',
    5027 => 'EditPaint',
    5028 => 'EditPaste',
    5029 => 'EditPtFromICH',
    5030 => 'EditQueryPresParams',
    5031 => 'EditReplace',
    5032 => 'EditSetCursorPos',
    5033 => 'EditSetFirstIndex',
    5034 => 'EditSetInsertMode',
    5035 => 'EditSetSelection',
    5036 => 'EditSetText',
    5037 => 'EditSetWindowParams',
    5038 => 'EditShowChange',
    5039 => 'EditStopMouseTracking',
    5040 => 'EditTimerScroll',
    5041 => 'EditTrackMouse',
    5042 => 'EditVirtualKey',
    5043 => 'EditWMChar',
    5044 => 'Far32LockupHook',
    5045 => 'FarCallHook',
    5046 => 'GetDriverInfo32',
    5047 => 'Gpi32LoadBitmap',
    5048 => 'Gre32Entry10',
    5049 => 'Gre32Entry2',
    5050 => 'Gre32Entry3',
    5051 => 'Gre32Entry4',
    5052 => 'Gre32Entry5',
    5053 => 'Gre32Entry6',
    5054 => 'Gre32Entry7',
    5055 => 'Gre32Entry8',
    5056 => 'Gre32Entry9',
    5057 => 'GetIconWindowsEXE',
    5058 => 'GetIconWindowsICO',
    5059 => 'InnerGre32Entry10',
    5060 => 'InnerGre32Entry2',
    5061 => 'InnerGre32Entry3',
    5062 => 'InnerGre32Entry4',
    5063 => 'InnerGre32Entry5',
    5064 => 'InnerGre32Entry6',
    5065 => 'InnerGre32Entry7',
    5066 => 'InnerGre32Entry8',
    5067 => 'InnerGre32Entry9',
    5068 => 'InputGetDeviceInfo',
    5069 => 'PM32ExecRegister',
    5070 => 'PMReleaseMutexSem',
    5071 => 'PMRequestMutexSem',
    5072 => 'PMRequestMutexSemSetWait',
    5073 => 'PostDeviceModes32',
    5074 => 'Prf32AddProgram',
    5075 => 'Prf32ChangeProgram',
    5076 => 'Prf32ChangeWriteThru',
    5077 => 'Prf32CloseProfile',
    5078 => 'Prf32CreateGroup',
    5079 => 'Prf32DestroyGroup',
    5080 => 'Prf32OpenProfile',
    5081 => 'Prf32QueryDefinition',
    5082 => 'Prf32QueryProfile',
    5083 => 'Prf32QueryProfileData',
    5084 => 'Prf32QueryProfileInt',
    5085 => 'Prf32QueryProfileSize',
    5086 => 'Prf32QueryProfileString',
    5087 => 'Prf32QueryProgramCategory',
    5088 => 'Prf32QueryProgramHandle',
    5089 => 'Prf32QueryProgramTitles',
    5090 => 'Prf32RemoveProgram',
    5091 => 'Prf32Reset',
    5092 => 'Prf32WriteProfileData',
    5093 => 'Prf32WriteProfileString',
    5094 => 'PrfSuspendWriteToDisk',
    5095 => 'PrfWriteToDisk',
    5096 => 'RamSemClear32',
    5097 => 'RamSemRequest32',
    5098 => 'SetDriverInfo32',
    5099 => 'She32PIInitIniFiles',
    5100 => 'She32SystemShutdown',
    5101 => 'ShpPILockIniFile',
    5102 => 'ShpPIShutdown',
    5103 => 'SLEC_InitPen',
    5104 => 'SSAllocMem',
    5105 => 'SSFreeMem',
    5106 => 'Start32SystemExecutables',
    5107 => 'StartTimer',
    5108 => 'SetDeviceSurface',
    5109 => 'ThkDos16SetFgnd',
    5110 => 'TidCurrent',
    5111 => 'Win32AddAtom',
    5112 => 'Win32AddSwitchEntry',
    5113 => 'Win32Alarm',
    5114 => 'Win32BeginEnumWindows',
    5115 => 'Win32BeginPaint',
    5116 => 'Win32BroadcastMsg',
    5117 => 'Win32BuildPtrHandle',
    5118 => 'Win32CalcFrameRect',
    5119 => 'Win32CallHelpHook',
    5120 => 'Win32CallMsgFilter',
    5121 => 'Win32CancelShutdown',
    5122 => 'Win32ChangeSwitchEntry',
    5123 => 'Win32CheckInput',
    5124 => 'Win32CloseClipbrd',
    5125 => 'Win32CompareStrings',
    5126 => 'Win32CopyAccelTable',
    5127 => 'Win32CopyRect',
    5128 => 'Win32CpTranslateChar',
    5129 => 'Win32CpTranslateString',
    5130 => 'Win32CreateAccelTable',
    5131 => 'Win32CreateAtomTable',
    5132 => 'Win32CreateCursor',
    5133 => 'Win32CreateDlg',
    5134 => 'Win32CreateFrameControls',
    5135 => 'Win32CreateMenu',
    5136 => 'Win32CreateMsgQueue',
    5137 => 'Win32CreatePointer',
    5138 => 'Win32CreatePointerIndirect',
    5139 => 'Win32CreateStdWindow',
    5140 => 'Win32CreateSwitchEntry',
    5141 => 'Win32CreateWindow',
    5142 => 'Win32DdeInitiate',
    5143 => 'Win32DdePostMsg',
    5144 => 'Win32DdeRespond',
    5145 => 'Win32DebugBreak',
    5146 => 'Win32DefDlgProc',
    5147 => 'Win32DefWindowProc',
    5148 => 'Win32DeleteAtom',
    5149 => 'Win32DeleteLibrary',
    5150 => 'Win32DeleteProcedure',
    5151 => 'Win32DestroyAccelTable',
    5152 => 'Win32DestroyAtomTable',
    5153 => 'Win32DestroyCursor',
    5154 => 'Win32DestroyMsgQueue',
    5155 => 'Win32DestroyPointer',
    5156 => 'Win32DestroyWindow',
    5157 => 'Win32DismissDlg',
    5158 => 'Win32DispatchMsg',
    5159 => 'Win32DlgBox',
    5160 => 'Win32DrawBitmap',
    5161 => 'Win32DrawBorder',
    5162 => 'Win32DrawPointer',
    5163 => 'Win32DrawText',
    5164 => 'Win32EmptyClipbrd',
    5165 => 'Win32EnablePhysInput',
    5166 => 'Win32EnableWindow',
    5167 => 'Win32EnableWindowUpdate',
    5168 => 'Win32EndEnumWindows',
    5169 => 'Win32EndPaint',
    5170 => 'Win32EndProgram',
    5171 => 'Win32EnumClipbrdFmts',
    5172 => 'Win32EnumDlgItem',
    5173 => 'Win32EqualRect',
    5174 => 'Win32ExcludeUpdateRegion',
    5175 => 'Win32ExplodeWindow',
    5176 => 'Win32FillRect',
    5177 => 'Win32FindAtom',
    5178 => 'Win32FlashWindow',
    5179 => 'Win32FocusChange',
    5180 => 'Win32FreeErrorInfo',
    5181 => 'Win32GetClipPS',
    5182 => 'Win32GetCurrentTime',
    5183 => 'Win32GetDlgMsg',
    5184 => 'Win32GetErasePS',
    5185 => 'Win32GetErrorInfo',
    5186 => 'Win32GetFrameTreePPs',
    5187 => 'Win32GetFrameTreePPSize',
    5188 => 'Win32GetKeyState',
    5189 => 'Win32GetLastError',
    5190 => 'Win32GetMaxPosition',
    5191 => 'Win32GetMinPosition',
    5192 => 'Win32GetMsg',
    5193 => 'Win32GetNextWindow',
    5194 => 'Win32GetPhysKeyState',
    5195 => 'Win32GetPS',
    5196 => 'Win32GetScreenPS',
    5197 => 'Win32GetSysBitmap',
    5198 => 'Win32HAPPfromPID',
    5199 => 'Win32HSWITCHfromHAPP',
    5200 => 'Win32InflateRect',
    5201 => 'Win32Initialize',
    5202 => 'Win32InSendMsg',
    5203 => 'Win32IntersectRect',
    5204 => 'Win32InvalidateRect',
    5205 => 'Win32InvalidateRegion',
    5206 => 'Win32InvertRect',
    5207 => 'Win32IsChild',
    5208 => 'Win32IsPhysInputEnabled',
    5209 => 'Win32IsRectEmpty',
    5210 => 'Win32IsThreadActive',
    5211 => 'Win32IsWindow',
    5212 => 'Win32IsWindowEnabled',
    5213 => 'Win32IsWindowShowing',
    5214 => 'Win32IsWindowVisible',
    5215 => 'Win32JiggleMouse',
    5216 => 'Win32LoadAccelTable',
    5217 => 'Win32LoadCharXlatetbl',
    5218 => 'Win32LoadDlg',
    5219 => 'Win32LoadLibrary',
    5220 => 'Win32LoadMenu',
    5221 => 'Win32LoadMessage',
    5222 => 'Win32LoadPointer',
    5223 => 'Win32LoadProcedure',
    5224 => 'Win32LoadString',
    5225 => 'Win32LockInput',
    5226 => 'Win32LockPointerUpdate',
    5227 => 'Win32LockVisRegions',
    5228 => 'Win32LockWindowUpdate',
    5229 => 'Win32MakePoints',
    5230 => 'Win32MakeRect',
    5231 => 'Win32MapDlgPoints',
    5232 => 'Win32MapWindowPoints',
    5233 => 'Win32MessageBox',
    5234 => 'Win32MoveCursor',
    5235 => 'Win32MsgMuxSemWait',
    5236 => 'Win32MsgSemWait',
    5237 => 'Win32MultWindowFromIDs',
    5238 => 'Win32NextChar',
    5239 => 'Win32OffsetRect',
    5240 => 'Win32OpenClipbrd',
    5241 => 'Win32OpenWindowDC',
    5242 => 'Win32PeekMsg',
    5243 => 'Win32PopupMenu',
    5244 => 'Win32PostMsg',
    5245 => 'Win32PostQueueMsg',
    5246 => 'Win32PrevChar',
    5247 => 'Win32ProcessDlg',
    5248 => 'Win32PtInRect',
    5249 => 'Win32QueryAccelTable',
    5250 => 'Win32QueryAccelTableValue',
    5251 => 'Win32QueryActiveWindow',
    5252 => 'Win32QueryAnchorBlock',
    5253 => 'Win32QueryAtomLength',
    5254 => 'Win32QueryAtomName',
    5255 => 'Win32QueryAtomUsage',
    5256 => 'Win32QueryCapture',
    5257 => 'Win32QueryClassInfo',
    5258 => 'Win32QueryClassName',
    5259 => 'Win32QueryClassThunkProc',
    5260 => 'Win32QueryClipbrdData',
    5261 => 'Win32QueryClipbrdFmtInfo',
    5262 => 'Win32QueryClipbrdOwner',
    5263 => 'Win32QueryClipbrdViewer',
    5264 => 'Win32QueryCp',
    5265 => 'Win32QueryCpList',
    5266 => 'Win32QueryCursorInfo',
    5267 => 'Win32QueryDesktopBkgnd',
    5268 => 'Win32QueryDesktopWindow',
    5269 => 'Win32QueryDlgItemShort',
    5270 => 'Win32QueryDlgItemText',
    5271 => 'Win32QueryDlgItemTextLength',
    5272 => 'Win32QueryFocus',
    5273 => 'Win32QueryMsgPos',
    5274 => 'Win32QueryMsgTime',
    5275 => 'Win32QueryObjectWindow',
    5276 => 'WinQueryPaletteMode',
    5277 => 'Win32QueryPointer',
    5278 => 'Win32QueryPointerInfo',
    5279 => 'Win32QueryPointerPos',
    5280 => 'Win32QueryPresParam',
    5281 => 'Win32QueryProcessCP',
    5282 => 'Win32QueryQueueInfo',
    5283 => 'Win32QueryQueueStatus',
    5284 => 'Win32QuerySendMsg',
    5285 => 'Win32QuerySessionTitle',
    5286 => 'Win32QuerySwitchEntry',
    5287 => 'Win32QuerySwitchHandle',
    5288 => 'Win32QuerySwitchList',
    5289 => 'Win32QuerySysColor',
    5290 => 'Win32QuerySysModalWindow',
    5291 => 'Win32QuerySysPointer',
    5292 => 'Win32QuerySysPointerData',
    5293 => 'Win32QuerySystemAtomTable',
    5294 => 'Win32QuerySysValue',
    5295 => 'Win32QueryTaskSizePos',
    5296 => 'Win32QueryTaskTitle',
    5297 => 'Win32QueryUpdateRect',
    5298 => 'Win32QueryUpdateRegion',
    5299 => 'Win32QueryVersion',
    5300 => 'Win32QueryVisibleRegion',
    5301 => 'Win32QueryWindow',
    5302 => 'Win32QueryWindowDC',
    5303 => 'Win32QueryWindowModel',
    5304 => 'Win32QueryWindowPos',
    5305 => 'Win32QueryWindowProcess',
    5306 => 'Win32QueryWindowPtr',
    5307 => 'Win32QueryWindowRect',
    5308 => 'Win32QueryWindowText',
    5309 => 'Win32QueryWindowTextLength',
    5310 => 'Win32QueryWindowThunkProc',
    5311 => 'Win32QueryWindowULong',
    5312 => 'Win32QueryWindowUShort',
    5313 => 'Win32QueueFromID',
    5314 => 'Win32RealizePalette',
    5315 => 'Win32RegisterClass',
    5316 => 'Win32RegisterPen',
    5317 => 'Win32RegisterSeamlessProc',
    5318 => 'Win32RegisterUserDatatype',
    5319 => 'Win32RegisterUserMsg',
    5320 => 'Win32ReleaseErasePS',
    5321 => 'Win32ReleaseHook',
    5322 => 'Win32ReleasePS',
    5323 => 'Win32RemovePresParam',
    5324 => 'Win32RemoveSwitchEntry',
    5325 => 'Win32ReplyMsg',
    5326 => 'Win32RequestMutexSem',
    5327 => 'Win32SaveWindowPos',
    5328 => 'Win32ScrollWindow',
    5329 => 'Win32SeamlessBox',
    5330 => 'Win32SemEnter',
    5331 => 'Win32SemLeave',
    5332 => 'Win32SemQuery',
    5333 => 'Win32SendDlgItemMsg',
    5334 => 'Win32SendMsg',
    5335 => 'Win32SetAccelTable',
    5336 => 'Win32SetAccelTableValue',
    5337 => 'Win32SetActiveWindow',
    5338 => 'Win32SetCapture',
    5339 => 'Win32SetCharXlateTbl',
    5340 => 'Win32SetClassMsgInterest',
    5341 => 'Win32SetClassThunkProc',
    5342 => 'Win32SetClipbrdData',
    5343 => 'Win32SetClipbrdOwner',
    5344 => 'Win32SetClipbrdViewer',
    5345 => 'Win32SetCp',
    5346 => 'Win32SetDesktopBkgnd',
    5347 => 'Win32SetDlgItemShort',
    5348 => 'Win32SetDlgItemText',
    5349 => 'Win32SetErrorInfo',
    5350 => 'Win32SetFocus',
    5351 => 'Win32SetFrameTreePPs',
    5352 => 'Win32SetHook',
    5353 => 'Win32SetKeyboardStateTable',
    5354 => 'Win32SetMsgInterest',
    5355 => 'Win32SetMsgMode',
    5356 => 'Win32SetMultWindowPos',
    5357 => 'Win32SetOwner',
    5358 => 'WinSetPaletteMode',
    5359 => 'Win32SetParent',
    5360 => 'Win32SetPointer',
    5361 => 'Win32SetPointerOwner',
    5362 => 'Win32SetPointerPos',
    5363 => 'Win32SetPresParam',
    5364 => 'Win32SetRect',
    5365 => 'Win32SetRectEmpty',
    5366 => 'Win32SetSynchroMode',
    5367 => 'Win32SetSysClipbrdViewer',
    5368 => 'Win32SetSysColors',
    5369 => 'Win32SetSysFont',
    5370 => 'Win32SetSysModalWindow',
    5371 => 'Win32SetSysPointerData',
    5372 => 'Win32SetSysValue',
    5373 => 'Win32SetVisibleRegionNotify',
    5374 => 'Win32SetWindowBits',
    5375 => 'Win32SetWindowPos',
    5376 => 'Win32SetWindowPtr',
    5377 => 'Win32SetWindowText',
    5378 => 'Win32SetWindowThunkProc',
    5379 => 'Win32SetWindowULong',
    5380 => 'Win32SetWindowUShort',
    5381 => 'Win32ShowCursor',
    5382 => 'Win32ShowPointer',
    5383 => 'Win32ShowTrackRect',
    5384 => 'Win32ShowWindow',
    5385 => 'Win32StartApp',
    5386 => 'Win32StartTimer',
    5387 => 'Win32StopTimer',
    5388 => 'Win32StretchPointer',
    5389 => 'Win32SubclassWindow',
    5390 => 'Win32SubstituteStrings',
    5391 => 'Win32SubtractRect',
    5392 => 'Win32SwitchProgramRegister',
    5393 => 'Win32SwitchToProgram',
    5394 => 'Win32SwitchToProgram2',
    5395 => 'Win32SystemShutdown',
    5396 => 'Win32Terminate',
    5397 => 'Win32TerminateApp',
    5398 => 'Win32ThreadAssocQueue',
    5399 => 'Win32TrackRect',
    5400 => 'Win32TrackSeamless',
    5401 => 'Win32TranslateAccel',
    5402 => 'Win32UnionRect',
    5403 => 'Win32UpdateWindow',
    5404 => 'Win32Upper',
    5405 => 'Win32UpperChar',
    5406 => 'Win32ValidateRect',
    5407 => 'Win32ValidateRegion',
    5408 => 'Win32VisRegionNotify',
    5409 => 'Win32WaitEventSem',
    5410 => 'Win32WaitMsg',
    5411 => 'Win32WaitMuxWaitSem',
    5412 => 'Win32WakeThread',
    5413 => 'Win32WindowFromDC',
    5414 => 'Win32WindowFromID',
    5415 => 'Win32WindowFromPoint',
    5416 => 'WinAugmentPointer',
    5417 => 'WinMessageBox2',
    5418 => 'WinMspAlloc',
    5419 => 'WinMspFree',
    5420 => 'WinMspInit',
    5421 => 'WinProcessHotKey',
    5422 => 'WinProfControl',
    5423 => 'WinXXAllocFill',
    5424 => 'WinXXAllocMem',
    5425 => 'WinXXCreateHeap',
    5426 => 'WinXXDestroyHeap',
    5427 => 'WinXXFreeMem',
    5428 => 'WinXXIsMemInHeap',
    5429 => 'WinXXReallocMem',
    5430 => 'PMHeapIsMemInChain',
    5431 => 'Win32NoShutdown',
    5432 => 'WinDrawTabbedText',
    5433 => 'Win32QueryPointerClipRect',
    5434 => 'Win32SetPointerClipRect',
    5436 => 'Win32WaitMsgTimeout',
    5437 => 'Win32IsWindowOfClass',
    5438 => 'Win32SetAtomTableOwner',
    5439 => 'WinXXQueryMemSize',
    5440 => 'Win32SetClipRegion',
    5441 => 'Win32QueryClipRegion',
    5442 => 'Win32AddClipbrdViewer',
    5443 => 'Win32RemoveClipbrdViewer',
    5444 => 'Win32QueryClipbrdViewerChain',
    5445 => 'Win32IncrementAtomUsage',
    5446 => 'DaxQueryOpenClipbrdWindow',
    5447 => 'WinQueryDaxData',
    5448 => 'WinSetDaxData',
    5449 => 'WinEnumProperties',
    5450 => 'WinQueryProperty',
    5451 => 'WinRemoveProperty',
    5452 => 'WinSetProperty',
    5453 => 'WinEnumClassProperties',
    5454 => 'WinQueryClassProperty',
    5455 => 'WinRemoveClassProperty',
    5456 => 'WinSetClassProperty',
    5457 => 'WinQueryHeapFlags',
    5458 => 'Win32SetKbdLayout',
    5459 => 'WinSetDAXDefWndProc',
    5460 => 'PostEscape32',
    5461 => 'Win32GetAFCValue',
    5462 => 'Win32SetAFCValue',
    5463 => 'Win32LoadVkeyGlyphXlateTbl',
    5464 => 'Win32SetVkeyGlyphXlateTbl',
    5465 => 'Win32QueryVkeyGlyphXlateTbl',
    5466 => 'Win32TrackWindow',
    5467 => 'Win32SemEnterTimeout',
    5468 => 'WinSetDesktopWorkArea',
    5469 => 'WinQueryDesktopWorkArea',
    5470 => 'WinQueryControlColors',
    5471 => 'WinSetControlColors',
    5472 => 'CtlQueryColor',
    5473 => 'Win32TranslateChar2',
    5474 => 'Win32WaitForIdleThread',
    5475 => 'WinXXCreateHeap2',
    5476 => 'WinQuerySharedHeapData',
    5477 => 'Win32QueryActiveOtherWindow',
    5478 => 'Win32EnumVkeyScanIDs',
    5479 => 'Win32QueryKbdLayout',
    5480 => 'WinQueryCpType',
    5481 => 'Win32QueryCharXlatetbl',
    6000 => 'KbdPacket',
    6099 => 'InitGameFrameProc',
    6100 => 'GreNLS',
    6194 => 'ValidateDCHandle',
    6195 => 'HookMan',
    6196 => 'CCHSetHailing',
    6197 => 'EnableCoachMsgHook',
    6198 => 'FCallGRECoach',
    6199 => 'GRE32CallForward',
    6200 => 'GreMemptrs',
    6201 => 'FPen',
    6202 => 'ShellWindow',
    6203 => 'PMSemaphores',
    6204 => 'PHandleTable',
    6205 => 'PSharedHeap',
    6206 => 'VPAULDefaultColors',
    10000 => 'DaxCreateCaret',
    10001 => 'DaxDestroyCaret',
    10002 => 'DaxGetCaretBlinkTime',
    10004 => 'DaxHideCaret',
    10005 => 'DaxSetCaretBlinkTime',
    10007 => 'DaxShowCaret',
    10018 => 'DaxShowCursor',
    10019 => 'DaxSwapMouseButton',
    10020 => 'LookupAtom',
    10021 => 'DaxOpenClipbrd',
  },

  'PMWP' => {
    1 => 'LoadPMWP',
    2 => 'FSQueryDriveData',
    10 => 'WPFileSystemCClassData',
    11 => 'WPFilesystemClassData',
    12 => 'WPFilesystemNewClass',
    13 => 'WPFolderCClassData',
    14 => 'WPFolderClassData',
    15 => 'WPFolderNewClass',
    16 => 'WPDataFileCClassData',
    17 => 'WPDataFileClassData',
    18 => 'WPDataFileNewClass',
    22 => 'WPObjectCClassData',
    23 => 'WPObjectClassData',
    24 => 'WPObjectNewClass',
    25 => 'WPAbstractCClassData',
    26 => 'WPAbstractClassData',
    27 => 'WPAbstractNewClass',
    28 => 'WPTemplatesCClassData',
    29 => 'WPTemplatesClassData',
    30 => 'WPTemplatesNewClass',
    31 => 'WPShadowCClassData',
    32 => 'WPShadowClassData',
    33 => 'WPShadowNewClass',
    34 => 'WPDiskCClassData',
    35 => 'WPDiskClassData',
    36 => 'WPDiskNewClass',
    37 => 'WPStartupCClassData',
    38 => 'WPStartupClassData',
    39 => 'WPStartupNewClass',
    40 => 'WPTransientCClassData',
    41 => 'WPTransientClassData',
    42 => 'WPTransientNewClass',
    43 => 'WPDrivesCClassData',
    44 => 'WPDrivesClassData',
    45 => 'WPDrivesNewClass',
    46 => 'WPProgramCClassData',
    47 => 'WPProgramClassData',
    48 => 'WPProgramNewClass',
    49 => 'WPProgramFileCClassData',
    50 => 'WPProgramFileClassData',
    51 => 'WPProgramFileNewClass',
    52 => 'WPShredderCClassData',
    53 => 'WPShredderClassData',
    54 => 'WPShredderNewClass',
    55 => 'WPDesktopCClassData',
    56 => 'WPDesktopClassData',
    57 => 'WPDesktopNewClass',
    58 => 'WPRootFolderCClassData',
    59 => 'WPRootFolderClassData',
    60 => 'WPRootFolderNewClass',
    61 => 'WPIconCClassData',
    62 => 'WPIconClassData',
    63 => 'WPIconNewClass',
    64 => 'WPPointerCClassData',
    65 => 'WPPointerClassData',
    66 => 'WPPointerNewClass',
    67 => 'WPBitmapCClassData',
    68 => 'WPBitmapClassData',
    69 => 'WPBitmapNewClass',
    85 => 'WPCommandFileCClassData',
    86 => 'WPCommandFileClassData',
    87 => 'WPCommandFileNewClass',
    88 => 'WPClassManagerCClassData',
    89 => 'WPClassManagerClassData',
    90 => 'WPClassManagerNewClass',
    91 => 'WPPifCClassData',
    92 => 'WPPifClassData',
    93 => 'WPPifNewClass',
    94 => 'WPMetCClassData',
    95 => 'WPMetClassData',
    96 => 'WPMetNewClass',
    101 => 'RestoreDesktop',
    102 => 'Strcat',
    103 => 'Memset',
    105 => 'Strcpy',
    106 => 'Strlen',
    107 => 'Itoa',
    108 => 'Strchr',
    109 => 'Strrchr',
    110 => 'Memcpy',
    111 => 'Strcmp',
    112 => 'Atoi',
    113 => 'Ultoa',
    114 => 'Isdbcs',
    115 => 'Nextpch',
    116 => 'Prevpch',
    117 => 'Strcmpi',
    118 => 'Strncmpi',
    119 => 'Strncat_trunc',
    120 => 'Strncat',
    121 => 'Strncpy_trunc',
    122 => 'Strncpy',
    123 => 'Strstr',
    124 => 'Strupr',
    125 => 'Xlatblank',
    126 => 'Atol',
    127 => 'Strncmp',
    128 => 'Strpbrk',
    129 => 'Stripblanks',
    130 => 'Cleanupdesktop',
    145 => 'WinStartShell',
    147 => 'ShlInsertContextMenuItems',
    148 => 'ShlInsertSettingsPage',
    149 => 'WinShutdownSystem',
    150 => 'Allocmem',
    151 => 'Freemem',
    152 => 'WinShutdownAndReboot',
    153 => 'WinShutdown',
    200 => 'WinRegisterObjectClass',
    201 => 'WinDeRegisterObjectClass',
    202 => 'WinCreateObject - LA',
    203 => 'MriLoadResource',
    204 => 'ShlCreateContextMenu',
    205 => 'WinEnumObjectClasses',
    206 => 'ShlQueryFolderFromPath',
    207 => 'WinStoreWindowPos',
    208 => 'WinRestoreWindowPos',
    209 => 'WinLoadFileIcon',
    210 => 'WinSetFileIcon',
    211 => 'ShlStartWorkplace',
    212 => 'ShlExceptionHandler',
    213 => 'ShlSaveEnv',
    214 => 'ShlRestoreEnv',
    215 => 'Memcmp',
    216 => 'WinFreeFileIcon',
    217 => 'ShlQueryIconGivenFEAl2',
    218 => 'ShlLoadIcon',
    219 => 'WinReplaceObjectClass',
    220 => 'DiskFilter',
    221 => 'WinRestartWorkplace',
    223 => 'ReportMessage',
    224 => 'ShlGetUserWordPtr',
    225 => 'DoNetLogon',
    226 => 'DoNetLogoff',
    227 => 'DoNetError',
    228 => 'DoNetConnect',
    229 => 'DoNetDisconnect',
    230 => 'NwiEnumCache',
    231 => 'NwiEnumNetwork',
    232 => 'NwiQueryCache',
    233 => 'NwiQueryNetwork',
    234 => 'NwiGetNewName',
    235 => 'NwiAuthDefaults',
    236 => 'NwiAuthenticate',
    237 => 'NwiUnauthenticate',
    238 => 'NwiConnect',
    239 => 'NwiDisconnect',
    240 => 'NwiAllocUnc',
    241 => 'NwiFreeUnc',
    242 => 'NwiGetConnList',
    243 => 'NwiIL',
    244 => 'NwiIP',
    245 => 'NwtFillCombobox',
    246 => 'NwiQueryNetCaps',
    247 => 'NwiQueryServerVersion',
    248 => 'NwiEnumInfo',
    249 => 'NwiQueryInfo',
    250 => 'WinSetObjectData',
    251 => 'WinDestroyObject',
    252 => 'WinQueryObject',
    253 => '_vaPsz',
    254 => '_AddRunningProgram',
    255 => '_CreateDuplicatePointer',
    256 => '_GetFrameHandle',
    257 => '_RelocateObjectMinWindows',
    258 => '_SetSysMenu',
    260 => '_SetupFontSample',
    261 => '_SubstituteStrings',
    262 => 'WinQueryActiveDesktopPathname',
    263 => 'WinQueryObjectPath',
    264 => '_pszData',
    265 => '_vButtonType',
    266 => '_vDefButtonType',
    267 => '_vDefMinWindows',
    268 => '_vMinWindows',
    269 => '_vCxIcon',
    270 => '_vCxScreen',
    271 => '_vCxScroll',
    272 => '_vCyIcon',
    273 => '_vCyScreen',
    274 => '_vCyScroll',
    276 => '_vhModMri',
    277 => '_vhwndDesktop',
    278 => '_vhwndDesktopFrame',
    279 => '_vhwndHelpInstance',
    280 => '_vhwndTaskList',
    281 => 'WinCreateObject - GA',
    282 => 'WinUnlockSystem',
    283 => 'WinLockupSystem',
    284 => 'MessageLoopProc',
    285 => 'WinSaveObject',
    286 => 'WinOpenObject',
    287 => 'WinMoveObject',
    288 => 'WinCopyObject',
    289 => 'WinCreateShadow',
    310 => 'M_WPFileSystemCClassData',
    311 => 'M_WPFileSystemClassData',
    312 => 'M_WPFileSystemNewClass',
    313 => 'M_WPFolderCClassData',
    314 => 'M_WPFolderClassData',
    315 => 'M_WPFolderNewClass',
    316 => 'M_WPDataFileCClassData',
    317 => 'M_WPDataFileClassData',
    318 => 'M_WPDataFileNewClass',
    319 => 'M_WPTemplatesCClassData',
    320 => 'M_WPTemplatesClassData',
    321 => 'M_WPTemplatesNewClass',
    322 => 'M_WPObjectCClassData',
    323 => 'M_WPObjectClassData',
    324 => 'M_WPObjectNewClass',
    325 => 'M_WPAbstractCClassData',
    326 => 'M_WPAbstractClassData',
    327 => 'M_WPAbstractNewClass',
    328 => 'M_WPShadowCClassData',
    329 => 'M_WPShadowClassData',
    330 => 'M_WPShadowNewClass',
    331 => 'M_WPDiskCClassData',
    332 => 'M_WPDiskClassData',
    333 => 'M_WPDiskNewClass',
    334 => 'M_WPStartupCClassData',
    335 => 'M_WPStartupClassData',
    336 => 'M_WPStartupNewClass',
    337 => 'M_WPTransientCClassData',
    338 => 'M_WPTransientClassData',
    339 => 'M_WPTransientNewClass',
    340 => 'M_WPDrivesCClassData',
    341 => 'M_WPDrivesClassData',
    342 => 'M_WPDrivesNewClass',
    343 => 'M_WPProgramCClassData',
    344 => 'M_WPProgramClassData',
    345 => 'M_WPProgramNewClass',
    346 => 'M_WPProgramFileCClassData',
    347 => 'M_WPProgramFileClassData',
    348 => 'M_WPProgramFileNewClass',
    349 => 'M_WPShredderCClassData',
    350 => 'M_WPShredderClassData',
    351 => 'M_WPShredderNewClass',
    355 => 'M_WPDesktopCClassData',
    356 => 'M_WPDesktopClassData',
    357 => 'M_WPDesktopNewClass',
    358 => 'M_WPRootFolderCClassData',
    359 => 'M_WPRootFolderClassData',
    360 => 'M_WPRootFolderNewClass',
    361 => 'M_WPIconCClassData',
    362 => 'M_WPIconClassData',
    363 => 'M_WPIconNewClass',
    364 => 'M_WPPointerCClassData',
    365 => 'M_WPPointerClassData',
    366 => 'M_WPPointerNewClass',
    367 => 'M_WPBitmapCClassData',
    368 => 'M_WPBitmapClassData',
    369 => 'M_WPBitmapNewClass',
    385 => 'M_WPCommandFileCClassData',
    386 => 'M_WPCommandFileClassData',
    387 => 'M_WPCommandFileNewClass',
    388 => 'M_WPNetworkCClassData',
    389 => 'M_WPNetworkClassData',
    390 => 'M_WPNetworkNewClass',
    391 => 'M_WPNetgrpCClassData',
    392 => 'M_WPNetgrpClassData',
    393 => 'M_WPNetgrpNewClass',
    394 => 'M_WPServerCClassData',
    395 => 'M_WPServerClassData',
    396 => 'M_WPServerNewClass',
    397 => 'M_WPSharedDirCClassData',
    398 => 'M_WPSharedDirClassData',
    399 => 'M_WPSharedDirNewClass',
    400 => 'M_WPNetLinkCClassData',
    401 => 'M_WPNetLinkClassData',
    402 => 'M_WPNetLinkNewClass',
    403 => 'M_WPPifCClassData',
    404 => 'M_WPPifClassData',
    405 => 'M_WPPifNewClass',
    406 => 'M_WPMetCClassData',
    407 => 'M_WPMetClassData',
    408 => 'M_WPMetNewClass',
    409 => 'WPNetworkCClassData',
    410 => 'WPNetworkClassData',
    411 => 'WPNetworkNewClass',
    412 => 'WPSharedDirCClassData',
    413 => 'WPSharedDirClassData',
    414 => 'WPSharedDirNewClass',
    415 => 'WPServerCClassData',
    416 => 'WPServerClassData',
    417 => 'WPServerNewClass',
    418 => 'WPNetLinkCClassData',
    419 => 'WPNetLinkClassData',
    420 => 'WPNetLinkNewClass',
    421 => 'WPNetgrpCClassData',
    422 => 'WPNetgrpClassData',
    423 => 'WPNetgrpNewClass',
    424 => 'VPIDWorkplace',
    427 => 'SchemeBackgroundDlgProc',
    428 => 'ShlStoreString',
    429 => 'ShlFreeString',
    430 => 'EncodeBackgroundData',
    431 => 'DecodeBackgroundData',
    432 => 'UnloadUnitBitmap',
    433 => 'WPMinWindowCClassData',
    434 => 'WPMinWindowClassData',
    435 => 'M_WPMinWindowNewClass',
    436 => 'WPMinWindowNewClass',
    437 => 'WPCnrViewCClassData',
    438 => 'WPCnrViewClassData',
    439 => 'M_WPCnrViewNewClass',
    440 => 'WPCnrViewNewClass',
    441 => 'M_WPFindFolderNewClass',
    442 => 'WPFindFolderNewClass',
    443 => 'M_WPProgramGroupNewClass',
    444 => 'WPDiskCVNewClass',
    445 => 'RWMonitorCClassData',
    446 => 'RWMonitorClassData',
    447 => 'RWMonitorNewClass',
    448 => 'WPFilterCClassData',
    449 => 'WPFilterClassData',
    450 => 'WPFilterNewClass',
    451 => 'M_WPFilterNewClass',
    452 => 'WPFinderCClassData',
    453 => 'WPFinderClassData',
    454 => 'WPFinderNewClass',
    455 => 'M_WPFinderNewClass',
    456 => 'WPMinWinViewerCClassData',
    457 => 'WPMinWinViewerClassData',
    458 => 'WPMinWinViewerNewClass',
    459 => 'M_WPMinWinViewerNewClass',
    460 => 'WPProgramGroupCClassData',
    461 => 'WPProgramGroupClassData',
    462 => 'WPProgramGroupNewClass',
    463 => 'WinRestartWPDServer',
    464 => 'WinRestartSomDD',
    465 => 'WinIsWPDServerReady',
    466 => 'VHwndWorkplaceWindow',
    467 => 'WPLaunchpadCClassData',
    468 => 'WPLaunchpadClassData',
    469 => 'WPLaunchpadNewClass',
    470 => 'M_WPLaunchpadCClassData',
    471 => 'M_WPLaunchpadClassData',
    472 => 'M_WPLaunchpadNewClass',
    473 => 'ShlRealizeDefaultPalette',
    474 => 'VHPalDefaultColors',
    475 => 'VFPaletteManagedDisplay',
    476 => 'FindOneObject',
    477 => 'ShlCreateTempFile',
    478 => 'ShlDeleteTempFile',
    479 => 'VSZDesktopFolder',
    480 => 'WinIsSomDDReady',
    481 => 'ShlUnloadServer',
    482 => 'NotifyObjectInCnrOpened',
    483 => 'PMWPDateToString',
    484 => 'M_WPCnrViewCClassData',
    485 => 'M_WPCnrViewClassData',
    486 => 'VFConfirmations',
    487 => 'VFConfirmationsLoaded',
    488 => 'VULWPSDSOMThreadID',
    489 => 'LWPDOpenedOnWPDServer',
    490 => 'ShlStartApp',
    491 => 'WPImageFileCClassData',
    492 => 'WPImageFileClassData',
    493 => 'WPImageFileNewClass',
    494 => 'M_WPImageFileCClassData',
    495 => 'M_WPImageFileClassData',
    496 => 'M_WPImageFileNewClass',
    497 => 'ODWPSCClassData',
    498 => 'ODWPSClassData',
    499 => 'ODWPSNewClass',
    500 => 'M_ODWPSCClassData',
    501 => 'M_ODWPSClassData',
    502 => 'M_ODWPSNewClass',
    503 => 'FileSysQueryAwakeObject',
    504 => 'NodeMovedNotify',
    505 => 'Ultoah',
    506 => 'RunOnThread',
    507 => 'SHCRT_ToUpper',
    508 => 'SubstituteString',
    509 => 'BuildShortFilename',
    510 => 'BuildNameFromNumber',
    511 => 'WinNotebookButtonFromID',
    512 => 'WinWaitForShell',
    513 => 'VDriveData',
  },

  'PMGRE' => {
    3 => 'InnerGreEntry',
    4 => 'GreInitialize',
    6 => 'GreInitialize32',
    12 => 'GreEntry2',
    13 => 'GreEntry3',
    14 => 'GreEntry4',
    15 => 'GreEntry5',
    16 => 'GreEntry6',
    17 => 'GreEntry7',
    18 => 'GreEntry8',
    19 => 'GreEntry9',
    20 => 'GreEntry10',
    30 => 'GetDriverInfo',
    31 => 'SetDriverInfo',
    32 => 'PostDeviceModes',
    33 => 'InitMoveCursor',
    34 => 'BitmapLimitWarning',
    37 => 'GetDriverInfo32',
    38 => 'SetDriverInfo32',
    39 => 'PostDeviceModes32',
    41 => 'PostEscape32',
    42 => 'PmWinGreEntry2',
    43 => 'PmWinGreEntry3',
    44 => 'PmWinGreEntry4',
    45 => 'PmWinGreEntry5',
    46 => 'PmWinGreEntry6',
    47 => 'PmWinGreEntry7',
    48 => 'PmWinGreEntry8',
    49 => 'PmWinGreEntry9',
    50 => 'PmWinGreEntry10',
    62 => 'Gre32Entry2',
    63 => 'Gre32Entry3',
    64 => 'Gre32Entry4',
    65 => 'Gre32Entry5',
    66 => 'Gre32Entry6',
    67 => 'Gre32Entry7',
    68 => 'Gre32Entry8',
    69 => 'Gre32Entry9',
    70 => 'Gre32Entry10',
    72 => 'InnerGre32Entry2',
    73 => 'InnerGre32Entry3',
    74 => 'InnerGre32Entry4',
    75 => 'InnerGre32Entry5',
    76 => 'InnerGre32Entry6',
    77 => 'InnerGre32Entry7',
    78 => 'InnerGre32Entry8',
    79 => 'InnerGre32Entry9',
    80 => 'InnerGre32Entry10',
    100 => 'SSAllocSeg',
    101 => 'SSAllocHuge',
    102 => 'SSFreeSeg',
    103 => 'SSFlushSegs',
    104 => 'SSServer',
    105 => 'SSInit',
    106 => 'SSAllocMem',
    107 => 'SSFreeMem',
    108 => 'SSFlushMem',
    140 => 'SSServer32',
    141 => 'SSInit32',
    200 => 'Enable_Call_16',
    201 => 'Devmode_Call_16',
    202 => 'DeleteBitmap16Call',
    203 => 'PFN4R2',
    204 => 'PFN5R2',
    205 => 'PFN6R2',
    206 => 'PFN7R2',
    207 => 'PFN8R2',
    208 => 'PFN9R2',
    209 => 'PFN10R2',
    210 => 'Devname_Call_16',
    213 => 'Dispatch16Gate3',
    214 => 'Dispatch16Gate4',
    215 => 'Dispatch16Gate5',
    216 => 'Dispatch16Gate6',
    217 => 'Dispatch16Gate7',
    218 => 'Dispatch16Gate8',
    219 => 'Dispatch16Gate9',
    220 => 'Dispatch16Gate10',
    223 => 'Dispatch32Gate3',
    224 => 'Dispatch32Gate4',
    225 => 'Dispatch32Gate5',
    226 => 'Dispatch32Gate6',
    227 => 'Dispatch32Gate7',
    228 => 'Dispatch32Gate8',
    229 => 'Dispatch32Gate9',
    230 => 'Dispatch32Gate10',
    300 => 'GreRequestMutexSem',
    301 => 'GreReleaseMutexSem',
    400 => 'RamSemRequest32',
    401 => 'RamSemClear32',
    402 => 'RamSemRequest16',
    403 => 'RamSemClear16',
    500 => 'GreMemPtrs',
    501 => 'GreNLS',
    510 => 'SetDeviceSurface',
  },

  'SOM' => {
    1 => 'SomCalloc',
    2 => 'SomClassCClassData',
    3 => 'SomClassClassData',
    4 => 'SomClassInitFuncName',
    5 => 'SomClassMgrCClassData',
    6 => 'SomClassMgrClassData',
    7 => 'SomClassMgrObject',
    8 => 'SomDeleteModule',
    9 => 'SomError',
    10 => 'SomFree',
    11 => 'SomLoadModule',
    12 => 'SomMalloc',
    13 => 'SomObjectCClassData',
    14 => 'SomObjectClassData',
    15 => 'SomOutCharRoutine',
    16 => 'SomRealloc',
    17 => 'Som_AssertLevel',
    18 => 'Som_TraceLevel',
    19 => 'Som_WarnLevel',
    20 => 'SomClassMgrNewClass',
    21 => 'SomClassNewClass',
    22 => 'SomObjectNewClass',
    23 => 'SomAssert',
    24 => 'SomBeginPersistentIds',
    25 => 'SomCheckArgs',
    26 => 'SomCheckId',
    27 => 'SomCompareIds',
    28 => 'SomConstructClass',
    29 => 'SomEndPersistentIds',
    30 => 'SomEnvironmentNew',
    31 => 'SomIdFromString',
    32 => 'SomLPrintf',
    33 => 'SomParentResolve',
    34 => 'SomPrefixLevel',
    35 => 'SomPrintf',
    36 => 'SomRegisterId',
    37 => 'SomResolve',
    38 => 'SomSaveMetrics',
    39 => 'SomSetExpectedIds',
    40 => 'SomStringFromId',
    41 => 'SomTest',
    42 => 'SomTestCls',
    43 => 'SomTotalRegIds',
    44 => 'SomUniqueKey',
    45 => 'SomVprintf',
    46 => 'SomWriteMetrics',
    47 => 'SomDataResolve',
  },

  'REXX' => {
    1 => 'RexxStart',
    2 => 'RexxVariablePool',
    3 => 'RexxSetHalt',
    4 => 'RexxSetTrace',
    5 => 'RexxResetTrace',
    6 => 'RXTRACERESET',
    7 => 'RXBREAKCLEANUP',
    8 => 'RXVAR',
    9 => 'REXXSAA',
    10 => 'RXHALTSET',
    11 => 'RXTRACESET',
  },

  'REXXAPI' => {
    1 => 'RexxCreateQueue',
    2 => 'RexxDeleteQueue',
    3 => 'RexxAddQueue',
    4 => 'RexxPullQueue',
    5 => 'RexxQueryQueue',
    6 => 'RexxRegisterSubcomDll',
    7 => 'RexxRegisterSubcomExe',
    8 => 'RexxQuerySubcom',
    9 => 'RexxDeregisterSubcom',
    10 => 'RexxLoadSubcom',
    11 => 'RexxRegisterExitDll',
    12 => 'RexxRegisterExitExe',
    13 => 'RexxDeregisterExit',
    14 => 'RexxQueryExit',
    15 => 'RexxCallExit',
    16 => 'RexxCallSubcom',
    17 => 'RexxRegisterFunctionDll',
    18 => 'RexxRegisterFunctionExe',
    19 => 'RexxDeregisterFunction',
    20 => 'RexxQueryFunction',
    21 => 'RexxCallFunction',
    22 => 'RexxAddMacro',
    23 => 'RexxDropMacro',
    24 => 'RexxClearMacroSpace',
    25 => 'RexxLoadMacroSpace',
    26 => 'RexxQueryMacro',
    27 => 'RexxReorderMacro',
    28 => 'RexxSaveMacroSpace',
    29 => 'RexxExecuteMacroFunction',
    30 => 'RXMACROLOAD',
    31 => 'RXMACROSAVE',
    32 => 'RXSUBCOMLOAD',
    33 => 'RXMACRODROP',
    34 => 'RXEXITQUERY',
    35 => 'RXMACROERASE',
    36 => 'RXSUBCOMDROP',
    37 => 'RXMACROQUERY',
    38 => 'RXMACROCHANGE',
    39 => 'RXSUBCOMQUERY',
    40 => 'RXFUNCTIONCALL',
    41 => 'RXEXITREGISTER',
    42 => 'RXMACROREORDER',
    43 => 'RXSUBCOMEXECUTE',
    44 => 'RXSUBCOMREGISTER',
    45 => 'RXFUNCTIONQUERY',
    46 => 'RXFUNCTIONREGISTER',
    47 => 'RXEXITDROP',
    48 => 'RXFUNCTIONDEREGISTER',
  },

  'MDM' => {
    1 => 'mciSendCommand',
    2 => 'mciSendString',
    3 => 'mciGetErrorString',
    6 => 'mciQueryDefaultConnections',
    7 => 'mciDefaultConnection',
    8 => 'mciQueryConnections',
    9 => 'mciConnection',
    10 => 'mciSetSysValue',
    11 => 'mciQuerySysValue',
    12 => 'mciMakeGroup',
    13 => 'mciDeleteGroup',
    16 => 'mciGetDeviceID',
    17 => 'mdmDriverNotify',
    18 => 'MCI16GETERRORSTRING',
    19 => 'MCI16SENDSTRING',
    20 => 'MCI16GETDEVICEID',
    21 => 'MM_DosLoadModule',
    22 => 'mdmAPMEntry',
  },

  'HELPMGR' => {
    1 => 'WinCreateHelpInstance',
    2 => 'WinDestroyHelpInstance',
    3 => 'WinQueryHelpInstance',
    4 => 'WinAssociateHelpInstance',
    5 => 'WinLoadHelpTable',
    6 => 'WinCreateHelpTable',
    7 => 'HMWindowProc',
    8 => 'HelpProcessor',
    9 => 'CoverPageFrameWindowProc',
    10 => 'CoverPageWindowProc',
    11 => 'PageFrameWindowProc',
    12 => 'PageWindowProc',
    13 => 'FootnoteFrameWindowProc',
    14 => 'FootnoteWindowProc',
    15 => 'SearchDlgProc',
    16 => 'PrtPrintDlgProc',
    17 => 'ListWindowProc',
    18 => 'ListFrameWindowProc',
    19 => 'IndexWindowProc',
    20 => 'IndexFrameWindowProc',
    21 => 'TocWindowProc',
    22 => 'TocFrameWindowProc',
    23 => 'BmBookMarkDlgProc',
    24 => 'HistoryFrameWindowProc',
    25 => 'HistoryWindowProc',
    26 => 'WinCreateBookInstance',
    27 => 'BmCuaLogoDlgProc',
    28 => 'IoLoadAllToc',
    29 => 'IoLoadAllIndex',
    30 => 'IoFreeAllToc',
    31 => 'IoFreeAllIndex',
    32 => 'IoFreeIoInfolist',
    33 => 'FindWildPattern',
    34 => 'FindPattern',
    35 => 'FindTokenPattern',
    36 => 'GetStrToken',
    37 => 'HmSetHelpDatabase',
    38 => 'MscCleanup',
    39 => 'HpfsSplitPath',
    40 => 'ChopDot',
    41 => 'MakeHpfsFileList',
    42 => 'GoodList',
    43 => 'IsValidHpfsName',
    44 => 'HpfsMakeFullPathname',
    45 => 'MscAppendInf',
    46 => 'MscStricmp',
    47 => 'MscStrnicmp',
    48 => 'LibraryFrameWindowProc',
    49 => 'LibraryWindowProc',
    50 => 'WinxxCreateHelpInstance',
    51 => 'Win32CreateHelpInstance',
    52 => 'Win32DestroyHelpInstance',
    53 => 'Win32QueryHelpInstance',
    54 => 'Win32AssociateHelpInstance',
    55 => 'Win32LoadHelpTable',
    56 => 'Win32CreateHelpTable',
    57 => 'AcvpWindowProc',
    58 => 'AcvpFrameWindowProc',
    74 => 'DdfInitialize',
    75 => 'DdfPara',
    76 => 'DdfSetFormat',
    77 => 'DdfSetTextAlign',
    78 => 'DdfSetColor',
    79 => 'DdfInform',
    80 => 'DdfSetFontStyle',
    81 => 'DdfHyperText',
    82 => 'DdfBeginList',
    83 => 'DdfListItem',
    84 => 'DdfEndList',
    85 => 'DdfText',
    86 => 'DdfMetafile',
    87 => 'DdfSetFont',
    88 => 'DdfBitmap',
    89 => 'SearchMindex',
    90 => 'DbmStrtok2',
  },

  'LIBUNI' => {
    1 => 'UniQueryXdigit',
    2 => 'UniQuerySpace',
    3 => 'UniQueryPrint',
    4 => 'UniQueryGraph',
    5 => 'UniQueryCntrl',
    6 => 'UniQueryAlpha',
    7 => 'UniFreeAttrObject',
    8 => 'UniQueryCharAttr',
    9 => 'UniQueryUpper',
    10 => 'UniQueryPunct',
    11 => 'UniQueryLower',
    12 => 'UniQueryDigit',
    13 => 'UniQueryBlank',
    14 => 'UniQueryAlnum',
    15 => 'UniScanForAttr',
    16 => 'UniCreateAttrObject',
    17 => 'UniCreateTransformObject',
    18 => 'UniFreeTransformObject',
    19 => 'UniQueryLocaleObject',
    20 => 'UniCreateLocaleObject',
    21 => 'UniFreeLocaleObject',
    22 => 'UniFreeMem',
    28 => 'UniFreeLocaleInfo',
    29 => 'UniQueryLocaleInfo',
    30 => 'UniQueryLocaleItem',
    31 => 'UniStrcat',
    32 => 'UniStrchr',
    33 => 'UniStrcmp',
    34 => 'UniStrcmpi',
    35 => 'UniStrcoll',
    36 => 'UniStrcpy',
    37 => 'UniStrcspn',
    38 => 'UniStrfmon',
    39 => 'UniStrftime',
    40 => 'UniStrlen',
    41 => 'UniStrncat',
    42 => 'UniStrncmp',
    43 => 'UniStrncmpi',
    44 => 'UniStrncpy',
    45 => 'UniStrpbrk',
    46 => 'UniStrptime',
    47 => 'UniStrrchr',
    48 => 'UniStrspn',
    49 => 'UniStrstr',
    50 => 'UniStrtod',
    51 => 'UniStrtol',
    52 => 'UniStrtoul',
    53 => 'UniStrxfrm',
    54 => 'UniLocaleStrToToken',
    55 => 'UniLocaleTokenToStr',
    56 => 'UniTransformStr',
    57 => 'UniTransLower',
    58 => 'UniTransUpper',
    59 => 'UniTolower',
    60 => 'UniToupper',
    61 => 'UniStrupr',
    62 => 'UniStrlwr',
    63 => 'UniStrtok',
    67 => 'UniMapCtryToLocale',
    70 => 'UniMakeKey',
    71 => 'UniQueryChar',
    72 => 'UniGetOverride',
    73 => 'UniGetColval',
    74 => 'UniQueryAttr',
    75 => 'UniQueryStringType',
    76 => 'UniQueryCharType',
    77 => 'UniQueryNumericValue',
    78 => 'UniQueryCharTypeTable',
    80 => 'UniProcessUconv',
    151 => 'Locale',
    152 => 'UniMakeUserLocale',
    153 => 'UniSetUserLocaleItem',
    154 => 'UniDeleteUserLocale',
    155 => 'UniCompleteUserLocale',
    156 => 'UniQueryLocaleValue',
    157 => 'UniQueryLocaleList',
    158 => 'UniQueryLanguageName',
    159 => 'UniQueryCountryName',
  },

  'UCONV' => {
    1 => 'UniCreateUconvObject',
    2 => 'UniUconvToUcs',
    3 => 'UniUconvFromUcs',
    4 => 'UniFreeUconvObject',
    7 => 'UniQueryUconvObject',
    8 => 'UniSetUconvObject',
    9 => 'UniQueryUconvCp',
    10 => 'UniMapCpToUcsCp',
    11 => 'UniStrFromUcs',
    12 => 'UniStrToUcs',
    13 => '_UniMalloc',
    14 => '_UniFree',
  },

  'FFST' => {
    1 => 'FFSTProbe',
    2 => 'FFSTQueryConfiguration',
    3 => 'FFSTSetConfiguration',
  },

  'SOFTDRAW' => {
    1 => 'SDEntry',
    2 => 'SDBitBlt',
    3 => 'SDLine',
  },

  'TCPIP32' => {
    1 => 'ACCEPT',
    2 => 'BIND',
    3 => 'CONNECT',
    4 => 'GETHOSTID',
    5 => 'GETPEERNAME',
    6 => 'GETSOCKNAME',
    7 => 'GETSOCKOPT',
    8 => 'IOCTL',
    9 => 'LISTEN',
    10 => 'RECV',
    11 => 'RECVFROM',
    12 => 'OS2_SELECT',
    13 => 'SEND',
    14 => 'SENDTO',
    15 => 'SETSOCKOPT',
    16 => 'SOCKET',
    17 => 'SOCLOSE',
    18 => 'SO_CANCEL',
    19 => 'SOABORT',
    20 => 'SOCK_ERRNO',
    21 => 'RECVMSG',
    22 => 'SENDMSG',
    23 => 'READV',
    24 => 'WRITEV',
    25 => 'SHUTDOWN',
    26 => 'SOCK_INIT',
    27 => 'ADDSOCKETTOLIST',
    28 => 'REMOVESOCKETFROMLIST',
    29 => 'CLEANUPSOCKETS',
    30 => 'PSOCK_ERRNO',
    31 => 'GETINETVERSION',
    32 => 'SELECT',
    33 => 'mktime',
    35 => 'SET_ERRNO',
    38 => 'WINSOCKCLEANUPSOCKETS',
    102 => 'GETTIMEOFDAY',
    103 => 'LSWAP',
    104 => 'BSWAP',
    105 => 'INET_ADDR',
    106 => 'INET_LNAOF',
    107 => 'INET_NETOF',
    108 => 'INET_MAKEADDR',
    109 => 'INET_NETWORK',
    110 => 'INET_NTOA',
    111 => 'GETHOSTBYNAME',
    112 => 'GETHOSTBYADDR',
    113 => 'GETNETBYNAME',
    114 => 'GETNETBYADDR',
    115 => 'SETNETENT',
    116 => 'ENDNETENT',
    117 => 'GETNETENT',
    118 => 'SETPROTOENT',
    119 => 'ENDPROTOENT',
    120 => 'GETPROTOENT',
    121 => 'GETPROTOBYNAME',
    122 => 'GETPROTOBYNUMBER',
    123 => 'GETSERVBYPORT',
    124 => 'GETSERVBYNAME',
    125 => 'SETSERVENT',
    126 => 'ENDSERVENT',
    127 => 'GETSERVENT',
    128 => 'SETHOSTENT',
    129 => 'ENDHOSTENT',
    130 => 'GETHOSTENT',
    131 => '__DN_EXPAND',
    132 => '__DN_COMP',
    133 => '__DN_SKIPNAME',
    134 => 'DN_FIND',
    135 => '_GETSHORT',
    136 => '_GETLONG',
    137 => '__PUTSHORT',
    138 => '__PUTLONG',
    139 => '__RES_INIT',
    140 => '__RES_MKQUERY',
    141 => '__RES_SEND',
    142 => 'H_ERRNO',
    143 => '_RESS',
    144 => 'GETHOSTNAME',
    145 => 'REXEC',
    151 => 'TCP_H_ERRNO1',
    152 => '__RES_SEARCH',
    153 => '__RES_QUERY',
    154 => '__RES_QUERYDOMAIN',
    156 => 'RACCEPT',
    157 => 'RBIND',
    158 => 'RCONNECT',
    159 => 'RGETSOCKNAME',
    160 => 'RLISTEN',
    161 => 'RGETHOSTBYNAME',
    200 => 'OS2_IOCTL',
    201 => '__TCPFDISSET',
    202 => 'CONV_SOCKADDR_PARMS',
    203 => 'HTONL',
    204 => 'NTOHL',
    205 => 'HTONS',
    206 => 'NTOHS',
    207 => 'SYSCTL',
    208 => 'HERROR',
    209 => 'HSTRERROR',
    211 => '__P_CLASS_SYMS',
    212 => '__P_TYPE_SYMS',
    213 => '__RES_HNOK',
    214 => '__RES_OWNOK',
    215 => '__RES_MAILOK',
    216 => '__RES_DNOK',
    217 => '__SYM_STON',
    218 => '__SYM_NTOS',
    219 => '__SYM_NTOP',
    220 => '__B64_NTOP',
    221 => '__B64_PTON',
    222 => '__LOC_ATON',
    223 => '__LOC_NTOA',
    224 => '__FP_RESSTAT',
    225 => '__FP_QUERY',
    226 => '__FP_NQUERY',
    227 => '__HOSTALIAS',
    228 => '__P_CLASS',
    229 => '__P_TIME',
    230 => '__P_TYPE',
    231 => '__P_QUERY',
    232 => '__P_CDNNAME',
    233 => '__P_CDNAME',
    234 => '__P_FQNNAME',
    235 => '__P_FQNAME',
    236 => '__P_RR',
    237 => '__P_OPTION',
    238 => '__P_SECSTODATE',
    239 => '__DN_COUNT_LABELS',
    240 => '__RES_RANDOMID',
    241 => '__RES_ISOURSERVER',
    242 => '__RES_NAMEINQUERY',
    243 => '__RES_QUERIESMATCH',
    244 => '__RES_CLOSE',
    245 => 'GETHOSTBYNAME2',
    246 => 'INET_ATON',
    247 => 'INET_NETA',
    248 => 'INET_NET_NTOP',
    249 => 'INET_NET_PTON',
    250 => 'INET_PTON',
    251 => 'INET_NTOP',
    252 => 'INET_NSAP_ADDR',
    253 => 'INET_NSAP_NTOA',
    254 => 'SOCKETPAIR',
    255 => 'SOCK_STRERROR',
    256 => 'ACCEPT_AND_RECV',
    257 => 'SEND_FILE',
    300 => 'KERNCHKACC',
    301 => 'CONVERT16TO32BITADDR',
    302 => 'SOCKETMAIN',
  },

  'NAMPIPES' => {
    1 => 'DosMakeNmPipe',
    2 => 'DosQNmPipeInfo',
    3 => 'DosConnectNmPipe',
    4 => 'DosDisconnectNmPipe',
    5 => 'DosQNmPHandState',
    6 => 'DosSetNmPHandState',
    7 => 'DosPeekNmPipe',
    8 => 'DosWaitNmPipe',
    9 => 'DosTransactNmPipe',
    10 => 'DosCallNmPipe',
    11 => 'DosRawReadNmPipe',
    12 => 'DosRawWriteNmPipe',
    13 => 'DosSetNmPipeSem',
    14 => 'DosQNmPipeSemState',
  },

  'TCP32DLL' => {
    1 => 'SETTIMEOFDAY',
    2 => 'GETTIMEOFDAY',
    3 => 'LSWAP',
    4 => 'BSWAP',
    5 => 'INET_ADDR',
    6 => 'INET_LNAOF',
    7 => 'INET_NETOF',
    8 => 'INET_MAKEADDR',
    9 => 'INET_NETWORK',
    10 => 'INET_NTOA',
    11 => 'GETHOSTBYNAME',
    12 => 'GETHOSTBYADDR',
    13 => 'GETNETBYNAME',
    14 => 'GETNETBYADDR',
    15 => 'SETNETENT',
    16 => 'ENDNETENT',
    17 => 'GETNETENT',
    18 => 'SETPROTOENT',
    19 => 'ENDPROTOENT',
    20 => 'GETPROTOENT',
    21 => 'GETPROTOBYNAME',
    22 => 'GETPROTOBYNUMBER',
    23 => 'GETSERVBYPORT',
    24 => 'GETSERVBYNAME',
    25 => 'SETSERVENT',
    26 => 'ENDSERVENT',
    27 => 'GETSERVENT',
    28 => 'SETHOSTENT',
    29 => 'ENDHOSTENT',
    30 => 'GETHOSTENT',
    31 => 'DN_EXPAND',
    32 => 'DN_COMP',
    33 => 'DN_SKIPNAME',
    34 => 'DN_FIND',
    35 => '_GETSHORT',
    36 => '_GETLONG',
    37 => 'PUTSHORT',
    38 => 'PUTLONG',
    39 => 'RES_INIT',
    40 => 'RES_MKQUERY',
    41 => 'RES_SEND',
    42 => 'H_ERRNO',
    43 => '_RES',
    44 => 'GETHOSTNAME',
    45 => 'REXEC',
    46 => '_GETHTBYNAME',
    47 => '_GETHTBYADDR',
    48 => 'GETHOSTBYNAME_R',
    49 => 'GETHOSTBYADDR_R',
    50 => 'GETSERVBYNAME_R',
    51 => 'TCP_H_ERRNO',
    52 => 'RES_SEARCH',
    53 => 'RES_QUERY',
    54 => 'RES_QUERYDOMAIN',
    55 => 'OS2_GETHOSTBYNAME',
    56 => 'RACCEPT',
    57 => 'RBIND',
    58 => 'RCONNECT',
    59 => 'RGETSOCKNAME',
    60 => 'RLISTEN',
    61 => 'RGETHOSTBYNAME',
    63 => 'direct',
    64 => 'SOCKSinit',
    65 => 'GETHOSTBYNAMEMSC',
    66 => 'GETHOSTBYADDRMSC',
    67 => 'GETNETBYNAMEMSC',
    68 => 'GETNETBYADDRMSC',
    69 => 'GETPROTOBYNAMEMSC',
    70 => 'GETPROTOBYNUMBERMSC',
    71 => 'GETSERVBYNAMEMSC',
    72 => 'GETSERVBYPORTMSC',
    73 => 'SETHOSTENTMSC',
    74 => 'GETHOSTENTMSC',
    75 => 'ENDHOSTENTMSC',
    76 => 'SETNETENTMSC',
    77 => 'GETNETENTMSC',
    78 => 'ENDNETENTMSC',
    79 => 'SETPROTOENTMSC',
    80 => 'GETPROTOENTMSC',
    81 => 'ENDPROTOENTMSC',
    82 => 'SETSERVENTMSC',
    83 => 'GETSERVENTMSC',
    84 => 'ENDSERVENTMSC',
    85 => 'INET_ADDRMSC',
    86 => 'INET_LNAOFMSC',
    87 => 'INET_NETOFMSC',
    88 => 'INET_MAKEADDRMSC',
    89 => 'INET_NETWORKMSC',
    90 => 'INET_NTOAMSC',
    91 => '_GETSHORTMSC',
    92 => '_GETLONGMSC',
    93 => 'PUTSHORTMSC',
    94 => 'PUTLONGMSC',
    95 => 'DN_COMPMSC',
    96 => 'DN_EXPANDMSC',
    97 => 'DN_FINDMSC',
    98 => 'DN_SKIPNAMEMSC',
    99 => 'RES_INITMSC',
    100 => 'RES_MKQUERYMSC',
    101 => 'RES_QUERYMSC',
    102 => 'RES_QUERYDOMAINMSC',
    103 => 'RES_SENDMSC',
    104 => 'RES_SEARCHMSC',
    105 => 'RES16',
    106 => 'REXECMSC',
    107 => 'H_ERRNO16',
  },

  'OS2SM' => {
    1 => 'WinInitSessionMgr',
    2 => 'WinSetFgndWindow',
    3 => 'ShlUnloadPublicFonts',
    4 => 'WinStpRegister',
    5 => 'WinInstStartApp',
    6 => 'WinTerminateApp',
    7 => 'WinCreateSwitchEntry',
    8 => 'WinQuerySessionTitle',
    9 => 'WinAddSwitchEntry',
    10 => 'WinChangeSwitchEntry',
    11 => 'WinQuerySwitchEntry',
    12 => 'WinQuerySwitchHandle',
    13 => 'WinQueryTaskTitle',
    14 => 'WinQueryTaskSizePos',
    15 => 'WinQuerySwitchList',
    16 => 'WinRemoveSwitchEntry',
    17 => 'WinSwitchToProgram',
    18 => 'WinSwitchProgramRegister',
    21 => 'WinEndProgram',
    22 => 'WinStopProgram',
    23 => 'WinEndWindowSession',
    24 => 'lpfnShellWndProc',
    25 => 'lpfnIconWndProc',
    26 => 'WinSwitchToTaskManager',
    27 => 'fnBadAppDlgProc',
    28 => 'WinSwitchToProgram2',
    29 => 'WinProcessHotKey',
    31 => 'WinInitSession',
    32 => 'WinEndSession',
    33 => 'WinInitSwEntry',
    34 => 'WinSetSwEntry',
    35 => 'WinQueryExtIDFocus',
    36 => 'WinSetExtIDFocus',
    37 => 'SheSystemShutdown',
    38 => 'StartSystemExecutables',
    39 => 'ShlLoadPublicFonts',
    40 => 'WinNoShutdown',
    41 => 'SheInitializeIniFile',
    42 => 'WinSetTitle',
    43 => 'WinCplRegister',
    44 => 'WinPMFileRegister',
    45 => 'SheStartLongProgram',
    46 => 'StartStartUpDotCmd',
    47 => 'WinCanTerminate',
    103 => 'ShellWindow',
  },

  'MONCALLS' => {
    1 => 'DosMonWrite',
    2 => 'DosMonRead',
    3 => 'DosMonClose',
    4 => 'DosMonOpen',
    5 => 'DosMonReg',
  },

  'MCIAPI' => {
    2 => 'mciRxSendString',
    3 => 'mciRxGetErrorString',
    4 => 'mciRxGetDeviceID',
    5 => 'mciRxInit',
    6 => 'mciRxExit',
    10 => 'mciPlayFile',
    11 => 'mciPlayResource',
    12 => 'mciRecordAudioFile',
    13 => 'MCI16PLAYFILE',
    14 => 'MCI16PLAYRESOURCE',
    15 => 'MCI16RECORDAUDIOFILE',
    16 => 'mmioRemoveElement',
    17 => 'MMIO16REMOVEELEMENT',
    18 => 'mmioFindElement',
    19 => 'MMIO16FINDELEMENT',
    20 => 'MCI32PLAYFILE',
    21 => 'MCI32PLAYRESOURCE',
    22 => 'MCI32RECORDAUDIOFILE',
    23 => 'MMIO32REMOVEELEMENT',
    24 => 'MMIO32FINDELEMENT',
    25 => 'mciCreatePlayFilePalette',
  },

  'DIVE' => {
    1 => 'DiveQueryCaps',
    2 => 'DiveOpen',
    3 => 'DiveClose',
    4 => 'DiveSetupBlitter',
    5 => 'DiveBlitImage',
    6 => 'DiveAcquireFrameBuffer',
    7 => 'DiveSwitchBank',
    8 => 'DiveDeacquireFrameBuffer',
    9 => 'DiveSetDestinationPalette',
    10 => 'DiveSetSourcePalette',
    11 => 'DiveCalcFrameBufferAddress',
    12 => 'DiveAllocImageBuffer',
    13 => 'DiveFreeImageBuffer',
    14 => 'DiveBeginImageBufferAccess',
    15 => 'DiveEndImageBufferAccess',
    16 => 'DiveFullScreenInit',
    17 => 'DiveFullScreenTerm',
    18 => 'DiveSetTransparentBlitMode',
    19 => 'DiveBlitImageLines',
    20 => '_DIVEInitTerm',
  },

  'BDCALLS' => {
    1 => 'NlsConvertBidiNumerics',
    2 => 'NlsConvertBidiString',
    3 => 'NlsIntSetBidiAtt',
    4 => 'NlsIntQueryBidiAtt',
    5 => 'NlsSetBidiAtt',
    6 => 'NlsQueryBidiAtt',
    7 => 'NlsInverseString',
    8 => 'NlsSetBidiPrint',
    9 => 'NlsEditShape',
    10 => 'NlsShapeBidiString',
    11 => 'NlPopUp',
  },

  'MMIO' => {
    2 => 'mmiohlpCleanupInstance',
    3 => 'mmiohlpListCreate',
    4 => 'mmiohlpListAdd',
    5 => 'mmiohlpListGet',
    6 => 'mmiohlpListFind',
    7 => 'mmiohlpListInsert',
    8 => 'mmiohlpListChange',
    9 => 'mmiohlpListDelete',
    10 => 'mmiohlpListGetHeader',
    11 => 'mmiohlpConvertAddressToHmmio',
    12 => 'mmiohlpConvertHmmioToAddress',
    13 => 'mmiohlpFreeHmmioEntry',
    14 => 'mmiohlpGrowHmmioTable',
    15 => 'mmiohlpGenerateHmmio',
    16 => 'mmiohlpAcquireMmioSem',
    17 => 'mmiohlpDiscardMmioSem',
    18 => 'mmiohlpReadIniFile',
    19 => 'mmiohlpLoadDefIOProcs',
    20 => 'mmiohlpUnloadDefIOProcs',
    21 => 'mmiohlpRestoreInfoState',
    22 => 'mmiohlpAllocateInternalBuffer',
    23 => 'mmiohlpExpandMemFile',
    24 => 'mmioStringToFOURCC',
    25 => 'mmioGetLastError',
    26 => 'mmioInstallIOProc',
    27 => 'mmioOpen',
    28 => 'mmioRead',
    29 => 'mmioWrite',
    30 => 'mmioSeek',
    31 => 'mmioFlush',
    32 => 'mmioClose',
    33 => 'DOSIOProc',
    34 => 'MEMIOProc',
    35 => 'BNDIOProc',
    36 => 'mmioAscend',
    37 => 'mmioDescend',
    38 => 'mmioCreateChunk',
    39 => 'mmioGetInfo',
    40 => 'mmioSetInfo',
    41 => 'mmioSendMessage',
    42 => 'mmioAdvance',
    43 => 'mmioSetBuffer',
    44 => 'mmioCFOpen',
    45 => 'mmioCFClose',
    46 => 'mmioCFAddEntry',
    47 => 'mmioCFDeleteEntry',
    48 => 'mmioCFChangeEntry',
    49 => 'mmioCFFindEntry',
    50 => 'mmioCFAddElement',
    51 => 'mmioCFGetInfo',
    52 => 'mmioCFSetInfo',
    53 => 'mmioCFCopy',
    54 => 'mmiohlpBuildCtoc',
    55 => 'mmiohlpCreateCtoc',
    56 => 'mmiohlpRewriteCtoc',
    57 => 'mmiohlpGetHeaderInfo',
    58 => 'mmiohlpUpdateCtocHeader',
    59 => 'mmiohlpChangeCtocHeader',
    60 => 'mmiohlpGetRemainingSize',
    61 => 'mmiohlpFindOpenCtoc',
    62 => 'mmiohlpGetFullPathName',
    63 => 'mmiohlpAddCtocInstance',
    64 => 'mmiohlpRemoveCtocInstance',
    65 => 'mmiohlpLastModTime',
    66 => 'mmiohlpOpenTempElement',
    67 => 'mmiohlpCloseTempElement',
    68 => 'mmiohlpTempName',
    69 => 'mmiohlpRemoveSharingEntry',
    70 => 'mmiohlpAddSharingEntry',
    71 => 'mmiohlpCheckSharingMode',
    72 => 'mmiohlpCheckHmmcfSharingMode',
    73 => 'mmiohlpListTransferNode',
    74 => 'mmioQueryFormatCount',
    75 => 'mmioGetFormats',
    76 => 'mmioQueryHeaderLength',
    77 => 'mmioGetHeader',
    78 => 'mmioSetHeader',
    79 => 'mmioIdentifyFile',
    80 => 'mmioGetFormatName',
    81 => 'mmiohlpGetFormatStringLength',
    82 => 'mmiohlpGetFormatString',
    83 => 'mmiohlpGetNLSData',
    84 => 'CFIOProc',
    85 => 'mmioIniFileHandler',
    86 => 'mmioIdentifyFileFormat',
    87 => 'mmioIdentifyStorageSystem',
    88 => 'mmioDetermineSSIOProc',
    89 => 'mmioDetermineFFIOProc',
    90 => 'mmioDetermineLastIOProc',
    91 => 'mmiohlpIsFccSS',
    92 => 'mmiohlpIsFccFF',
    93 => 'mmioQueryIOProcModuleHandle',
    94 => 'mmiohlpGetElementStart',
    95 => 'mmiohlpChangeSharingEntry',
    96 => 'mmiohlpLoadNextIOProc',
    97 => 'mmiohlpLoadIOProc',
    98 => 'mmioMigrateIniFile',
    99 => 'mmioIniFileCODEC',
    100 => 'mmioCFCompact',
    101 => 'mmioSet',
    102 => 'mmioQueryCODECName',
    103 => 'mmiohlpCFName',
    104 => 'mmioLoadCODECProc',
    105 => 'mmioQueryCODECNameLength',
    106 => 'mmioGetData',
  },

  'MOUCALLS' => {
    1 => 'MouGetPtrShape',
    2 => 'MouSetPtrShape',
    3 => 'MouGetNumMickeys',
    4 => 'MouGetHotKey',
    5 => 'MouShellInit',
    6 => 'MouGetScaleFact',
    7 => 'MouFlushQue',
    8 => 'MouGetNumButtons',
    9 => 'MouClose',
    10 => 'MouSetHotKey',
    11 => 'MouSetScaleFact',
    12 => 'MouFree',
    13 => 'MouGetNumQueEl',
    14 => 'MouDeRegister',
    15 => 'MouGetEventMask',
    16 => 'MouSetEventMask',
    17 => 'MouOpen',
    18 => 'MouRemovePtr',
    19 => 'MouGetPtrPos',
    20 => 'MouReadEventQue',
    21 => 'MouSetPtrPos',
    22 => 'MouGetDevStatus',
    23 => 'MouSynch',
    24 => 'MouRegister',
    25 => 'MouSetDevStatus',
    26 => 'MouDrawPtr',
    27 => 'MouInitReal',
    29 => 'MouGetThreshold',
    30 => 'MouSetThreshold',
  },

  'PMBIDI' => {
    1 => 'PMBidi_Initialize',
    10 => 'WIN16SETLANGINFO',
    11 => 'WIN16QUERYLANGINFO',
    12 => 'WIN16SETKBDLAYER',
    13 => 'WIN16QUERYKBDLAYER',
    14 => 'WIN16SETLANGVIEWER',
    15 => 'WIN16QUERYLANGVIEWER',
    18 => 'WIN16SETPROCESSLANGINFO',
    19 => 'WIN16QUERYPROCESSLANGINFO',
    20 => 'Win32SetLangInfo',
    21 => 'Win32QueryLangInfo',
    22 => 'Win32SetKbdLayer',
    23 => 'Win32QueryKbdLayer',
    24 => 'Win32SetLangViewer',
    25 => 'Win32QueryLangViewer',
    30 => 'Win32SetProcessLangInfo',
    31 => 'Win32QueryProcessLangInfo',
    40 => 'GPI16SETBIDIATTR',
    41 => 'GPI16QUERYBIDIATTR',
    50 => 'Gpi32SetBidiAttr',
    51 => 'Gpi32QueryBidiAttr',
    60 => 'Bidi_QueryCp',
    61 => 'BIDI_16QUERYCP',
    101 => 'PMBIDI_Get_StdDlgLang_Setting',
    102 => 'PMBIDI_16GET_STDDLGLANG_SETTING',
    110 => 'PMBIDI_String_To_BinVal',
    111 => 'PMBIDI_BinVal_To_String',
    112 => 'PMBIDI_Keyword_To_BinVal',
    113 => 'PMBIDI_Get_HelpBidi_Setting',
    200 => 'NLS16CONVERTBIDISTRING',
    201 => 'NLS16EDITSHAPE',
    202 => 'NLS16INVERSESTRING',
    203 => 'NLS16SHAPEBIDISTRING',
    204 => 'NLS16CONVERTBIDINUMERICS',
    205 => 'Nls32ConvertBidiString',
    206 => 'Nls32EditShape',
    207 => 'Nls32InverseString',
    208 => 'Nls32ShapeBidiString',
    209 => 'Nls32ConvertBidiNumerics',
    306 => 'layout_object_create',
    307 => 'layout_object_destroy',
    308 => 'layout_object_transform',
    309 => 'layout_object_editshape',
    310 => 'layout_object_setvalues',
    311 => 'layout_object_getvalues',
    400 => 'PMBIDI_16CP_TRANSLATE_STRING',
    401 => 'PMBIDI_CpTranslateString',
    450 => 'Bidi_MapSrcToTrg',
    451 => 'Bidi_ClassifyCodepage',
    452 => 'Bidi_IsStringBidi',
    453 => 'Bidi_IsStringAllBidi',
    454 => 'Bidi_ReverseString',
    460 => 'Bidi_LayoutConvert',
    461 => 'Bidi_LayoutEdit',
    999 => 'ulProcess_BidiAttr',
  },

  'PMPIC' => {
    1 => 'PicPrint',
    2 => 'PicIchg',
    3 => 'Pif2Met',
    4 => 'PrfPif2Met',
    5 => 'PicFileOpenDialog',
    11 => 'Pic32Print',
    12 => 'Pic32Ichg',
    13 => 'Prf32Pif2Met',
  },

  'PMVIOP' => {
    1 => 'WinCreateConsole',
    2 => 'WinDestroyConsole',
    3 => 'WinSyncWithPS',
    4 => 'WinConsoleOpenKbd',
    5 => 'WinConsoleCloseKbd',
    6 => 'WinConsoleSetStatus',
    7 => 'WinConsoleGetStatus',
    8 => 'WinConsoleSetCP',
    10 => 'WinConsoleGetCP',
    11 => 'WinConsoleKbdXlate',
    12 => 'WinConsoleSetCustXt',
    13 => 'WinConsoleGetFocus',
    14 => 'WinConsoleFreeFocus',
    15 => 'WinConsoleReadKeyEvent',
    16 => 'WinConsoleFlushKeyEvents',
    17 => 'WinConsoleQueuedPointerEvents',
    18 => 'WinConsoleReadPointerEvent',
    19 => 'WinConsoleFlushPointerEvents',
    20 => 'WinConsoleGetPointerFilterMask',
    21 => 'WinConsoleSetPointerFilterMask',
    22 => 'WinConsoleGetPtrPos',
    23 => 'WinConsoleSetPtrPos',
    24 => 'WinShieldAbort',
    25 => 'ShieldFrameProc',
    26 => 'VioShieldWindowProc',
    27 => 'LockVioPS',
    28 => 'UnlockVioPS',
    29 => 'MarkingWindowProc',
    30 => 'WinDefAvioWindowProc',
    31 => 'WinConsoleGetKbdHandle',
    32 => 'WinConsoleAttachMouseUser',
    33 => 'WinConsoleDetachMouseUser',
    34 => 'TaskMgrSubClassProc',
    35 => 'WinShieldPreThaw',
    36 => 'WinInitShield',
    37 => 'Mortician',
    39 => 'UnlockSemaphores',
    40 => 'ClearData',
    41 => 'QueryConsole',
    42 => 'MakeVisible',
    43 => 'GetPasteChar',
    44 => 'SeamlessCommonVDM',
    45 => 'SeamlessControlProc',
    46 => 'TerminateClipDDE',
    47 => 'VDMClipDDENotify',
    49 => 'PM32ClipDDENotify',
    50 => 'Seamless32RegisterObject',
    51 => 'Seamless32ActivateWindow',
    52 => 'NotifyAllVDMs',
    53 => 'VDMSwapButtonNotify',
    54 => 'Get32DisplayType',
    55 => 'Seamless32RegisterAssocObj',
    56 => 'VdmRegisterHook',
    57 => 'VdmDeregisterHook',
    101 => 'ScreenGroupToFPConsole',
    102 => 'APFNVDMServ',
    103 => 'GetSelAccess',
    104 => 'NPSZStrings',
    105 => 'KeyboardEvent',
    106 => 'EstablishKbdEnvironment',
    107 => 'HMyModuleHandle',
    108 => 'FSeamlessCaptured',
    110 => 'HMQTaskmgr',
    111 => 'PCharXlateTblDefault',
    112 => 'HAPPSeamlessCommonVDM',
    114 => 'HAPPSeamlessCommonVDM31',
    116 => 'HAPPSeamlessCommonVDM31Enh',
    117 => 'FKbdHook',
    118 => 'FMouHook',
    119 => 'SelCommonList',
    120 => 'usCommonSegSize',
    121 => 'HMODSeamless',
    122 => 'HFrameWindowFromConsole',
  },

  'REGISTRY' => {
    1 => 'RegCloseKey',
    3 => 'RegCreateKeyA',
    4 => 'RegCreateKeyExA',
    5 => 'RegCreateKeyExW',
    6 => 'RegCreateKeyW',
    7 => 'RegDeleteKeyA',
    8 => 'RegDeleteKeyW',
    9 => 'RegDeleteValueA',
    10 => 'RegDeleteValueW',
    11 => 'RegEnumKeyA',
    12 => 'RegEnumKeyExA',
    13 => 'RegEnumKeyExW',
    14 => 'RegEnumKeyW',
    15 => 'RegEnumValueA',
    16 => 'RegEnumValueW',
    17 => 'RegFlushKey',
    22 => 'RegOpenKeyA',
    23 => 'RegOpenKeyExA',
    24 => 'RegOpenKeyExW',
    25 => 'RegOpenKeyW',
    26 => 'RegQueryInfoKeyA',
    27 => 'RegQueryInfoKeyW',
    30 => 'RegQueryValueA',
    31 => 'RegQueryValueExA',
    32 => 'RegQueryValueExW',
    33 => 'RegQueryValueW',
    42 => 'RegSetValueA',
    43 => 'RegSetValueExA',
    44 => 'RegSetValueExW',
    45 => 'RegSetValueW',
    50 => 'KRegInit',
    51 => 'KRegTerm',
  },

  'WPPRINT' => {
    1 => '_PdrClassData',
    2 => '_WPSpoolClassData',
    3 => '_QueueClassData',
    4 => '_QdrClassData',
    5 => '_WPPrinterCClassData',
    6 => '_PdrCClassData',
    7 => '_WPSpoolCClassData',
    8 => '_QdrCClassData',
    9 => '_LmCClassData',
    10 => '_JoCClassData',
    11 => '_LmClassData',
    12 => '_JoClassData',
    13 => 'WPPrinterNewClass',
    14 => '_WPRprinterCClassData',
    15 => 'QueueNewClass',
    16 => 'LmNewClass',
    17 => 'SomInitModule',
    18 => '_WPPrinterDriverClassData',
    19 => 'JoNewClass',
    20 => '_WPRprinterClassData',
    21 => '_WPPrinterDriverCClassData',
    22 => 'WPPMSpoolInit',
    23 => 'WPPMInitPrinterObjects',
    24 => 'WPSpoolNewClass',
    25 => 'WPRprinterNewClass',
    26 => 'WPPrinterDriverNewClass',
    27 => '_WPPrinterClassData',
    28 => '_PortClassData',
    29 => '_QueueCClassData',
    30 => 'PortNewClass',
    31 => 'QueryNetowrkPath',
    32 => 'PdrNewClass',
    33 => 'QdrNewClass',
    34 => '_PortCClassData',
    35 => 'DevNewClass',
    36 => '_DevClassData',
    37 => '_DevCClassData',
    101 => 'WPPMSpoolInit',
    102 => 'WPPMInitPrinterObjects',
    103 => 'SOMInitModule',
    105 => 'WPPrinterCClassData',
    106 => 'WPPrinterClassData',
    107 => 'WPPrinterNewClass',
    108 => 'WPJobCClassData',
    109 => 'WPJobClassData',
    110 => 'WPJobNewClass',
    111 => 'WPDevCClassData',
    112 => 'WPDevClassData',
    113 => 'WPDevNewClass',
    114 => 'WPPdrCClassData',
    115 => 'WPPdrClassData',
    116 => 'WPPdrNewClass',
    117 => 'WPLmCClassData',
    118 => 'WPLmClassData',
    119 => 'WPLmNewClass',
    120 => 'WPPortCClassData',
    121 => 'WPPortClassData',
    122 => 'WPPortNewClass',
    123 => 'WPQdrCClassData',
    124 => 'WPQdrClassData',
    125 => 'WPQdrNewClass',
    126 => 'WPQueueCClassData',
    127 => 'WPQueueClassData',
    128 => 'WPQueueNewClass',
    129 => 'WPSpoolCClassData',
    130 => 'WPSpoolClassData',
    131 => 'WPSpoolNewClass',
    132 => 'WPPrinterDriverCClassData',
    133 => 'WPPrinterDriverClassData',
    134 => 'WPPrinterDriverNewClass',
    135 => 'WPRPrinterCClassData',
    136 => 'WPRPrinterClassData',
    137 => 'WPRPrinterNewClass',
    138 => 'QueryNetworkPath',
    139 => 'DlgBeforePrint',
    140 => 'WPPrinterDriverPackedCClassData',
    141 => 'WPPrinterDriverPackedClassData',
    142 => 'WPPrinterDriverPackedNewClass',
    143 => 'M_WPPrinterCClassData',
    144 => 'M_WPPrinterClassData',
    145 => 'M_WPPrinterNewClass',
    146 => 'M_WPJobCClassData',
    147 => 'M_WPJobClassData',
    148 => 'M_WPJobNewClass',
    149 => 'M_WPPdrCClassData',
    150 => 'M_WPPdrClassData',
    151 => 'M_WPPdrNewClass',
    152 => 'M_WPPortCClassData',
    153 => 'M_WPPortClassData',
    154 => 'M_WPPortNewClass',
    155 => 'M_WPQdrCClassData',
    156 => 'M_WPQdrClassData',
    157 => 'M_WPQdrNewClass',
    158 => 'M_WPSpoolCClassData',
    159 => 'M_WPSpoolClassData',
    160 => 'M_WPSpoolNewClass',
    161 => 'M_WPRPrinterCClassData',
    162 => 'M_WPRPrinterClassData',
    163 => 'M_WPRPrinterNewClass',
  },

  'MMPM' => {
    1 => 'mciSendCommand',
    2 => 'mciSendString',
    3 => 'mciGetErrorString',
    4 => 'mciQueryDefaultConnections',
    5 => 'mciDefaultConnection',
    6 => 'mciQueryConnections',
    7 => 'mciConnection',
    8 => 'mciSetSysValue',
    9 => 'mciQuerySysValue',
    10 => 'mciMakeGroup',
    11 => 'mciDeleteGroup',
    12 => 'mciGetDeviceID',
    13 => 'mdmDriverNotify',
    14 => 'MM_DosLoadModule',
    15 => 'mmiohlpCleanupInstance',
    16 => 'mmiohlpListCreate',
    17 => 'mmiohlpListAdd',
    18 => 'mmiohlpListGet',
    19 => 'mmiohlpListFind',
    20 => 'mmiohlpListInsert',
    21 => 'mmiohlpListChange',
    22 => 'mmiohlpListDelete',
    23 => 'mmiohlpListGetHeader',
    24 => 'mmiohlpConvertAddressToHmmio',
    25 => 'mmiohlpConvertHmmioToAddress',
    26 => 'mmiohlpFreeHmmioEntry',
    27 => 'mmiohlpGrowHmmioTable',
    28 => 'mmiohlpGenerateHmmio',
    29 => 'mmiohlpAcquireMmioSem',
    30 => 'mmiohlpDiscardMmioSem',
    31 => 'mmiohlpReadIniFile',
    32 => 'mmiohlpLoadDefIOProcs',
    33 => 'mmiohlpUnloadDefIOProcs',
    34 => 'mmiohlpRestoreInfoState',
    35 => 'mmiohlpAllocateInternalBuffer',
    36 => 'mmiohlpExpandMemFile',
    37 => 'mmioStringToFOURCC',
    38 => 'mmioGetLastError',
    39 => 'mmioInstallIOProc',
    40 => 'mmioOpen',
    41 => 'mmioRead',
    42 => 'mmioWrite',
    43 => 'mmioSeek',
    44 => 'mmioFlush',
    45 => 'mmioClose',
    46 => 'DOSIOProc',
    47 => 'MEMIOProc',
    48 => 'BNDIOProc',
    49 => 'mmioAscend',
    50 => 'mmioDescend',
    51 => 'mmioCreateChunk',
    52 => 'mmioGetInfo',
    53 => 'mmioSetInfo',
    54 => 'mmioSendMessage',
    55 => 'mmioAdvance',
    56 => 'mmioSetBuffer',
    57 => 'mmioCFOpen',
    58 => 'mmioCFClose',
    59 => 'mmioCFAddEntry',
    60 => 'mmioCFDeleteEntry',
    61 => 'mmioCFChangeEntry',
    62 => 'mmioCFFindEntry',
    63 => 'mmioCFAddElement',
    64 => 'mmioCFGetInfo',
    65 => 'mmioCFSetInfo',
    66 => 'mmioCFCopy',
    67 => 'mmiohlpBuildCtoc',
    68 => 'mmiohlpCreateCtoc',
    69 => 'mmiohlpRewriteCtoc',
    70 => 'mmiohlpGetHeaderInfo',
    71 => 'mmiohlpUpdateCtocHeader',
    72 => 'mmiohlpChangeCtocHeader',
    73 => 'mmiohlpGetRemainingSize',
    74 => 'mmiohlpFindOpenCtoc',
    75 => 'mmiohlpGetFullPathName',
    76 => 'mmiohlpAddCtocInstance',
    77 => 'mmiohlpRemoveCtocInstance',
    78 => 'mmiohlpLastModTime',
    79 => 'mmiohlpOpenTempElement',
    80 => 'mmiohlpCloseTempElement',
    81 => 'mmiohlpTempName',
    82 => 'mmiohlpRemoveSharingEntry',
    83 => 'mmiohlpAddSharingEntry',
    84 => 'mmiohlpCheckSharingMode',
    85 => 'mmiohlpCheckHmmcfSharingMode',
    86 => 'mmiohlpListTransferNode',
    87 => 'mmioQueryFormatCount',
    88 => 'mmioGetFormats',
    89 => 'mmioQueryHeaderLength',
    90 => 'mmioGetHeader',
    91 => 'mmioSetHeader',
    92 => 'mmioIdentifyFile',
    93 => 'mmioGetFormatName',
    94 => 'mmiohlpGetFormatStringLength',
    95 => 'mmiohlpGetFormatString',
    96 => 'mmiohlpGetNLSData',
    97 => 'CFIOProc',
    98 => 'mmioIniFileHandler',
    99 => 'mmioIdentifyFileFormat',
    100 => 'mmioIdentifyStorageSystem',
    101 => 'mmioDetermineSSIOProc',
    102 => 'mmioDetermineFFIOProc',
    103 => 'mmioDetermineLastIOProc',
    104 => 'mmiohlpIsFccSS',
    105 => 'mmiohlpIsFccFF',
    106 => 'mmioQueryIOProcModuleHandle',
    107 => 'mmiohlpGetElementStart',
    108 => 'mmiohlpChangeSharingEntry',
    109 => 'mmiohlpLoadNextIOProc',
    110 => 'mmiohlpLoadIOProc',
    111 => 'mmioMigrateIniFile',
    112 => 'mmioIniFileCODEC',
    113 => 'mmioCFCompact',
    114 => 'mmioSet',
    115 => 'mmioQueryCODECName',
    116 => 'mmiohlpCFName',
    117 => 'mmioLoadCODECProc',
    118 => 'mmioQueryCODECNameLength',
    119 => 'mmioGetData',
    120 => 'HhpCreateHeap',
    121 => 'HhpIAllocMem',
    122 => 'HhpFreeMem',
    123 => 'HhpDestroyHeap',
    124 => 'HhpAccessHeap',
    125 => 'HhpReleaseHeap',
    126 => 'HhpAllocBuffer',
    127 => 'HhpFreeBuffer',
    128 => 'HhpAccessBuffer',
    129 => 'HhpGetPID',
    130 => 'HhpTAllocMem',
    131 => 'SMHEntryPoint',
    132 => 'SpiCreateStream',
    133 => 'SpiGetHandler',
    134 => 'SpiStartStream',
    135 => 'SpiAssociate',
    136 => 'SpiDestroyStream',
    137 => 'SpiSeekStream',
    138 => 'SpiStopStream',
    139 => 'SpiEnableEvent',
    140 => 'SpiDisableEvent',
    141 => 'SpiEnableSync',
    142 => 'SpiDisableSync',
    143 => 'SpiInstallProtocol',
    144 => 'SpiGetProtocol',
    145 => 'SpiGetTime',
    146 => 'SpiEnumerateHandlers',
    147 => 'SpiEnumerateProtocols',
    148 => 'SpiSendMsg',
    149 => 'SpiDetermineSyncMaster',
    150 => 'SpiDebug',
    151 => 'AUDIOIFDriverEntry',
    152 => 'VSDEntry',
    153 => 'mciDriverEntry',
    154 => 'mciDriverEntry',
    155 => 'mciDriverEntry',
    156 => 'mciDriverEntry',
    157 => 'vsdDriverEntry',
    158 => 'mciDriverEntry',
    159 => 'WAVEIOProc',
    160 => 'MIDIIOProc',
    161 => 'IOProc_Entry',
    162 => 'MapTranslateInit',
    163 => 'MapTranslateByte',
    164 => 'MapQueryPorts',
    165 => 'MapTranslateTerm',
    166 => 'MapQueryChannelMap',
    167 => 'MapSetChannelMap',
    168 => 'MapQueryMidiType',
    169 => 'MapSetMidiType',
    170 => 'MapQueryMidiTypeList',
    171 => 'MapQueryMidiTypeData',
    208 => 'mci16GetErrorString',
    209 => 'mci16SendString',
    210 => 'mci16GetDeviceID',
  },

  '' => {
  },
);

my %modulemap = ();
my %imports = ();

# !!! FIXME: lx_dump stupidly uses a different output format for LX and NE
# !!! FIXME:  binaries, so we parse for both here.  :(   Fix that in lx_dump.
while (<>) {
    chomp;
    if (/\A\s*Fixup type: IMPORTORDINAL \(module (\d+), ordinal (\d+)\)\Z/) {
        $imports{(int($1) << 16) | int($2)} = 0;
    } elsif (/\A\s*Fixup type: IMPORTNAME \(module (\d+), ordinal (\d+)\)/) {
        print("WARNING: Saw IMPORTNAME, currently unsupported\n");
    } elsif (/\AImport by ordinal fixup record:\Z/) {
        my $modordstr = <>;
        my $ordstr = <>;
        chomp($modordstr);
        chomp($ordstr);
        if ($modordstr =~ /\AModule ordinal:\s*(\d+)\Z/) {
            my $modord = int($1);
            if ($ordstr =~ /\AImport ordinal:\s*(\d+)\Z/) {
                my $ord = int($1);
                $imports{(int($modord) << 16) | int($ord)} = 0;
            }
        }
    } elsif (/\AModule reference table \(/) {
        while (<>) {
            chomp;
            if (/\A\s*(\d+)\:\s*(.*?)\Z/) {
                my $ord = int($1);
                my $name = $2;
                $name =~ tr/a-z/A-Z/;
                $modulemap{$ord} = $name;
                #print("Module '$name' is ordinal $ord\n");
            } else {
                last;
            }
        }
    } elsif (/\AImport modules \(/) {
        while (<>) {
            chomp;
            if (/\A\s*(\d+)\:\s*(.*?)\Z/) {
                my $ord = int($1);
                my $name = $2;
                $name =~ tr/a-z/A-Z/;
                $modulemap{$ord} = $name;
                #print("Module '$name' is ordinal $ord\n");
            } else {
                last;
            }
        }
    }
}


my %unknownmodules = ();

foreach (sort(keys(%imports))) {
    my $h = $_;
    my $module = ($h >> 16) & 0xFFFF;
    my $ordinal = $h & 0xFFFF;
    #print("$module:$ordinal\n");

    next if (defined $unknownmodules{$module});

    if (not defined $modulemap{$module}) {
        $unknownmodules{$module} = 1;
        print STDERR "*** UNKNOWN MODULE ORDINAL $module!\n";
        next;
    }
    
    my $modname = $modulemap{$module};
    if (not defined $os2modules{$modname}) {
        $unknownmodules{$module} = 1;
        print STDERR "*** UNKNOWN MODULE $modname!\n";
        next;
    }
}

foreach (sort(keys(%imports))) {
    my $h = $_;
    my $module = ($h >> 16) & 0xFFFF;
    my $ordinal = $h & 0xFFFF;
    #print("$module:$ordinal\n");

    next if (defined $unknownmodules{$module});

    my $modname = $modulemap{$module};
    if (not defined $os2modules{$modname}{$ordinal}) {
        print STDERR "*** UNKNOWN ORDINAL $ordinal IN MODULE $modname!\n";
        next;
    }

    my $symname = $os2modules{$modname}{$ordinal};
    print("$symname ($modname\@$ordinal)\n");
}

# end of os2imports.pl ...

